@@ -657,6 +657,7 @@ atlantis\
 atunnels\
 ball\
 bat\
+biof\
 blot\
 bouboule\
 bounce\
@@ -674,12 +675,13 @@ decay\
 deco\
 demon\
 dilemma\
-dragon\
 discrete\
+dragon\
 drift\
 euler2d\
 eyes\
 fadeplot\
+fiberlamp\
 fire\
 flag\
 flame\
@@ -720,7 +722,7 @@ molecule\
 morph3d\
 mountain\
 munch\
-nose\
+noof\
 nose\
 pacman\
 penrose\
@@ -760,6 +762,7 @@ text3d\
 text3d2\
 thornbird\
 tik_tak\
+toneclock\
 triangle\
 tube\
 turtle\
