@@ -10,22 +10,21 @@
  * Substitute #undef with #define to activate option
  */
 
-XCOMM !!!WARNING!!! Known security hole with MesaGL < 3.0 if setuid root
-XCOMM Define these now or down further below, see below for explaination.
-XCOMM #define CPPCompiler
-XCOMM #define XpmLibrary
-XCOMM #define XmLibrary
-XCOMM #define GLLibrary
+XCOMM Define these now or down further below, see below for explanation.
+#define CPPCompiler
+#define XpmLibrary
+#define XmLibrary
+#define GLLibrary
 XCOMM #define TtfLibrary
 XCOMM #define GlttLibrary
-XCOMM #define DtSaverLibrary
-XCOMM #define DPMSLibrary
+#define DtSaverLibrary
+#define DPMSLibrary
 XCOMM #define RplayLibrary
 XCOMM #define NasLibrary
 XCOMM #define Modules
 XCOMM #define Check
-XCOMM #define Unstable
-XCOMM #define DisableInteractive
+#define Unstable
+#define DisableInteractive
 
 N =
 O = .o
@@ -127,7 +126,7 @@ XCOMM  EDITRESLIB = -lXmu
 
 XCOMM   *** END XM CONFIG SECTION ***
 
-XCOMM   *** BEGIN MESAGL AND OPENGL CONFIG SECTION ***
+XCOMM   *** BEGIN MESA AND OPENGL CONFIG SECTION ***
 
 XCOMM Modes in modes/glx use this.
 XCOMM If your system has libMesaGL & widgets,
@@ -163,7 +162,7 @@ XCOMM Threads
 XCOMM  GLLIB += -lpthread
 #endif
 
-XCOMM   *** END MESAGL AND OPENGL CONFIG SECTION ***
+XCOMM   *** END MESA AND OPENGL CONFIG SECTION ***
 
 XCOMM   *** BEGIN CDE DT CONFIG SECTION ***
 
@@ -351,7 +350,7 @@ XCOMM  PASSWDDEF = -DDCE_PASSWD
 XCOMM  PASSWDINC = -I/usr/include/reentrant
 XCOMM  PASSWDLIB = -ldce -lc_r
 
-XCOMM PAM (tested only on Linux)
+XCOMM PAM
 XCOMM  PASSWDDEF = -DUSE_PAM
 XCOMM  PASSWDLIB = -lpam -ldl
 
@@ -475,6 +474,7 @@ BITMAPTYPE = sco
 PIXMAPTYPE = sco
 #else
 #ifdef cygwinArchitecture
+SLEEPDEF = -DHAVE_USLEEP
 BITMAPTYPE = cygwin
 PIXMAPTYPE = cygwin
 #else
