@@ -65,8 +65,8 @@ static XrmOptionDescRec opts[] =
 };
 static argtype vars[] =
 {
-	{(caddr_t *) & rule, (char *) "rule", (char *) "Rule", (char *) DEF_RULE, t_String},
-	{(caddr_t *) & eyes, (char *) "eyes", (char *) "Eyes", (char *) DEF_EYES, t_Bool}
+	{(void *) & rule, (char *) "rule", (char *) "Rule", (char *) DEF_RULE, t_String},
+	{(void *) & eyes, (char *) "eyes", (char *) "Eyes", (char *) DEF_EYES, t_Bool}
 };
 static OptionStruct desc[] =
 {
@@ -196,7 +196,7 @@ typedef struct {
 static int newDirectionMap[4][6][6] = {
 { /* TRS */
 	{NU, NU, ZP, ZN, YN, YP}, /* oldGravity = XN */
-	{NU, NU, ZN, ZP, YP, YN}, 
+	{NU, NU, ZN, ZP, YP, YN},
 	{ZN, ZP, NU, NU, XP, XN}, /* oldGravity = YN */
 	{ZP, ZN, NU, NU, XN, XP},
 	{YP, YN, XN, XP, NU, NU}, /* oldGravity = ZN */
@@ -204,7 +204,7 @@ static int newDirectionMap[4][6][6] = {
 },
 { /* TLS */
 	{NU, NU, ZN, ZP, YP, YN}, /* oldGravity = XN */
-	{NU, NU, ZP, ZN, YN, YP}, 
+	{NU, NU, ZP, ZN, YN, YP},
 	{ZP, ZN, NU, NU, XN, XP}, /* oldGravity = YN */
 	{ZN, ZP, NU, NU, XP, XN},
 	{YN, YP, XP, XN, NU, NU}, /* oldGravity = ZN */
@@ -212,7 +212,7 @@ static int newDirectionMap[4][6][6] = {
 },
 { /* TUS */
 	{NU, NU, XP, XP, XP, XP}, /* oldGravity = XN */
-	{NU, NU, XN, XN, XN, XN}, 
+	{NU, NU, XN, XN, XN, XN},
 	{YP, YP, NU, NU, YP, YP}, /* oldGravity = YN */
 	{YN, YN, NU, NU, YN, YN},
 	{ZP, ZP, ZP, ZP, NU, NU}, /* oldGravity = ZN */
@@ -220,7 +220,7 @@ static int newDirectionMap[4][6][6] = {
 },
 { /* TDS */
 	{NU, NU, XN, XN, XN, XN}, /* oldGravity = XN */
-	{NU, NU, XP, XP, XP, XP}, 
+	{NU, NU, XP, XP, XP, XP},
 	{YN, YN, NU, NU, YN, YN}, /* oldGravity = YN */
 	{YP, YP, NU, NU, YP, YP},
 	{ZN, ZN, ZN, ZN, NU, NU}, /* oldGravity = ZN */
@@ -231,7 +231,7 @@ static int newDirectionMap[4][6][6] = {
 static int newGravityMap[4][6][6] = {
 { /* TRS */
 	{NU, NU, XN, XN, XN, XN}, /* oldGravity = XN */
-	{NU, NU, XP, XP, XP, XP}, 
+	{NU, NU, XP, XP, XP, XP},
 	{YN, YN, NU, NU, YN, YN}, /* oldGravity = YN */
 	{YP, YP, NU, NU, YP, YP},
 	{ZN, ZN, ZN, ZN, NU, NU}, /* oldGravity = ZN */
@@ -239,7 +239,7 @@ static int newGravityMap[4][6][6] = {
 },
 { /* TLS */
 	{NU, NU, XN, XN, XN, XN}, /* oldGravity = XN */
-	{NU, NU, XP, XP, XP, XP}, 
+	{NU, NU, XP, XP, XP, XP},
 	{YN, YN, NU, NU, YN, YN}, /* oldGravity = YN */
 	{YP, YP, NU, NU, YP, YP},
 	{ZN, ZN, ZN, ZN, NU, NU}, /* oldGravity = ZN */
@@ -247,7 +247,7 @@ static int newGravityMap[4][6][6] = {
 },
 { /* TUS */
 	{NU, NU, YN, YP, ZN, ZP}, /* oldGravity = XN */
-	{NU, NU, YN, YP, ZN, ZP}, 
+	{NU, NU, YN, YP, ZN, ZP},
 	{XN, XP, NU, NU, ZN, ZP}, /* oldGravity = YN */
 	{XN, XP, NU, NU, ZN, ZP},
 	{XN, XP, YN, YP, NU, NU}, /* oldGravity = ZN */
@@ -255,7 +255,7 @@ static int newGravityMap[4][6][6] = {
 },
 { /* TDS */
 	{NU, NU, YP, YN, ZP, ZN}, /* oldGravity = XN */
-	{NU, NU, YP, YN, ZP, ZN}, 
+	{NU, NU, YP, YN, ZP, ZN},
 	{XP, XN, NU, NU, ZP, ZN}, /* oldGravity = YN */
 	{XP, XN, NU, NU, ZP, ZN},
 	{XP, XN, YP, YN, NU, NU}, /* oldGravity = ZN */
@@ -653,7 +653,6 @@ RunAnt3D(antfarm3dstruct * ap)
 	statestruct *status;
 	int         i, state_pos, tape_pos;
 	unsigned char color;
-	short       old_dir, old_grav;
 
 	if (ap->ants == NULL)
 		return False;
@@ -673,9 +672,6 @@ RunAnt3D(antfarm3dstruct * ap)
 		SetList3D(anant->column, anant->row, anant->stack,
 			status->color);
 		ap->tape[tape_pos] = status->color;     /* write on tape */
-		                                                                
-		old_dir = anant->direction;
-		old_grav = anant->gravity;
 #ifdef DEBUG
 		(void) printf("gen %d: ", ap->generation);
 #endif
@@ -685,7 +681,7 @@ RunAnt3D(antfarm3dstruct * ap)
 		/*chg_dir = (2 * ANGLES - status->direction) % ANGLES;
 		anant->direction = (chg_dir + old_dir) % ANGLES; */
 		anant->state = status->next;
-		                                                                
+
 		/* Allow step first then turn */
 		/*old_dir = ((status->direction < ANGLES) ?
 			anant->direction : old_dir);*/
@@ -775,8 +771,6 @@ getTurk(ModeInfo * mi, int logClass, int number)
 	ap->nstates = 1;
 	total = ap->ncolors * ap->nstates;
 	for (j = 0; j < total; j++) {
-		int turn;
-
 		power4 >>= 2;
 		ap->machine[j].color = (j + 1) % total;
 		ap->machine[j].turn = ((power4 * 3) & number) / power4;
@@ -840,7 +834,7 @@ parseRule(ModeInfo * mi)
 					} while ((!bucket[0] && !bucket[1]) || (!bucket[0] && !bucket[2]) ||
 						 (!bucket[0] && !bucket[3]) || (!bucket[1] && !bucket[2]) ||
 						 (!bucket[1] && !bucket[3]) || (!bucket[2] && !bucket[3]));
-										
+
 					getTurk(mi, logClass, number);
 					return;
 				}
@@ -901,21 +895,21 @@ lissajous(antfarm3dstruct * ap)
 	alt = 44.0 * sin(ap->metaAlt * IP) + 45.0;
 	ap->metaAlt += 1.123;
 	if (ap->metaAlt >= 360.0)
-		ap->metaAlt -= 360.0;	
+		ap->metaAlt -= 360.0;
 	if (ap->metaAlt < 0.0)
-		ap->metaAlt += 360.0;	
+		ap->metaAlt += 360.0;
 	azm = 44.0 * sin(ap->metaAzm * IP) + 45.0;
 	ap->metaAzm += 0.987;
 	if (ap->metaAzm >= 360.0)
-		ap->metaAzm -= 360.0;	
+		ap->metaAzm -= 360.0;
 	if (ap->metaAzm < 0.0)
-		ap->metaAzm += 360.0;	
+		ap->metaAzm += 360.0;
 	dist = 10.0 * sin(ap->metaDist * IP) + 50.0;
 	ap->metaDist += 1.0;
 	if (ap->metaDist >= 360.0)
 		ap->metaDist -= 360.0;
 	if (ap->metaDist < 0.0)
-		ap->metaDist += 360.0;	
+		ap->metaDist += 360.0;
 #if 0
 	if (alt >= 90.0)
 		alt = 90.0;
@@ -1067,12 +1061,13 @@ DrawFace(ModeInfo * mi, int color, XPoint * cubepts,
 		XFillPolygon(display, ap->dbuf, gc, facepts, 4,
 			Convex, CoordModeOrigin);
 	gc = MI_GC(mi);
-	if (!ap->wireframe)
+	if (!ap->wireframe) {
 		if (color == NCOLORS) {
 			XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
 		} else {
 			XSetForeground(display, gc, MI_WHITE_PIXEL(mi));
 		}
+	}
 	XDrawLines(display, ap->dbuf, gc, facepts, 5, CoordModeOrigin);
 }
 
@@ -1128,12 +1123,13 @@ DrawEyes(ModeInfo * mi, int color, XPoint * cubepts,
 		XFillPolygon(display, ap->dbuf, gc, facepts, 4,
 			Convex, CoordModeOrigin);
 	gc = MI_GC(mi);
-	if (!ap->wireframe)
+	if (!ap->wireframe) {
 		if (color == NCOLORS) {
 			XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
 		} else {
 			XSetForeground(display, gc, MI_WHITE_PIXEL(mi));
 		}
+	}
 	XDrawLines(display, ap->dbuf, gc, facepts, 5, CoordModeOrigin);
 }
 
@@ -1155,7 +1151,7 @@ DrawCube(ModeInfo * mi, antstruct * cell)
 	row = (double) cell->row - ap->oy;
 	stack = (double) cell->stack - ap->oz;
 	color = cell->color;
-	out = 0; 
+	out = 0;
 	i = 0;
 	for (dz = stack - LEN; dz <= stack + LEN2; dz += LEN2)
 		for (dy = row - LEN; dy <= row + LEN2; dy += LEN2)
