@@ -50,7 +50,7 @@ static const char sccsid[] = "@(#)apollonian.c	5.02 2001/07/01 xlockmore";
  * Add a small font
  *
  * Revision History:
- * 25-Jun-2001: Converted from C and Postscript code by David Bagley 
+ * 25-Jun-2001: Converted from C and Postscript code by David Bagley
  *              Original code by Allan R. Wilks <allan@research.att.com>.
  *
  * From Circle Math Science News April 21, 2001 VOL. 254-255
@@ -96,8 +96,8 @@ static XrmOptionDescRec opts[] =
 };
 static argtype vars[] =
 {
-	{(caddr_t *) & altgeom, (char *) "altgeom", (char *) "AltGeom", (char *) DEF_ALTGEOM, t_Bool},
-	{(caddr_t *) & label, (char *) "label", (char *) "Label", (char *) DEF_LABEL, t_Bool},
+	{(void *) & altgeom, (char *) "altgeom", (char *) "AltGeom", (char *) DEF_ALTGEOM, t_Bool},
+	{(void *) & label, (char *) "label", (char *) "Label", (char *) DEF_LABEL, t_Bool},
 };
 static OptionStruct desc[] =
 {
@@ -131,9 +131,8 @@ typedef struct {
         double h;       /* hyperbolic bend */
         double x, y;    /* euclidean bend times euclidean position */
 } circle;
-enum space {
-  /* euclidean = 0, */ spherical = 1, hyperbolic = 2
-};
+
+typedef enum {euclidean = 0, spherical = 1, hyperbolic = 2} Space;
 
 static const char * space_string[] = {
   "euclidean",
@@ -155,7 +154,7 @@ c * z3 = (q123 + a * i)^2/(a*(a+b)) where q123 = sqrt(a*b+a*c+b*c)
 d * z4 = (q124 + a * i)^2/(a*(a+b)) where q124 = q123 - a - b
 If (e,x,y) represents the Euclidean circle (1/e,x/e,y/e) (so that e is
 the label in the standard picture) then the "spherical label" is
-(e^2+x^2+y^2-1)/(2*e) (an integer!)  and the "hyperbolic label", is 
+(e^2+x^2+y^2-1)/(2*e) (an integer!)  and the "hyperbolic label", is
 calulated by h + s = e.
 */
 static circle examples[][4] = {
@@ -224,7 +223,7 @@ static circle examples[][4] = {
 	{-6, -5, -1,           0.0,  0.0},
 	{11, 10,  1,     5.0 / 6.0,  0.0},
 	{14, 11,  3,  -16.0 / 15.0, -0.8},
-	{15, 12,  3,          -0.9,  1.2} 
+	{15, 12,  3,          -0.9,  1.2}
 },
 #endif
 /* Non integer stuff */
@@ -233,7 +232,7 @@ static circle examples[][4] = {
 	{   -1,    -1,    -1,   0.0,  0.0},
 	{DELTA, DELTA, DELTA,   1.0,  0.0},
 	{DELTA, DELTA, DELTA,   1.0, -1.0},
-	{DELTA, DELTA, DELTA,  -1.0,  1.0} 
+	{DELTA, DELTA, DELTA,  -1.0,  1.0}
 },
 { /* semi-bounded (x, y calculated later) */
 #define ALPHA 2.618033989 /* ((3+sqrt(5))/2) */
@@ -284,7 +283,7 @@ Hyperbolic
 typedef struct {
 	int         size;
 	XPoint      offset;
-	int         geometry;
+	Space       geometry;
 	circle      c1, c2, c3, c4;
 	int         color_offset;
 	int         count;
@@ -336,7 +335,7 @@ dquad(int n, apollonian_quadruple *quad)
 {
 	int a, b, c, d;
 	int counter = 0, B, C;
-	
+
 	for (a = 0; a < MAXBEND; a++) {
 		B = (int) (K * a);
 		for (b = a + 1; b <= B; b++) {
@@ -358,7 +357,7 @@ dquad(int n, apollonian_quadruple *quad)
 	(void) printf("found only %d below maximum bend of %d\n",
 		counter, MAXBEND);
 	for (; counter < n; counter++) {
- 		quad[counter].a = -1; 
+ 		quad[counter].a = -1;
  		quad[counter].b = 2;
  		quad[counter].c = 2;
 		quad[counter].d = 3;
@@ -443,7 +442,7 @@ iceil(int a, int b)
 }
 
 static double
-geom(int geometry, int e, int p, int q)
+geom(Space geometry, int e, int p, int q)
 {
 	int g = (geometry == spherical) ? -1 :
 		(geometry == hyperbolic) ? 1 : 0;
@@ -546,8 +545,8 @@ p(ModeInfo *mi, circle c)
 		  XDrawString(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
 			((int) (cp->size * c.x / (2.0 * c.e) + cp->offset.x)),
 			((int) (cp->size * c.y / (2.0 * c.e) + MI_HEIGHT(mi) -
-			FONT_HEIGHT / 2)), space_string[cp->geometry],
-			strlen(space_string[cp->geometry]));
+			FONT_HEIGHT / 2)), space_string[(int) cp->geometry],
+			strlen(space_string[(int) cp->geometry]));
 		}
 		return;
 	}
@@ -707,9 +706,9 @@ init_apollonian(ModeInfo * mi)
 		dquad(cp->count, cp->quad);
 	}
 	cp->game = NRAND(PREDEF_CIRCLE_GAMES + cp->count);
-	cp->geometry = (cp->game && cp->altgeom) ? NRAND(3) : 0;
+	cp->geometry = (Space) ((cp->game && cp->altgeom) ? NRAND(3) : 0);
 
-	if (cp->game < PREDEF_CIRCLE_GAMES) {	
+	if (cp->game < (int) PREDEF_CIRCLE_GAMES) {
 		cp->c1 = examples[cp->game][0];
 		cp->c2 = examples[cp->game][1];
 		cp->c3 = examples[cp->game][2];
@@ -722,7 +721,7 @@ init_apollonian(ModeInfo * mi)
 		cp->c2.e = cp->quad[i].b;
 		cp->c3.e = cp->quad[i].c;
 		cp->c4.e = cp->quad[i].d;
-		if (cp->geometry)
+		if (cp->geometry != euclidean)
 			cquad(&(cp->c1), &(cp->c2), &(cp->c3), &(cp->c4));
 	}
 	cp->time = 0;
@@ -765,7 +764,7 @@ init_apollonian(ModeInfo * mi)
 	randomize_c(i, &(cp->c2));
 	randomize_c(i, &(cp->c3));
 	randomize_c(i, &(cp->c4));
-#endif 
+#endif
 }
 
 void
