@@ -57,7 +57,7 @@ static XrmOptionDescRec opts[] =
 };
 static argtype vars[] =
 {
-	{(caddr_t *) & boil, (char *) "boil", (char *) "Boil", (char *) DEF_BOIL, t_Bool}
+	{(void *) & boil, (char *) "boil", (char *) "Boil", (char *) DEF_BOIL, t_Bool}
 };
 static OptionStruct desc[] =
 {
@@ -165,7 +165,6 @@ changeBubble(ModeInfo * mi)
 	}
 }
 
- 
 static void
 free_bubble(Display *display, bubblestruct *bp)
 {
@@ -272,7 +271,7 @@ draw_bubble(ModeInfo * mi)
 	bp = &bubbles[MI_SCREEN(mi)];
 	if (bp->bubble == NULL)
 		return;
-	
+
 	MI_IS_DRAWN(mi) = True;
 	if (MI_NPIXELS(mi) <= 2)
 		XSetForeground(display, gc, MI_WHITE_PIXEL(mi));
