@@ -135,13 +135,13 @@ static XrmOptionDescRec opts[] =
 
 static argtype vars[] =
 {
-	{(caddr_t *) & nx, (char *) "nx", (char *) "nx", (char *) DEF_NX, t_Int},
-	{(caddr_t *) & ny, (char *) "ny", (char *) "ny", (char *) DEF_NY, t_Int},
-	{(caddr_t *) & centre, (char *) "centre", (char *) "Centre", (char *) DEF_CENTRE, t_Bool},
-	{(caddr_t *) & maxsize, (char *) "maxsize", (char *) "Maxsize", (char *) DEF_MAXSIZE, t_Bool},
-	{(caddr_t *) & unit_cell, (char *) "cell", (char *) "Cell", (char *) DEF_CELL, t_Bool},
-	{(caddr_t *) & grid_cell, (char *) "grid", (char *) "Grid", (char *) DEF_GRID, t_Bool},
-	{(caddr_t *) & cycle_p, (char *) "cycle", (char *) "Cycle", (char *) DEF_CYCLE, t_Bool}
+	{(void *) & nx, (char *) "nx", (char *) "nx", (char *) DEF_NX, t_Int},
+	{(void *) & ny, (char *) "ny", (char *) "ny", (char *) DEF_NY, t_Int},
+	{(void *) & centre, (char *) "centre", (char *) "Centre", (char *) DEF_CENTRE, t_Bool},
+	{(void *) & maxsize, (char *) "maxsize", (char *) "Maxsize", (char *) DEF_MAXSIZE, t_Bool},
+	{(void *) & unit_cell, (char *) "cell", (char *) "Cell", (char *) DEF_CELL, t_Bool},
+	{(void *) & grid_cell, (char *) "grid", (char *) "Grid", (char *) DEF_GRID, t_Bool},
+	{(void *) & cycle_p, (char *) "cycle", (char *) "Cycle", (char *) DEF_CYCLE, t_Bool}
 };
 static OptionStruct desc[] =
 {
