@@ -22,6 +22,7 @@ static const char sccsid[] = "@(#)dclock.c	5.00 2000/11/01 xlockmore";
  * other special, indirect and consequential damages.
  *
  * Revision History:
+ * 01-Mar-2005: Added 24 hour clock (alex(at)shark-linux(dot)de)
  * 01-Nov-2000: Allocation checks
  * 07-May-1999: New "savers" added for y2k and second millennium countdowns.
  *              Tom Schmidt <tschmidt@micron.com>
@@ -141,6 +142,7 @@ static const char sccsid[] = "@(#)dclock.c	5.00 2000/11/01 xlockmore";
 #define DEF_HIV    "False"
 #define DEF_LAB    "False"
 #define DEF_VEG    "False"
+#define DEF_TIME24 "False"
 #define DEF_Y2K    "False"
 #define DEF_Y2001  "False"
 
@@ -200,6 +202,7 @@ static Bool forest;
 static Bool hiv;
 static Bool lab;
 static Bool veg;
+static Bool time24;
 static Bool y2k;
 static Bool millennium;
 
@@ -217,6 +220,8 @@ static XrmOptionDescRec opts[] =
 	{(char *) "+lab", (char *) ".dclock.lab", XrmoptionNoArg, (caddr_t) "off"},
 	{(char *) "-veg", (char *) ".dclock.veg", XrmoptionNoArg, (caddr_t) "on"},
 	{(char *) "+veg", (char *) ".dclock.veg", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "-time24", (char *) ".dclock.time24", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+time24", (char *) ".dclock.time24", XrmoptionNoArg, (caddr_t) "off"},
 	{(char *) "-y2k", (char *) ".dclock.y2k", XrmoptionNoArg, (caddr_t) "on"},
 	{(char *) "+y2k", (char *) ".dclock.y2k", XrmoptionNoArg, (caddr_t) "off"},
 	{(char *) "-millennium", (char *) ".dclock.millennium", XrmoptionNoArg, (caddr_t) "on"},
@@ -224,14 +229,15 @@ static XrmOptionDescRec opts[] =
 };
 static argtype vars[] =
 {
-	{(caddr_t *) & led, (char *) "led", (char *) "LED", (char *) DEF_LED, t_Bool},
-	{(caddr_t *) & popex, (char *) "popex", (char *) "PopEx", (char *) DEF_POPEX, t_Bool},
-	{(caddr_t *) & forest, (char *) "forest", (char *) "Forest", (char *) DEF_FOREST, t_Bool},
-	{(caddr_t *) & hiv, (char *) "hiv", (char *) "Hiv", (char *) DEF_HIV, t_Bool},
-	{(caddr_t *) & lab, (char *) "lab", (char *) "Lab", (char *) DEF_LAB, t_Bool},
-	{(caddr_t *) & veg, (char *) "veg", (char *) "Veg", (char *) DEF_VEG, t_Bool},
-	{(caddr_t *) & y2k, (char *) "y2k", (char *) "Y2K", (char *) DEF_Y2K, t_Bool},
-	{(caddr_t *) & millennium, (char *) "millennium", (char *) "Millennium", (char *) DEF_Y2001, t_Bool}
+	{(void *) & led, (char *) "led", (char *) "LED", (char *) DEF_LED, t_Bool},
+	{(void *) & popex, (char *) "popex", (char *) "PopEx", (char *) DEF_POPEX, t_Bool},
+	{(void *) & forest, (char *) "forest", (char *) "Forest", (char *) DEF_FOREST, t_Bool},
+	{(void *) & hiv, (char *) "hiv", (char *) "Hiv", (char *) DEF_HIV, t_Bool},
+	{(void *) & lab, (char *) "lab", (char *) "Lab", (char *) DEF_LAB, t_Bool},
+	{(void *) & veg, (char *) "veg", (char *) "Veg", (char *) DEF_VEG, t_Bool},
+	{(void *) & time24, (char *) "time24", (char *) "Time24", (char *) DEF_TIME24, t_Bool},
+	{(void *) & y2k, (char *) "y2k", (char *) "Y2K", (char *) DEF_Y2K, t_Bool},
+	{(void *) & millennium, (char *) "millennium", (char *) "Millennium", (char *) DEF_Y2001, t_Bool}
 };
 static OptionStruct desc[] =
 {
@@ -241,6 +247,7 @@ static OptionStruct desc[] =
 	{(char *) "-/+hiv", (char *) "turn on/off HIV infection counter"},
 	{(char *) "-/+lab", (char *) "turn on/off Animal Research counter"},
 	{(char *) "-/+veg", (char *) "turn on/off Animal Consumation counter"},
+	{(char *) "-/+time24", (char *) "turn on/off 24 hour display"},
 	{(char *) "-/+y2k", (char *) "turn on/off Year 2000 countdown"},
 	{(char *) "-/+millennium", (char *) "turn on/off 3rd Millennium (1 January 2001) countdown"},
 };
@@ -321,7 +328,7 @@ typedef struct {
 	int         pixw, pixh;
 	Pixmap      pixmap;
 	GC          fgGC, bgGC;
-	Bool        popex, forest, hiv, lab, veg, y2k, millennium, led;
+	Bool        popex, forest, hiv, lab, veg, time24, y2k, millennium, led;
 	XPoint      parallelogram[4];
 } dclockstruct;
 
@@ -351,7 +358,7 @@ convert(double x, char *string)
    locale.  Known to work with gcc-2.95.2 and glibc-2.1.3. */
 	(void) snprintf(string, STRSIZE, "%'.0f", x);
 #else
-	
+
 	int         i, j, k = 0;
 	int         place = (int) (log(x) / logbase);
 	double      divisor = 1.0;
@@ -573,6 +580,9 @@ drawDclock(ModeInfo * mi)
 
 			if (!dp->popex && !dp->forest && !dp->hiv && !dp->lab &&
 			    !dp->veg && !dp->y2k && !dp->millennium) {
+			  if (dp->time24)
+				(void) strftime(dp->str1pta, STRSIZE, "%H:%M:%S", localtime(&(dp->timeold)));
+			  else
 				(void) strftime(dp->str1pta, STRSIZE, "%I:%M:%S %p", localtime(&(dp->timeold)));
 			}
 			(void) strftime(dp->str2pta, STRSIZE, "%a %b %d %Y", localtime(&(dp->timeold)));
@@ -844,19 +854,20 @@ init_dclock(ModeInfo * mi)
 	dp->hiv = False;
 	dp->lab = False;
 	dp->veg = False;
+	dp->time24 = False;
 	dp->y2k = False;
 	dp->millennium = False;
 #if defined(MODE_dclock_y2k) && defined(MODE_dclock_millennium)
-#define NUM_DCLOCK_MODES 9
+#define NUM_DCLOCK_MODES 10
 #endif
 #if defined(MODE_dclock_y2k) && !defined(MODE_dclock_millennium)
-#define NUM_DCLOCK_MODES 8
+#define NUM_DCLOCK_MODES 9
 #endif
 #if !defined(MODE_dclock_y2k) && defined(MODE_dclock_millennium)
-#define NUM_DCLOCK_MODES 8
+#define NUM_DCLOCK_MODES 9
 #endif
 #if !defined(MODE_dclock_y2k) && !defined(MODE_dclock_millennium)
-#define NUM_DCLOCK_MODES 7
+#define NUM_DCLOCK_MODES 8
 #endif
 	if (MI_IS_FULLRANDOM(mi)) {
 		switch (NRAND(NUM_DCLOCK_MODES)) {
@@ -880,8 +891,11 @@ init_dclock(ModeInfo * mi)
 			case 6:
 				dp->veg = True;
 				break;
-#if defined(MODE_dclock_y2k) || defined(MODE_dclock_millennium)
 			case 7:
+				dp->time24 = True;
+				break;
+#if defined(MODE_dclock_y2k) || defined(MODE_dclock_millennium)
+			case 8:
 #ifdef MODE_dclock_y2k
 				dp->y2k = True;
 #else
@@ -889,7 +903,7 @@ init_dclock(ModeInfo * mi)
 #endif
 				break;
 #if defined(MODE_dclock_y2k) && defined(MODE_dclock_millennium)
-			case 8:
+			case 9:
 				dp->millennium = True;
 				break;
 #endif
@@ -904,6 +918,7 @@ init_dclock(ModeInfo * mi)
 		dp->hiv = hiv;
 		dp->lab = lab;
 		dp->veg = veg;
+		dp->time24 = time24;
 		dp->y2k = y2k;
 		dp->millennium = millennium;
 	}
@@ -1018,7 +1033,10 @@ init_dclock(ModeInfo * mi)
 		} else {
 			struct tm *t = localtime((const time_t *) &timeLocal);
 
-			(void) strftime(dp->str1, STRSIZE, "%I:%M:%S %p", t);
+			if (dp->time24)
+			  (void) strftime(dp->str1, STRSIZE, "%H:%M:%S", t);
+			else
+			  (void) strftime(dp->str1, STRSIZE, "%I:%M:%S %p", t);
 			dp->hour = t->tm_hour;
 			(void) strftime(dp->str2, STRSIZE, "%a %b %d %Y", t);
 
