@@ -95,7 +95,7 @@ static XrmOptionDescRec opts[] =
 };
 static argtype vars[] =
 {
-	{(caddr_t *) & invert, (char *) "invert", (char *) "Invert", (char *) DEF_INVERT, t_Bool}
+	{(void *) & invert, (char *) "invert", (char *) "Invert", (char *) DEF_INVERT, t_Bool}
 };
 static OptionStruct desc[] =
 {
@@ -319,7 +319,7 @@ getText(ModeInfo * mi, XImage ** image)
 			  text1[strlen(text1) - 1] == '\n'))
 		text1[strlen(text1) - 1] = 0;
 	if ((text2 = (char *) strdup(text1)) == NULL) {
-		(void) free((void *) text1);
+		free(text1);
 		return False;
 	}
 
@@ -345,8 +345,8 @@ getText(ModeInfo * mi, XImage ** image)
 
 	if ((text_pixmap = XCreatePixmap(display, MI_WINDOW(mi),
 			width, height, 1)) == None) {
-		(void) free((void *) text1);
-		(void) free((void *) text2);
+		free(text1);
+		free(text2);
 		return False;
 	}
 
@@ -356,8 +356,8 @@ getText(ModeInfo * mi, XImage ** image)
 	if ((gc = XCreateGC(display, text_pixmap,
 		       GCFont | GCForeground | GCBackground, &gcv)) == None) {
 	    XFreePixmap(display, text_pixmap);
-		(void) free((void *) text1);
-		(void) free((void *) text2);
+		free(text1);
+		free(text2);
 		return False;
 	}
 	XFillRectangle(display, text_pixmap, gc, 0, 0, width, height);
@@ -383,8 +383,8 @@ getText(ModeInfo * mi, XImage ** image)
 				   line, strlen(line));
 		lines++;
 	}
-	(void) free((void *) text1);
-	(void) free((void *) text2);
+	free(text1);
+	free(text2);
 	/*XUnloadFont(display, messagefont->fid); */
 	XFreeGC(display, gc);
 
@@ -476,7 +476,7 @@ release_flag(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_flag(MI_DISPLAY(mi), &flags[screen]);
-		(void) free((void *) flags);
+		free(flags);
 		flags = (flagstruct *) NULL;
 	}
 	if (messagefont != None) {
