@@ -78,8 +78,8 @@ static XrmOptionDescRec opts[] =
 
 static argtype vars[] =
 {
-	{(caddr_t *) & fisheye, (char *) "fisheye", (char *) "FishEye", (char *) DEF_FISHEYE, t_Bool},
-	{(caddr_t *) & tracks, (char *) "tracks", (char *) "Tracks", (char *) DEF_TRACKS, t_Bool}
+	{(void *) & fisheye, (char *) "fisheye", (char *) "FishEye", (char *) DEF_FISHEYE, t_Bool},
+	{(void *) & tracks, (char *) "tracks", (char *) "Tracks", (char *) DEF_TRACKS, t_Bool}
 };
 
 static OptionStruct desc[] =
@@ -560,9 +560,9 @@ draw_galaxy(ModeInfo * mi)
 	if (gp->fisheye) {
 		XCopyArea(display, drawable, MI_WINDOW(mi), gc,
 			0, 0, MI_WIDTH(mi), MI_HEIGHT(mi),0 , 0);
-	
+
 		XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
-	
+
 		XFillRectangle(display, drawable, gc,
 			0, 0, MI_WIDTH(mi), MI_HEIGHT(mi));
 	}
