@@ -13,7 +13,7 @@ static const char sccsid[] = "@(#)molecule.c	5.01 2001/04/12 xlockmore";
  * the above copyright notice appear in all copies and that both that
  * copyright notice and this permission notice appear in supporting
  * documentation.  No representations are made about the suitability of this
- * software for any purpose.  It is provided "as is" without express or 
+ * software for any purpose.  It is provided "as is" without express or
  * implied warranty.
  *
  *
@@ -25,7 +25,7 @@ static const char sccsid[] = "@(#)molecule.c	5.01 2001/04/12 xlockmore";
  * 19-Apr-01:  rolf@groppe.de   fixed some allocation problems
  *                              Startup message now only at first call
  * 12-Apr-01:  rolf@groppe.de   Ported this mode from xscreensaver to xlock.
- *                              Use of parameter -cycles instead of timeout, 
+ *                              Use of parameter -cycles instead of timeout,
  *                              when used as xlock module.
  *                              Some minor changes for better display in
  *                              iconified state.
@@ -42,7 +42,7 @@ static const char sccsid[] = "@(#)molecule.c	5.01 2001/04/12 xlockmore";
 
      - I'm not sure the text labels are being done in the best way;
        they are sometimes, but not always, occluded by spheres that
-       pass in front of them. 
+       pass in front of them.
  */
 
 #ifdef VMS
@@ -238,17 +238,17 @@ static XrmOptionDescRec opts[] = {
 };
 
 static argtype vars[] = {
-  {(caddr_t *) &molecule_str, (char *) "molecule",   (char *) "Molecule", (char *) DEF_MOLECULE,t_String},
+  {(void *) &molecule_str, (char *) "molecule",   (char *) "Molecule", (char *) DEF_MOLECULE,t_String},
 #ifdef STANDALONE
-  {(caddr_t *) &timeout,   (char *) "timeout",(char *) "Seconds", (char *) DEF_TIMEOUT,t_Int},
+  {(void *) &timeout,   (char *) "timeout",(char *) "Seconds", (char *) DEF_TIMEOUT,t_Int},
 #endif
-  {(caddr_t *) &do_spin,   (char *) "spin",   (char *) "Spin",   (char *) DEF_SPIN,   t_String},
-  {(caddr_t *) &do_wander, (char *) "wander", (char *) "Wander", (char *) DEF_WANDER, t_Bool},
-  {(caddr_t *) &do_labels, (char *) "labels", (char *) "Labels", (char *) DEF_LABELS, t_Bool},
-  {(caddr_t *) &do_titles, (char *) "titles", (char *) "Titles", (char *) DEF_TITLES, t_Bool},
-  {(caddr_t *) &do_atoms,  (char *) "atoms",  (char *) "Atoms",  (char *) DEF_ATOMS,  t_Bool},
-  {(caddr_t *) &do_bonds,  (char *) "bonds",  (char *) "Bonds",  (char *) DEF_BONDS,  t_Bool},
-  {(caddr_t *) &do_bbox,   (char *) "bbox",   (char *) "BBox",   (char *) DEF_BBOX,   t_Bool},
+  {(void *) &do_spin,   (char *) "spin",   (char *) "Spin",   (char *) DEF_SPIN,   t_String},
+  {(void *) &do_wander, (char *) "wander", (char *) "Wander", (char *) DEF_WANDER, t_Bool},
+  {(void *) &do_labels, (char *) "labels", (char *) "Labels", (char *) DEF_LABELS, t_Bool},
+  {(void *) &do_titles, (char *) "titles", (char *) "Titles", (char *) DEF_TITLES, t_Bool},
+  {(void *) &do_atoms,  (char *) "atoms",  (char *) "Atoms",  (char *) DEF_ATOMS,  t_Bool},
+  {(void *) &do_bonds,  (char *) "bonds",  (char *) "Bonds",  (char *) DEF_BONDS,  t_Bool},
+  {(void *) &do_bbox,   (char *) "bbox",   (char *) "BBox",   (char *) DEF_BBOX,   t_Bool},
 };
 
 static OptionStruct desc[] = {
@@ -298,7 +298,7 @@ static Bool
 load_font (ModeInfo *mi, char *res, XFontStruct **fontP, GLuint *dlistP)
 {
 #ifdef STANDALONE
-  const char *font = get_string_resource (res, "Font"); 
+  const char *font = get_string_resource (res, "Font");
 #else
   const char *font = res;
 #endif
@@ -314,7 +314,7 @@ load_font (ModeInfo *mi, char *res, XFontStruct **fontP, GLuint *dlistP)
   id = f->fid;
   first = f->min_char_or_byte2;
   last = f->max_char_or_byte2;
-  
+
   clear_gl_error ();
   *dlistP = glGenLists ((GLuint) last+1);
   if (check_gl_error ("glGenLists"))
@@ -467,7 +467,7 @@ set_atom_color (ModeInfo *mi, molecule_atom *a, Bool font_p)
       gl_color[2] = xcolor.blue  / 65536.0;
       gl_color[3] = 1.0;
     }
-  
+
   if (font_p)
     glColor3f (gl_color[0], gl_color[1], gl_color[2]);
   else
@@ -618,9 +618,9 @@ draw_bounding_box (ModeInfo *mi)
   if (x1 > 0) x1 = 0; if (x2 < 0) x2 = 0;
   if (y1 > 0) y1 = 0; if (y2 < 0) y2 = 0;
   if (z1 > 0) z1 = 0; if (z2 < 0) z2 = 0;
-  glVertex3f(x1, 0,  0);  glVertex3f(x2, 0,  0); 
-  glVertex3f(0 , y1, 0);  glVertex3f(0,  y2, 0); 
-  glVertex3f(0,  0,  z1); glVertex3f(0,  0,  z2); 
+  glVertex3f(x1, 0,  0);  glVertex3f(x2, 0,  0);
+  glVertex3f(0 , y1, 0);  glVertex3f(0,  y2, 0);
+  glVertex3f(0,  0,  z1); glVertex3f(0,  0,  z2);
   glEnd();
 
   glPopAttrib();
@@ -673,7 +673,7 @@ print_title_string (ModeInfo *mi, const char *string,
                     GLfloat x, GLfloat y, GLfloat line_height)
 {
   molecule_configuration *mc = &mcs[MI_SCREEN(mi)];
-  
+
   y -= line_height;
 
   glPushAttrib (GL_LIGHTING | GL_DEPTH_TEST);
@@ -911,7 +911,7 @@ parse_pdb_data (molecule *m, const char *data, const char *filename, int line)
           char *name = (char *) calloc (1, 100);
           char *n2 = name;
           int L = strlen(s);
-          
+
           if (L > 99) L = 99;
 
           (void) strncpy(n2, s, L);
@@ -1022,8 +1022,8 @@ parse_pdb_data (molecule *m, const char *data, const char *filename, int line)
         {
           int atoms[11];
           int i = sscanf (s + 8, " %d %d %d %d %d %d %d %d %d %d %d %d ",
-                          &atoms[0], &atoms[1], &atoms[2], &atoms[3], 
-                          &atoms[4], &atoms[5], &atoms[6], &atoms[7], 
+                          &atoms[0], &atoms[1], &atoms[2], &atoms[3],
+                          &atoms[4], &atoms[5], &atoms[6], &atoms[7],
                           &atoms[8], &atoms[9], &atoms[10], &atoms[11]);
           int j;
           for (j = 1; j < i; j++)
@@ -1349,7 +1349,7 @@ startup_blurb (ModeInfo *mi)
   firstcall = False;
 }
 
-void 
+void
 init_molecule (ModeInfo *mi)
 {
   molecule_configuration *mc;
@@ -1425,7 +1425,7 @@ init_molecule (ModeInfo *mi)
 
   load_molecules (mi);
   mc->which =  NRAND(mc->nmolecules);
-  
+
 #ifdef STANDALONE
   mc->no_label_threshold = get_float_resource ("noLabelThreshold",
                                                "NoLabelThreshold");
