@@ -106,10 +106,10 @@ static XrmOptionDescRec opts[] =
 };
 static argtype vars[] =
 {
-  {(caddr_t *) & random_start, (char *) "randomStart", (char *) "RandomStart", (char *) "True", t_Bool},
-	{(caddr_t *) & show_axes, (char *) "showAxes", (char *) "ShowAxes", (char *) "True", t_Bool},
-	{(caddr_t *) & show_planes, (char *) "showPlanes", (char *) "ShowPlanes", (char *) "False", t_Bool},
-	{(caddr_t *) & spin_delay, (char *) "spinDelay", (char *) "SpinDelay", (char *) "2", t_Int},
+	{(void *) & random_start, (char *) "randomStart", (char *) "RandomStart", (char *) "True", t_Bool},
+	{(void *) & show_axes, (char *) "showAxes", (char *) "ShowAxes", (char *) "True", t_Bool},
+	{(void *) & show_planes, (char *) "showPlanes", (char *) "ShowPlanes", (char *) "False", t_Bool},
+	{(void *) & spin_delay, (char *) "spinDelay", (char *) "SpinDelay", (char *) "2", t_Int},
 };
 static OptionStruct desc[] =
 {
@@ -131,7 +131,7 @@ ModStruct   hyper_description =
 
 #endif
 
-#if DEBUG
+#ifdef DEBUG
 #include <assert.h>
 #endif
 
@@ -447,7 +447,7 @@ figure_points(ModeInfo * mi)
 	 * First, figure out the points.
 	 */
 	hp->num_points = figure_num_points(hp->num_d);
-#if DEBUG
+#ifdef DEBUG
 	assert(hp->num_points <= hp->max_points);
 #endif
 	allocarray(hp->points, vector, hp->num_points * hp->num_mat);
@@ -471,7 +471,7 @@ figure_points(ModeInfo * mi)
 		n++;
 	} while (IncMultiCounter(c, hp->num_d));
 	free(c);
-#if DEBUG
+#ifdef DEBUG
 	assert(hp->num_points == n);
 #endif
 	/*
@@ -484,7 +484,7 @@ figure_points(ModeInfo * mi)
 		pix = NRAND(MI_NPIXELS(mi));
 
 	hp->num_lines = figure_num_lines(hp->num_d);
-#if DEBUG
+#ifdef DEBUG
 	assert(hp->num_lines <= hp->max_lines);
 #endif
 	allocarray(hp->lines, line_segment, hp->num_lines);
@@ -508,7 +508,7 @@ figure_points(ModeInfo * mi)
 			}
 		}
 	}
-#if DEBUG
+#ifdef DEBUG
 	assert(hp->num_lines == n);
 #endif
 
@@ -516,7 +516,7 @@ figure_points(ModeInfo * mi)
 	 * Now determine the planes of rotation.
 	 */
 	hp->num_planes = figure_num_planes(hp->num_d);
-#if DEBUG
+#ifdef DEBUG
 	assert(hp->num_planes <= max_planes);
 #endif
 	hp->show_planes = show_planes;
@@ -570,7 +570,7 @@ figure_points(ModeInfo * mi)
 			hp->rotation_planes[n].y = j;
 			n++;
 		}
-#if DEBUG
+#ifdef DEBUG
 	assert(hp->num_planes == n);
 #endif
 	/*
@@ -975,17 +975,17 @@ calc_transformation(ModeInfo * mi)
 	if ((Ttmp == NULL) || (Tpre == NULL) || (Tuser == NULL) ||
 			(Tpretranspose == NULL) || (Tscale == NULL) ||
 			(Tposttranspose == NULL)) {
-		if (Ttmp == NULL)	
+		if (Ttmp == NULL)
 			free(Ttmp);
-		if (Tpre == NULL)	
+		if (Tpre == NULL)
 			free(Tpre);
-		if (Tuser == NULL)	
+		if (Tuser == NULL)
 			free(Tuser);
-		if (Tpretranspose == NULL)	
+		if (Tpretranspose == NULL)
 			free(Tpretranspose);
-		if (Tscale == NULL)	
+		if (Tscale == NULL)
 			free(Tscale);
-		if (Tposttranspose == NULL)	
+		if (Tposttranspose == NULL)
 			free(Tposttranspose);
 		return False;
 	}
