@@ -128,9 +128,9 @@ static XrmOptionDescRec opts[] =
 };
 static argtype vars[] =
 {
-	{(caddr_t *) & faces, (char *) "faces", (char *) "Faces", (char *) DEF_FACES, t_Bool},
-	{(caddr_t *) & edges, (char *) "edges", (char *) "Edges", (char *) DEF_EDGES, t_Bool},
-	{(caddr_t *) & opaque, (char *) "opaque", (char *) "Opaque", (char *) DEF_OPAQUE, t_Bool}
+	{(void *) & faces, (char *) "faces", (char *) "Faces", (char *) DEF_FACES, t_Bool},
+	{(void *) & edges, (char *) "edges", (char *) "Edges", (char *) DEF_EDGES, t_Bool},
+	{(void *) & opaque, (char *) "opaque", (char *) "Opaque", (char *) DEF_OPAQUE, t_Bool}
 };
 static OptionStruct desc[] =
 {
