@@ -27,6 +27,8 @@ static const char sccsid[] = "@(#)ifs.c	5.00 2000/11/01 xlockmore";
  * When shown ifs, Diana Rose (4 years old) said, "It looks like dancing."
  *
  * Revision History:
+ * 22-Dec-2004: TDA: Replace Gauss_Rand with a real Gaussian.  Fix
+ *              glitches where x=0 or y=0.
  * 01-Nov-2000: Allocation checks
  * 10-May-1997: jwz@jwz.org: turned into a standalone program.
  *              Made it render into an offscreen bitmap and then copy
@@ -114,7 +116,7 @@ static int  Cur_Pt;
 
 
 /*****************************************************/
-
+#if 0
 static      DBL
 Gauss_Rand(DBL c, DBL A, DBL S)
 {
@@ -137,6 +139,63 @@ Half_Gauss_Rand(DBL c, DBL A, DBL S)
 	return (c + y);
 }
 
+#else
+/* I don't know that it makes a difference, but these actually *are*
+   Gaussians.  [TDA] */
+
+/* Generate Gaussian random number: mean c, "amplitude" A (actually
+   A is 3*standard deviation).  'S' is unused.  */
+
+/* Note this generates a pair of gaussian variables, so it saves one
+   to give out next time it's called */
+
+static double
+Gauss_Rand(DBL c, DBL A, DBL S)
+{
+	static double d;
+	static Bool ready = 0;
+	if(ready) {
+		ready = 0;
+		return c + A/3 * d;
+	} else {
+		double x, y, w;
+		do {
+			x = 2.0 * (double)LRAND() / MAXRAND - 1.0;
+			y = 2.0 * (double)LRAND() / MAXRAND - 1.0;
+			w = x*x + y*y;
+		} while(w >= 1.0);
+
+		w = sqrt((-2 * log(w))/w);
+		ready = 1;
+		d =          x * w;
+		return c + A/3 * y * w;
+	}
+}
+
+static double
+Half_Gauss_Rand(DBL c, DBL A, DBL S)
+{
+	static double d;
+	static Bool ready = 0;
+	if(ready) {
+		ready = 0;
+		return c + A/3 * d;
+	} else {
+		double x, y, w;
+		do {
+			x = (double)LRAND() / MAXRAND;
+			y = (double)LRAND() / MAXRAND;
+			w = x*x + y*y;
+		} while(w >= 1.0);
+
+		w = sqrt((-2 * log(w))/w);
+		ready = 1;
+		d =          x * w;
+		return c + A/3 * y * w;
+	}
+}
+#endif
+
 static void
 Random_Simis(FRACTAL * F, SIMI * Cur, int i)
 {
@@ -331,8 +390,8 @@ Trace(FRACTAL * F, F_PT xo, F_PT yo)
 	Cur = Cur_F->Components;
 	for (i = Cur_F->Nb_Simi; i; --i, Cur++) {
 		Transform(Cur, xo, yo, &x, &y);
-		Buf->x = F->Lx + (x * F->Lx / (UNIT * 2));
-		Buf->y = F->Ly - (y * F->Ly / (UNIT * 2));
+		Buf->x = F->Lx + ((double)x * F->Lx / (UNIT * 2));
+		Buf->y = F->Ly - ((double)y * F->Ly / (UNIT * 2));
 		Buf++;
 		Cur_Pt++;
 
