@@ -75,7 +75,7 @@ static XrmOptionDescRec opts[] =
 
 static argtype vars[] =
 {
-        {(caddr_t *) & trackmouse, (char *) "trackmouse", (char *) "TrackMouse", (char *) DEF_TRACKMOUSE, t_Bool}
+        {(void *) & trackmouse, (char *) "trackmouse", (char *) "TrackMouse", (char *) DEF_TRACKMOUSE, t_Bool}
 };
 
 static OptionStruct desc[] =
@@ -232,6 +232,8 @@ init_julia(ModeInfo * mi)
 	jp->depth = MI_COUNT(mi);
 	if (jp->depth > 10)
 		jp->depth = 10;
+	if (jp->depth < 7)
+		jp->depth = 7;
 
 	if (trackmouse && !jp->cursor) {	/* Create an invisible cursor */
 		Pixmap      bit;
@@ -247,7 +249,7 @@ init_julia(ModeInfo * mi)
 			free_julia(display, jp);
 			return;
 		}
-			
+
 		if ((jp->cursor = XCreatePixmapCursor(display, bit, bit,
 				 &black, &black, 0, 0)) == None) {
 			XFreePixmap(display, bit);
