@@ -117,6 +117,8 @@ static const char sccsid[] = "@(#)life.c	5.07 2003/02/27 xlockmore";
     -neighbors 6 -rule S2b34/B2a     <CALLAHAN>
     -neighbors 6 -rule S2a2b4a/B2b3a4b  <ANDREEN>
     -neighbors 12 -rule S34/B45  <TRILIFE, BAYS>
+    -neighbors 12 -rule S45/B456  <TRILIFE1, BAYS>
+    -neighbors 12 -rule S23/B45  <TRILIFE2, BAYS>
 */
 
 #ifdef STANDALONE
@@ -143,10 +145,17 @@ static const char sccsid[] = "@(#)life.c	5.07 2003/02/27 xlockmore";
 #include "automata.h"
 
 #ifdef MODE_life
-
+#define LIFE_NAMES 1
 #include "life.h"
 
+#ifdef LIFE_NAMES
+#define DEF_LABEL "True"
+#define FONT_HEIGHT 19
+#define FONT_WIDTH 15
+#define FONT_LENGTH 20
+#endif
 #define DEF_NEIGHBORS  "0"      /* choose best value (8) */
+#define DEF_SERIAL "False"
 
 #if 1
 #define DEF_RULE  "G"   /* All rules with known gliders */
@@ -158,28 +167,48 @@ static const char sccsid[] = "@(#)life.c	5.07 2003/02/27 xlockmore";
 #define DEF_RULE  "S2b34/B2a"   /* CALLAHAN */
 #define DEF_RULE  "S2a2b4a/B2b3a4b"     /* ANDREEN */
 #define DEF_RULE  "S34/B45"     /* TRILIFE */
+#define DEF_RULE  "S45/B456"    /* TRILIFE1 */
+#define DEF_RULE  "S23/B45"     /* TRILIFE2 */
 #endif
 
-#define DEF_HIGHLIFE  "FALSE"
-#define DEF_DAY_NIGHT  "FALSE"
-#define DEF_CALLAHAN  "FALSE"
-#define DEF_ANDREEN  "FALSE"
-#define DEF_TRILIFE  "FALSE"
+#define DEF_CONWAY  "False"
+#define DEF_HIGHLIFE  "False"
+#define DEF_DAY_NIGHT  "False"
+#define DEF_CALLAHAN  "False"
+#define DEF_ANDREEN  "False"
+#define DEF_TRILIFE  "False"
+#define DEF_TRILIFE1  "False"
+#define DEF_TRILIFE2  "False"
 
 static int  neighbors;
 static char *rule;
 static char *lifefile;
+#ifdef LIFE_NAMES
+static Bool label;
+#endif
+static Bool serial;
+static Bool conway;
 static Bool highlife;
 static Bool daynight;
 static Bool callahan;
 static Bool andreen;
 static Bool trilife;
+static Bool trilife1;
+static Bool trilife2;
 
 static XrmOptionDescRec opts[] =
 {
+#ifdef LIFE_NAMES
+	{(char *) "-label", (char *) ".life.label", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+label", (char *) ".life.label", XrmoptionNoArg, (caddr_t) "off"},
+#endif
 	{(char *) "-neighbors", (char *) ".life.neighbors", XrmoptionSepArg, (caddr_t) NULL},
 	{(char *) "-rule", (char *) ".life.rule", XrmoptionSepArg, (caddr_t) NULL},
 	{(char *) "-lifefile", (char *) ".life.lifefile", XrmoptionSepArg, (caddr_t) NULL},
+	{(char *) "-serial", (char *) ".life.serial", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+serial", (char *) ".life.serial", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "-conway", (char *) ".life.conway", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+conway", (char *) ".life.conway", XrmoptionNoArg, (caddr_t) "off"},
 	{(char *) "-highlife", (char *) ".life.highlife", XrmoptionNoArg, (caddr_t) "on"},
 	{(char *) "+highlife", (char *) ".life.highlife", XrmoptionNoArg, (caddr_t) "off"},
 	{(char *) "-daynight", (char *) ".life.daynight", XrmoptionNoArg, (caddr_t) "on"},
@@ -189,29 +218,47 @@ static XrmOptionDescRec opts[] =
 	{(char *) "-andreen", (char *) ".life.andreen", XrmoptionNoArg, (caddr_t) "on"},
 	{(char *) "+andreen", (char *) ".life.andreen", XrmoptionNoArg, (caddr_t) "off"},
 	{(char *) "-trilife", (char *) ".life.trilife", XrmoptionNoArg, (caddr_t) "on"},
-	{(char *) "+trilife", (char *) ".life.trilife", XrmoptionNoArg, (caddr_t) "off"}
+	{(char *) "+trilife", (char *) ".life.trilife", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "-trilife1", (char *) ".life.trilife1", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+trilife1", (char *) ".life.trilife1", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "-trilife2", (char *) ".life.trilife2", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+trilife2", (char *) ".life.trilife2", XrmoptionNoArg, (caddr_t) "off"}
 };
 static argtype vars[] =
 {
-	{(caddr_t *) & neighbors, (char *) "neighbors", (char *) "Neighbors", (char *) DEF_NEIGHBORS, t_Int},
-	{(caddr_t *) & rule, (char *) "rule", (char *) "Rule", (char *) DEF_RULE, t_String},
-	{(caddr_t *) & lifefile, (char *) "lifefile", (char *) "LifeFile", (char *) "", t_String},
-  {(caddr_t *) & highlife, (char *) "highlife", (char *) "HighLife", (char *) DEF_HIGHLIFE, t_Bool},
-  {(caddr_t *) & daynight, (char *) "daynight", (char *) "DayNight", (char *) DEF_DAY_NIGHT, t_Bool},
-  {(caddr_t *) & callahan, (char *) "callahan", (char *) "Callahan", (char *) DEF_CALLAHAN, t_Bool},
-	{(caddr_t *) & andreen, (char *) "andreen", (char *) "Andreen", (char *) DEF_ANDREEN, t_Bool},
-  {(caddr_t *) & trilife, (char *) "trilife", (char *) "TriLife", (char *) DEF_TRILIFE, t_Bool},
+#ifdef LIFE_NAMES
+	{(void *) & label, (char *) "label", (char *) "Label", (char *) DEF_LABEL, t_Bool},
+#endif
+	{(void *) & neighbors, (char *) "neighbors", (char *) "Neighbors", (char *) DEF_NEIGHBORS, t_Int},
+	{(void *) & rule, (char *) "rule", (char *) "Rule", (char *) DEF_RULE, t_String},
+	{(void *) & lifefile, (char *) "lifefile", (char *) "LifeFile", (char *) "", t_String},
+	{(void *) & serial, (char *) "serial", (char *) "Serial", (char *) DEF_SERIAL, t_Bool},
+	{(void *) & conway, (char *) "conway", (char *) "Conway", (char *) DEF_CONWAY, t_Bool},
+	{(void *) & highlife, (char *) "highlife", (char *) "HighLife", (char *) DEF_HIGHLIFE, t_Bool},
+	{(void *) & daynight, (char *) "daynight", (char *) "DayNight", (char *) DEF_DAY_NIGHT, t_Bool},
+	{(void *) & callahan, (char *) "callahan", (char *) "Callahan", (char *) DEF_CALLAHAN, t_Bool},
+	{(void *) & andreen, (char *) "andreen", (char *) "Andreen", (char *) DEF_ANDREEN, t_Bool},
+	{(void *) & trilife, (char *) "trilife", (char *) "TriLife", (char *) DEF_TRILIFE, t_Bool},
+	{(void *) & trilife1, (char *) "trilife1", (char *) "TriLife1", (char *) DEF_TRILIFE1, t_Bool},
+	{(void *) & trilife2, (char *) "trilife2", (char *) "TriLife2", (char *) DEF_TRILIFE2, t_Bool}
 };
 static OptionStruct desc[] =
 {
+#ifdef LIFE_NAMES
+	{(char *) "-/+label", (char *) "turn on/off name labeling"},
+#endif
 	{(char *) "-neighbors num", (char *) "squares 4 or 8, hexagons 6, triangles 3, 9 or 12"},
 	{(char *) "-rule string", (char *) "S<survival_neighborhood>/B<birth_neighborhood> parameters"},
 	{(char *) "-lifefile file", (char *) "life file"},
+	{(char *) "-/+serial", (char *) "turn on/off picking of sequential patterns"},
+	{(char *) "-/+conway", (char *) "turn on/off Conway's original Life rule B3/S23"},
 	{(char *) "-/+highlife", (char *) "turn on/off Bell's HighLife rule B36/S23"},
 	{(char *) "-/+daynight", (char *) "turn on/off Thompson's Day and Night rule B3678/S34678"},
 	{(char *) "-/+callahan", (char *) "turn on/off Callahan's hex rule B2a/S2b34"},
-	{(char *) "-/+andreen", (char *) "turn on/off Andreen's hex rule B2a3a4b/S2a2m4a"},
-	{(char *) "-/+trilife", (char *) "turn on/off Bay's tri rule B45/S34"}
+	{(char *) "-/+andreen", (char *) "turn on/off Andreen's hex rule B2a3a4b/S2a2b4a"},
+	{(char *) "-/+trilife", (char *) "turn on/off Bay's tri rule B45/S34"},
+	{(char *) "-/+trilife1", (char *) "turn on/off Bay's tri rule B456/S45"},
+	{(char *) "-/+trilife2", (char *) "turn on/off Bay's tri rule B45/S23"}
 };
 
 ModeSpecOpt life_opts =
@@ -305,10 +352,12 @@ typedef struct {
 	int         graphics_format;
 	GC          backGC;
 	int neighbors;
-	int highlife, daynight, callahan, andreen, trilife, trilife1, trilife2;
+	int conway, highlife, daynight, callahan, andreen;
+	int trilife, trilife1, trilife2;
 	int allPatterns, allGliders;
 	paramstruct input_param;
-
+	int         labelOffsetX, labelOffsetY;
+	char        ruleString[80], nameString[80];
 } lifestruct;
 
 static lifestruct *lifes = (lifestruct *) NULL;
@@ -378,7 +427,7 @@ codeToPatternedRule(int local_neighbors, paramstruct param)
 				}
 			return LIFE_8RULES;
 		case 12:
-			for (i = 0; i < LIFE_8RULES; i++)
+			for (i = 0; i < LIFE_12RULES; i++)
 				if (param_12rules[i].survival == param.survival &&
 				    param_12rules[i].birth == param.birth) {
 					for (g = 0; g < maxgroups[neighbor_kind]; g++) {
@@ -398,7 +447,8 @@ codeToPatternedRule(int local_neighbors, paramstruct param)
 }
 
 static void
-copyFromPatternedRule(int local_neighbors,  paramstruct * param, int patterned_rule)
+copyFromPatternedRule(int local_neighbors, paramstruct * param,
+		int patterned_rule)
 {
 	int         i, neighbor_kind;
 
@@ -438,33 +488,49 @@ copyFromPatternedRule(int local_neighbors,  paramstruct * param, int patterned_r
 }
 
 static void
-printRule(int local_neighbors, paramstruct param)
+printRule(int local_neighbors, char * string, paramstruct param, Bool verbose)
 {
-	int         l, g, neighbor_kind;
+	int         i = 1, l, g, neighbor_kind;
 	Bool        found;
 
-	(void) fprintf(stdout, "rule (Survival/Birth neighborhood): S");
+	string[0] = 'S';
+	if (verbose)
+		(void) fprintf(stdout, "rule (Survival/Birth neighborhood): ");
 	neighbor_kind = invplot(local_neighbors);
-	for (l = 0; l <= local_neighbors; l++) {
-		if (param.survival & (1 << l))
-			(void) fprintf(stdout, "%d", l);
-		else if (l >= FIRSTGROUP && l < FIRSTGROUP + maxgroups[neighbor_kind])
+	for (l = 0; l <= local_neighbors && l < 10; l++) {
+		if (param.survival & (1 << l)) {
+			(void) sprintf(&(string[i]), "%d", l);
+			i++;
+		} else if (l >= FIRSTGROUP && l < FIRSTGROUP + maxgroups[neighbor_kind]) {
 			for (g = 0; g < groupnumber[neighbor_kind][l - FIRSTGROUP]; g++) {
-				if (param.survival_group[l - FIRSTGROUP] & (1 << g))
-					(void) fprintf(stdout, "%d%c", l, 'a' + g);
-			}
-	} (void) fprintf(stdout, "/B");
-	for (l = 0; l <= local_neighbors; l++) {
-		if (param.birth & (1 << l))
-			(void) fprintf(stdout, "%d", l);
-		else if (l >= FIRSTGROUP && l < FIRSTGROUP + maxgroups[neighbor_kind])
-			for (g = 0; g < groupnumber[neighbor_kind][l - FIRSTGROUP]; g++) {
-				if (param.birth_group[l - FIRSTGROUP] & (1 << g))
-					(void) fprintf(stdout, "%d%c", l, 'a' + g);
+				if (param.survival_group[l - FIRSTGROUP] & (1 << g)) {
+					(void) sprintf(&(string[i]), "%d%c",
+						l, 'a' + g);
+					i += 2;
+				}
 			}
+		}
 	}
-	(void) fprintf(stdout, "\nbinary rule: Survival 0x%X, Birth 0x%X\n",
-		       param.survival, param.birth);
+	(void) sprintf(&(string[i]), "/B");
+	i += 2;
+	for (l = 0; l <= local_neighbors && l < 10; l++) {
+		if (param.birth & (1 << l)) {
+			(void) sprintf(&(string[i]), "%d", l);
+			i++;
+		} else if (l >= FIRSTGROUP && l < FIRSTGROUP + maxgroups[neighbor_kind]) {
+			for (g = 0; g < groupnumber[neighbor_kind][l - FIRSTGROUP]; g++) {
+				if (param.birth_group[l - FIRSTGROUP] & (1 << g)) {
+					(void) sprintf(&(string[i]), "%d%c",
+						l, 'a' + g);
+					i += 2;
+				}
+			}
+		}
+	}
+	string[i] = '\0';
+	if (verbose)
+	  (void) fprintf(stdout, "%s\nbinary rule: Survival 0x%X, Birth 0x%X\n",
+		       string, param.survival, param.birth);
 	found = False;
 	for (l = 0; l <= maxgroups[neighbor_kind]; l++) {
 		if (param.survival_group[l] || param.birth_group[l]) {
@@ -472,7 +538,7 @@ printRule(int local_neighbors, paramstruct param)
 			break;
 		}
 	}
-	if (found)
+	if (found && verbose)
 		for (l = 0; l < maxgroups[neighbor_kind]; l++) {
 			(void) fprintf(stdout,
 				       "groups in neighborhood %d: Survival 0x%X, Birth 0x%X\n",
@@ -485,38 +551,7 @@ position_of_neighbor(lifestruct * lp, int n, int col, int row)
 {
 	int         dir = n * 360 / lp->neighbors;
 
-	if (lp->neighbors == 6) {
-		switch (dir) {
-			case 0:
-				col = (col + 1 == lp->ncols) ? 0 : col + 1;
-				break;
-			case 60:
-				if (!(row & 1))
-					col = (col + 1 == lp->ncols) ? 0 : col + 1;
-				row = (!row) ? lp->nrows - 1 : row - 1;
-				break;
-			case 120:
-				if (row & 1)
-					col = (!col) ? lp->ncols - 1 : col - 1;
-				row = (!row) ? lp->nrows - 1 : row - 1;
-				break;
-			case 180:
-				col = (!col) ? lp->ncols - 1 : col - 1;
-				break;
-			case 240:
-				if (row & 1)
-					col = (!col) ? lp->ncols - 1 : col - 1;
-				row = (row + 1 == lp->nrows) ? 0 : row + 1;
-				break;
-			case 300:
-				if (!(row & 1))
-					col = (col + 1 == lp->ncols) ? 0 : col + 1;
-				row = (row + 1 == lp->nrows) ? 0 : row + 1;
-				break;
-			default:
-				(void) fprintf(stderr, "wrong direction %d\n", dir);
-		}
-	} else if (lp->neighbors == 4 || lp->neighbors == 8) {
+	if (lp->neighbors == 4 || lp->neighbors == 6 || lp->neighbors == 8) {
 		switch (dir) {
 			case 0:
 				col = (col + 1 == lp->ncols) ? 0 : col + 1;
@@ -525,9 +560,19 @@ position_of_neighbor(lifestruct * lp, int n, int col, int row)
 				col = (col + 1 == lp->ncols) ? 0 : col + 1;
 				row = (!row) ? lp->nrows - 1 : row - 1;
 				break;
+			case 60:
+				if (!(row & 1))
+					col = (col + 1 == lp->ncols) ? 0 : col + 1;
+				row = (!row) ? lp->nrows - 1 : row - 1;
+				break;
 			case 90:
 				row = (!row) ? lp->nrows - 1 : row - 1;
 				break;
+			case 120:
+				if (row & 1)
+					col = (!col) ? lp->ncols - 1 : col - 1;
+				row = (!row) ? lp->nrows - 1 : row - 1;
+				break;
 			case 135:
 				col = (!col) ? lp->ncols - 1 : col - 1;
 				row = (!row) ? lp->nrows - 1 : row - 1;
@@ -539,9 +584,19 @@ position_of_neighbor(lifestruct * lp, int n, int col, int row)
 				col = (!col) ? lp->ncols - 1 : col - 1;
 				row = (row + 1 == lp->nrows) ? 0 : row + 1;
 				break;
+			case 240:
+				if (row & 1)
+					col = (!col) ? lp->ncols - 1 : col - 1;
+				row = (row + 1 == lp->nrows) ? 0 : row + 1;
+				break;
 			case 270:
 				row = (row + 1 == lp->nrows) ? 0 : row + 1;
 				break;
+			case 300:
+				if (!(row & 1))
+					col = (col + 1 == lp->ncols) ? 0 : col + 1;
+				row = (row + 1 == lp->nrows) ? 0 : row + 1;
+				break;
 			case 315:
 				col = (col + 1 == lp->ncols) ? 0 : col + 1;
 				row = (row + 1 == lp->nrows) ? 0 : row + 1;
@@ -703,20 +758,32 @@ position_of_neighbor(lifestruct * lp, int n, int col, int row)
 }
 
 static void
-parseRule(ModeInfo * mi)
+parseRule(ModeInfo * mi, char * string)
 {
 	lifestruct *lp = &lifes[MI_SCREEN(mi)];
 	int         n, g = 0, l = 0, neighbor_kind;
 	char        serving = 0;
 	static Bool found = False;
 
-	if (found)
+	if (!found)
+		lp->input_param.survival = lp->input_param.birth = 0;
+	if (lp->input_param.survival || lp->input_param.birth)
 		return;
-	lp->input_param.survival = lp->input_param.birth = 0;
 	for (n = 0; n < MAXGROUPS; n++) {
 		lp->input_param.survival_group[n] = lp->input_param.birth_group[n] = 0;
 	}
-	if (lp->highlife) {
+	if (lp->conway) {
+		lp->neighbors = 8;
+		neighbor_kind = invplot(lp->neighbors);
+		found = !MI_IS_FULLRANDOM(mi);
+		lp->input_param.survival = param_8rules[0].survival;
+		lp->input_param.birth = param_8rules[0].birth;
+		for (n = 0; n < maxgroups[neighbor_kind]; n++) {
+			lp->input_param.survival_group[n] = param_8rules[0].survival_group[n];
+			lp->input_param.birth_group[n] = param_8rules[0].birth_group[n];
+		}
+		return;
+	} else if (lp->highlife) {
 		lp->neighbors = 8;
 		neighbor_kind = invplot(lp->neighbors);
 		found = !MI_IS_FULLRANDOM(mi);
@@ -781,6 +848,7 @@ parseRule(ModeInfo * mi)
 			lp->input_param.survival_group[n] = param_12rules[1].survival_group[n];
 			lp->input_param.birth_group[n] = param_12rules[1].birth_group[n];
 		}
+		return;
 	} else if (lp->trilife2) {
 		lp->neighbors = 12;
 		neighbor_kind = invplot(lp->neighbors);
@@ -791,26 +859,27 @@ parseRule(ModeInfo * mi)
 			lp->input_param.survival_group[n] = param_12rules[2].survival_group[n];
 			lp->input_param.birth_group[n] = param_12rules[2].birth_group[n];
 		}
+		return;
 	}
 	neighbor_kind = invplot(lp->neighbors);
-	if (rule && !MI_IS_FULLRANDOM(mi)) {
+	if (rule) {
 		n = 0;
 		while (rule[n]) {
-			if (rule[n] == 'P') {
+			if (rule[n] == 'P' || rule[n] == 'p') {
 				lp->allPatterns = True;
 				found = True;
 				if (MI_IS_VERBOSE(mi))
 					(void) fprintf(stdout, "rule: All rules with known patterns\n");
 				return;
-			} else if (rule[n] == 'G') {
+			} else if (rule[n] == 'G' || rule[n] == 'g') {
 				lp->allGliders = True;
 				found = True;
 				if (MI_IS_VERBOSE(mi))
 					(void) fprintf(stdout, "rule: All rules with known gliders\n");
 				return;
-			} else if (rule[n] == 'S' || rule[n] == 'E' || rule[n] == 'L') {
+			} else if (rule[n] == 'S' || rule[n] == 'E' || rule[n] == 'L' || rule[n] == 's' || rule[n] == 'e' || rule[n] == 'l') {
 				serving = 'S';
-			} else if (rule[n] == 'B') {
+			} else if (rule[n] == 'B' || rule[n] == 'b') {
 				serving = 'B';
 			} else {
 				l = rule[n] - '0';
@@ -818,18 +887,18 @@ parseRule(ModeInfo * mi)
 					g = rule[n + 1] - 'a';
 					if (l >= FIRSTGROUP && l < FIRSTGROUP + maxgroups[neighbor_kind] &&
 					    g >= 0 && g < groupnumber[neighbor_kind][l]) {	/* Groupings */
-						if (serving == 'S') {
+						if (serving == 'S' || rule[n] == 's') {
 							found = True;
 							lp->input_param.survival_group[l - FIRSTGROUP] |= (1 << g);
-						} else if (serving == 'B') {
+						} else if (serving == 'B' || rule[n] == 'b') {
 							found = True;
 							lp->input_param.birth_group[l - FIRSTGROUP] |= (1 << g);
 						}
 					} else {
-						if (serving == 'S') {
+						if (serving == 'S' || rule[n] == 's') {
 							found = True;
 							lp->input_param.survival |= (1 << l);
-						} else if (serving == 'B') {
+						} else if (serving == 'B' || rule[n] == 'b') {
 							found = True;
 							lp->input_param.birth |= (1 << l);
 						}
@@ -839,7 +908,8 @@ parseRule(ModeInfo * mi)
 			n++;
 		}
 	}
-	if (!found) {		/* Default to Conway's rule if very stupid */
+	if (!found || !(lp->input_param.survival || lp->input_param.birth)) {
+		/* Default to Conway's rule if rule does not make sense */
 		lp->allGliders = True;
 		found = !MI_IS_FULLRANDOM(mi);
 		if (MI_IS_VERBOSE(mi))
@@ -847,8 +917,7 @@ parseRule(ModeInfo * mi)
 			"rule: Defaulting to all rules with known gliders\n");
 		return;
 	}
-	if (MI_IS_VERBOSE(mi))
-		printRule(lp->neighbors, lp->input_param);
+	printRule(lp->neighbors, string, lp->input_param, MI_IS_VERBOSE(mi));
 }
 
 static void
@@ -1198,8 +1267,12 @@ setcell(ModeInfo * mi, int col, int row, int state)
 	cellstruct  info;
 	CellList   *curr, *currn;
 
-	if (col < 0 || row < 0 || col >= lp->ncols || row >= lp->nrows)
+	if (col < 0 || row < 0 || col >= lp->ncols || row >= lp->nrows) {
+#ifdef DEBUG
+		(void) printf("col %d, row %d outside grid\n", col, row);
+#endif
 		return True; /* Actually its a 3rd case */
+	}
 
 	position = row * lp->ncols + col;
 	curr = lp->arr[position];
@@ -1315,8 +1388,9 @@ RandomSoup(ModeInfo * mi, int n, int v)
 			if (NRAND(100) < n) {
 				SetList(col, row);
 			}
+	(void) strcpy(lp->nameString, "random pattern");
 	if (MI_IS_VERBOSE(mi))
-		(void) fprintf(stdout, "random pattern\n");
+		(void) fprintf(stdout, "%s\n", lp->nameString);
 }
 
 static void
@@ -1325,6 +1399,12 @@ GetPattern(ModeInfo * mi, int pattern_rule, int pattern)
 	lifestruct *lp = &lifes[MI_SCREEN(mi)];
 	int         row, col, orient, temp;
 	char       *patptr = (char *) NULL;
+#ifdef LIFE_NAMES
+	int pat = 2 * pattern + 1;
+	char * patstrg = (char *) "";
+#else
+	int pat = pattern;
+#endif
 
 	if (filePattern) {
 		patptr = &filePattern[0];
@@ -1333,46 +1413,84 @@ GetPattern(ModeInfo * mi, int pattern_rule, int pattern)
 			case 6:
 				switch (pattern_rule) {
 					case LIFE_6S2b34B2a:
-						patptr = &patterns_6S2b34B2a[pattern][0];
+						patptr = &patterns_6S2b34B2a[pat][0];
+#ifdef LIFE_NAMES
+						patstrg = &patterns_6S2b34B2a[2 * pattern][0];
+#endif
+
 						break;
 					case LIFE_6S2a2b4aB2a3a4b:
-						patptr = &patterns_6S2a2b4aB2a3a4b[pattern][0];
+						patptr = &patterns_6S2a2b4aB2a3a4b[pat][0];
+#ifdef LIFE_NAMES
+						patstrg = &patterns_6S2a2b4aB2a3a4b[2 * pattern][0];
+#endif
+
 						break;
 				}
 				break;
 			case 8:
 				switch (pattern_rule) {
 					case LIFE_8S23B3:
-						if (pattern < common_8size)
-						  patptr = &patterns_8S23B3_6[pattern][0];
-						else
-						  patptr = &patterns_8S23B3[pattern - common_8size][0];
+						if (pattern < (int) common_8size) {
+						  patptr = &patterns_8S23B3_6[pat][0];
+#ifdef LIFE_NAMES
+						  patstrg = &patterns_8S23B3_6[2 * pattern][0];
+#endif
+						} else {
+						  patptr = &patterns_8S23B3[pat - DIV * common_8size][0];
+#ifdef LIFE_NAMES
+						  patstrg = &patterns_8S23B3[2 * pattern - 2 * common_8size][0];
+#endif
+						}
 						break;
 					case LIFE_8S23B36:
-						if (pattern < common_8size)
-						  patptr = &patterns_8S23B3_6[pattern][0];
-						else
-						  patptr = &patterns_8S23B36[pattern - common_8size][0];
+						if (pattern < (int) common_8size) {
+						  patptr = &patterns_8S23B3_6[pat][0];
+#ifdef LIFE_NAMES
+						  patstrg = &patterns_8S23B3_6[2 * pattern][0];
+#endif
+						} else {
+						  patptr = &patterns_8S23B36[pat - DIV * common_8size][0];
+#ifdef LIFE_NAMES
+						  patstrg = &patterns_8S23B36[2 * pattern - 2 * common_8size][0];
+#endif
+						}
 						break;
 					case LIFE_8S34678B3678:
-						patptr = &patterns_8S34678B3678[pattern][0];
+						patptr = &patterns_8S34678B3678[pat][0];
+#ifdef LIFE_NAMES
+						patstrg = &patterns_8S34678B3678[2 * pattern][0];
+#endif
 						break;
 				}
 				break;
 			case 12:
 				switch (pattern_rule) {
 					case LIFE_12S34B45:
-						patptr = &patterns_12S34B45[pattern][0];
+						patptr = &patterns_12S34B45[pat][0];
+#ifdef LIFE_NAMES
+						patstrg = &patterns_12S34B45[2 * pattern][0];
+#endif
 						break;
 					case LIFE_12S45B456:
-						patptr = &patterns_12S45B456[pattern][0];
+						patptr = &patterns_12S45B456[pat][0];
+#ifdef LIFE_NAMES
+						patstrg = &patterns_12S45B456[2 * pattern][0];
+#endif
 						break;
 					case LIFE_12S23B45:
-						patptr = &patterns_12S23B45[pattern][0];
+						patptr = &patterns_12S23B45[pat][0];
+#ifdef LIFE_NAMES
+						patstrg = &patterns_12S23B45[2 * pattern][0];
+#endif
 						break;
 				}
 				break;
 		}
+#ifdef LIFE_NAMES
+		(void) strcpy(lp->nameString, patstrg);
+#endif
+
 	}
 #ifdef DEBUG
 	orient = 0;
@@ -1383,6 +1501,12 @@ GetPattern(ModeInfo * mi, int pattern_rule, int pattern)
 		orient = NRAND(12);
 	}
 #endif
+	if (MI_IS_VERBOSE(mi) && !filePattern) {
+#ifdef LIFE_NAMES
+		(void) fprintf(stdout, "%s, ", patstrg);
+#endif
+		(void) fprintf(stdout, "table number %d\n", pattern);
+	}
 	while ((col = *patptr++) != 127) {
 		row = *patptr++;
 		if (lp->neighbors == 6) {
@@ -1478,12 +1602,10 @@ GetPattern(ModeInfo * mi, int pattern_rule, int pattern)
 		row += lp->nrows / 2;
 		if (lp->neighbors % 3 == 0 && lp->neighbors != 6 &&
 				(lp->nrows / 2 + lp->ncols / 2 + 1) % 2) {
-			row++;	
+			row++;
 		}
 		SetList(col, row);
 	}
-	if (MI_IS_VERBOSE(mi) && !filePattern)
-		(void) fprintf(stdout, "table number %d\n", pattern);
 }
 
 static void
@@ -1992,10 +2114,11 @@ init_life(ModeInfo * mi)
 		if  (lp->neighbors == 8) {
 			int n = NRAND(r8n2);
 
-			lp->highlife = (n >= r8n1 && n < r8n2);
-			lp->daynight = (n >= r8n2);
+			lp->conway = (n < patterns_8rules[0]);
+			lp->highlife = (n >= patterns_8rules[0] && n < r8n1);
+			lp->daynight = (n >= r8n1);
 		} else {
-	   		lp->highlife = lp->daynight = False;
+	   		lp->conway = lp->highlife = lp->daynight = False;
 		}
 		if  (lp->neighbors == 6) {
 			lp->callahan = (NRAND(r6n1) < patterns_6rules[0]);
@@ -2006,20 +2129,21 @@ init_life(ModeInfo * mi)
 		if  (lp->neighbors == 12) {
 			int n = NRAND(r12n2);
 
-			lp->trilife = (n < r12n1);
-			lp->trilife1 = (n >= r12n1 && n < r12n2);
-			lp->trilife2 = (n >= r12n2);
+			lp->trilife = (n < patterns_12rules[0]);
+			lp->trilife1 = (n >= patterns_12rules[0] && n < r12n1);
+			lp->trilife2 = (n >= r12n1);
 		} else {
 	   		lp->trilife = lp->trilife1 = lp->trilife2 = False;
 		}
 	} else {
+	   	lp->conway = conway;
 	   	lp->highlife = highlife;
 	   	lp->daynight = daynight;
 	   	lp->callahan = callahan;
 	   	lp->andreen = andreen;
 	   	lp->trilife = trilife;
-	   	lp->trilife1 = False;
-	   	lp->trilife2 = False;
+	   	lp->trilife1 = trilife1;
+	   	lp->trilife2 = trilife2;
 	}
 	if (!lp->neighbors) {
 		for (i = 0; i < NEIGHBORKINDS; i++) {
@@ -2038,7 +2162,9 @@ init_life(ModeInfo * mi)
 			}
 		}
 	}
-	parseRule(mi);
+	lp->labelOffsetX = NRAND(8);
+	lp->labelOffsetY = NRAND(8);
+	parseRule(mi, lp->ruleString);
 	parseFile(mi);
 	if (lp->allPatterns) {
 		switch (lp->neighbors) {
@@ -2053,8 +2179,8 @@ init_life(ModeInfo * mi)
 				break;
 		}
 		copyFromPatternedRule(lp->neighbors, &lp->param, lp->patterned_rule);
-		if (MI_IS_VERBOSE(mi))
-			printRule(lp->neighbors, lp->param);
+		printRule(lp->neighbors, lp->ruleString, lp->param,
+			MI_IS_VERBOSE(mi));
 	} else if (lp->allGliders) {
 		switch (lp->neighbors) {
 			case 6:
@@ -2068,8 +2194,8 @@ init_life(ModeInfo * mi)
 				break;
 		}
 		copyFromPatternedRule(lp->neighbors, &lp->param, lp->patterned_rule);
-		if (MI_IS_VERBOSE(mi))
-			printRule(lp->neighbors, lp->param);
+		printRule(lp->neighbors, lp->ruleString, lp->param,
+			MI_IS_VERBOSE(mi));
 	} else {
 		lp->param.survival = lp->input_param.survival;
 		lp->param.birth = lp->input_param.birth;
@@ -2078,6 +2204,8 @@ init_life(ModeInfo * mi)
 			lp->param.birth_group[i] = lp->input_param.birth_group[i];
 		}
 		lp->patterned_rule = codeToPatternedRule(lp->neighbors, lp->param);
+		printRule(lp->neighbors, lp->ruleString, lp->param,
+			MI_IS_VERBOSE(mi));
 	}
 	lp->width = MI_WIDTH(mi);
 	lp->height = MI_HEIGHT(mi);
@@ -2241,6 +2369,9 @@ init_life(ModeInfo * mi)
 void
 draw_life(ModeInfo * mi)
 {
+	Display *display = MI_DISPLAY(mi);
+	Window window = MI_WINDOW(mi);
+	GC gc = MI_GC(mi);
 	CellList   *middle[STATES];	/* To distinguish between old and new stuff */
 	CellList   *curr;
 	cellstruct  info;
@@ -2378,9 +2509,27 @@ draw_life(ModeInfo * mi)
 	 * screen after batchcount.
 	 */
 
-	if (lp->generation && lp->generation %
-	    ((MI_COUNT(mi) < 0) ? 1 : MI_COUNT(mi)) == 0)
-		shooter(mi);
+	if (MI_COUNT(mi)) {
+		if (lp->generation && lp->generation %
+				((MI_COUNT(mi) < 0) ? 1 : MI_COUNT(mi)) == 0)
+			shooter(mi);
+	}
+	if (label) {
+                int size = MAX(MIN(MI_WIDTH(mi), MI_HEIGHT(mi)) - 1, 1);
+                if (size >= 10 * FONT_WIDTH) {
+                        /* hard code these to corners */
+                        XSetForeground(display, gc, MI_WHITE_PIXEL(mi));
+                        XDrawString(display, window, gc,
+                                16 + lp->labelOffsetX,
+                                16 + lp->labelOffsetY + FONT_HEIGHT,
+                                lp->ruleString, strlen(lp->ruleString));
+                        XDrawString(display, window, gc,
+                                16 + lp->labelOffsetX, MI_HEIGHT(mi) - 16 -
+                                lp->labelOffsetY - FONT_HEIGHT / 2,
+                                lp->nameString, strlen(lp->nameString));
+                }
+         }
+
 
 }
 
@@ -2487,9 +2636,10 @@ change_life(ModeInfo * mi)
 						lp->patterned_rule = 0;
 					break;
 			}
-			copyFromPatternedRule(lp->neighbors, &lp->param, lp->patterned_rule);
-			if (MI_IS_VERBOSE(mi))
-				printRule(lp->neighbors, lp->param);
+			copyFromPatternedRule(lp->neighbors, &lp->param,
+				lp->patterned_rule);
+			printRule(lp->neighbors, lp->ruleString, lp->param,
+				MI_IS_VERBOSE(mi));
 		} else if (lp->allGliders) {
 			lp->patterned_rule++;
 			switch (lp->neighbors) {
@@ -2507,10 +2657,12 @@ change_life(ModeInfo * mi)
 					break;
 			}
 			copyFromPatternedRule(lp->neighbors, &lp->param, lp->patterned_rule);
-			if (MI_IS_VERBOSE(mi))
-				printRule(lp->neighbors, lp->param);
+			printRule(lp->neighbors, lp->ruleString, lp->param,
+				MI_IS_VERBOSE(mi));
 		}
 	}
+	if (!serial)
+		lp->pattern = NRAND(npats + 2);
 	if (lp->pattern >= npats)
 		RandomSoup(mi, 30, MAX(2 * MIN(lp->nrows, lp->ncols) / 3, 15));
 	else
