@@ -79,7 +79,7 @@ static XrmOptionDescRec opts[] =
 };
 static argtype vars[] =
 {
-{(caddr_t *) & totalistic, (char *) "totalistic", (char *) "Totalistic", (char *) DEF_TOTALISTIC, t_Bool}
+	{(void *) & totalistic, (char *) "totalistic", (char *) "Totalistic", (char *) DEF_TOTALISTIC, t_Bool}
 };
 static OptionStruct desc[] =
 {
@@ -101,7 +101,7 @@ ModStruct   life1d_description =
 #define LIFE1DBITS(n,w,h)\
   if ((lp->pixmaps[lp->init_bits]=\
   XCreatePixmapFromBitmapData(display,window,(char *)n,w,h,1,0,1))==None){\
-  free_life1d(display,lp); return;} else {lp->init_bits++;} 
+  free_life1d(display,lp); return;} else {lp->init_bits++;}
 
 /* aliases for vars defined in the bitmap file */
 #define CELL_WIDTH   image_width
@@ -143,6 +143,7 @@ typedef struct {
 	unsigned char *newcells;
 	unsigned char *oldcells;
 	unsigned char *buffer;
+	unsigned char *previousBuffer;
 	XImage     *logo;
 	Colormap    cmap;
 	unsigned long black;
@@ -519,8 +520,6 @@ GetRule(life1dstruct * lp, int i)
 	}
 }
 
-/* The following sometimes does not detect when there are multiple periodic
-   life forms side by side. */
 static int
 compare(ModeInfo * mi)
 {
@@ -528,6 +527,8 @@ compare(ModeInfo * mi)
 	int         row, col, tryagain = False;
 	unsigned char *initl, *cmpr;
 
+        /* The following sometimes does not detect when there
+	   are multiple periodic life forms side by side. */
 	initl = lp->buffer + lp->row * lp->ncols;
 	for (row = lp->row - 1; row >= 0; row--) {
 		cmpr = lp->buffer + row * lp->ncols;
@@ -539,10 +540,30 @@ compare(ModeInfo * mi)
 			}
 			cmpr++;
 		}
-		if (!tryagain)
+		if (!tryagain) {
 			return True;
+		}
+	}
+        /* This is not guaranteed but its twice as good as without. */
+	if (lp->previousBuffer) {
+		initl = lp->buffer + lp->row * lp->ncols;
+		for (row = lp->nrows - 1; row >= 0; row--) {
+			cmpr = lp->previousBuffer + row * lp->ncols;
+			for (col = 0; col < lp->ncols; col++) {
+				tryagain = False;
+				if (*(initl + col) != *cmpr) {
+					tryagain = True;
+					break;
+				}
+				cmpr++;
+			}
+			if (!tryagain) {
+				return True;
+			}
+		}
 	}
 	return False;
+
 }
 
 static Bool
@@ -623,6 +644,10 @@ free_life1d(Display * display, life1dstruct * lp)
 		free(lp->buffer);
 		lp->buffer = (unsigned char *) NULL;
 	}
+	if (lp->previousBuffer != NULL) {
+		free(lp->previousBuffer);
+		lp->previousBuffer = (unsigned char *) NULL;
+	}
 	if (lp->nextstate != NULL) {
 		free(lp->nextstate);
 		lp->nextstate = (char *) NULL;
@@ -697,6 +722,9 @@ init_life1d(ModeInfo * mi)
 		free(lp->oldcells);
 	if (lp->buffer != NULL)
 		free(lp->buffer);
+	if (lp->previousBuffer != NULL)
+		free(lp->previousBuffer);
+	lp->previousBuffer = (unsigned char *) NULL;
 	lp->width = MI_WIDTH(mi);
 	lp->height = MI_HEIGHT(mi);
 	if (lp->width < 2)
@@ -735,8 +763,9 @@ init_life1d(ModeInfo * mi)
 		return;
 	}
 
-	if ((lp->oldcells = (unsigned char *) calloc(lp->ncols + 2 * (maxradius +
-			lp->border), sizeof (unsigned char))) == NULL) {
+	if ((lp->oldcells = (unsigned char *) calloc(lp->ncols + 2 *
+			(maxradius + lp->border),
+			sizeof (unsigned char))) == NULL) {
 		free_life1d(display, lp);
 		return;
 	}
@@ -802,6 +831,14 @@ draw_life1d(ModeInfo * mi)
 		lp->repeating = 0;
 		if (lp->screen_generation > MI_CYCLES(mi))
 			init_life1d(mi);
+		if (!lp->previousBuffer && lp->screen_generation > 1) {
+			lp->previousBuffer = (unsigned char *) calloc(lp->ncols *
+				lp->nrows, sizeof (unsigned char));
+		}
+		if (lp->previousBuffer) {
+			(void) memcpy((char *) (lp->previousBuffer),
+				(char *) (lp->buffer), lp->nrows * lp->ncols);
+		}
 
 		for (col = 0; col < lp->ncols; col++)
 			if (lp->buffer[col] != lp->newcells[col + lp->border])
