@@ -22,6 +22,8 @@ static const char sccsid[] = "@(#)life3d.c	5.07 2003/01/08 xlockmore";
  * other special, indirect and consequential damages.
  *
  * Revision History:
+ * 18-Apr-2004: Added shooting gliders for S567B6
+ * 13-Mar-2004: Added references
  * 28-Apr-2003: Randomized "rotation" of life form
  * 25-Jan-2003: Spawned a life3d.h
  * 19-Jan-2003: added more gliders from http://www.cse.sc.edu/~bays
@@ -41,7 +43,9 @@ static const char sccsid[] = "@(#)life3d.c	5.07 2003/01/08 xlockmore";
  *   Pages of Scientific American Magazine", W.H. Freedman and Company,
  *   New York, 1988 (February 1987 p 16)
  * Bays, Carter, "The Game of Three Dimensional Life", 86/11/20
- *   with (latest?) update from 87/2/1
+ *   with (latest?) update from 87/2/1 http://www.cse.sc.edu/~bays/
+ * Meeker, Lee Earl, "Four Dimensional Cellular Automata and the Game
+ *   of Life" 1998 http://home.sc.rr.com/lmeeker/Lee/Home.html
  */
 
 #ifdef STANDALONE
@@ -65,9 +69,17 @@ static const char sccsid[] = "@(#)life3d.c	5.07 2003/01/08 xlockmore";
 #include "iostuff.h"
 
 #ifdef MODE_life3d
-
+#define LIFE_NAMES 1
 #include "life3d.h"
 
+#ifdef LIFE_NAMES
+#define DEF_LABEL "True"
+#define FONT_HEIGHT 19
+#define FONT_WIDTH 15
+#define FONT_LENGTH 20
+#endif
+#define DEF_SERIAL "False"
+
 #if 1
 #define DEF_RULE  "G"		/* All rules with gliders */
 #else
@@ -82,21 +94,40 @@ static const char sccsid[] = "@(#)life3d.c	5.07 2003/01/08 xlockmore";
 
 static char *rule;
 static char *lifefile;
+#ifdef LIFE_NAMES
+static Bool label;
+#endif
+static Bool serial;
 
 static XrmOptionDescRec opts[] =
 {
+#ifdef LIFE_NAMES
+	{(char *) "-label", (char *) ".life3d.label", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+label", (char *) ".life3d.label", XrmoptionNoArg, (caddr_t) "off"},
+#endif
 	{(char *) "-rule", (char *) ".life3d.rule", XrmoptionSepArg, (caddr_t) NULL},
-	{(char *) "-lifefile", (char *) ".life3d.lifefile", XrmoptionSepArg, (caddr_t) NULL}
+	{(char *) "-lifefile", (char *) ".life3d.lifefile", XrmoptionSepArg, (caddr_t) NULL},
+	{(char *) "-serial", (char *) ".life3d.serial", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+serial", (char *) ".life3d.serial", XrmoptionNoArg, (caddr_t) "off"}
 };
 static argtype vars[] =
 {
-	{(caddr_t *) & rule, (char *) "rule", (char *) "Rule", (char *) DEF_RULE, t_String},
-	{(caddr_t *) & lifefile, (char *) "lifefile", (char *) "LifeFile", (char *) "", t_String}
+#ifdef LIFE_NAMES
+	{(void *) & label, (char *) "label", (char *) "Label", (char *) DEF_LABEL, t_Bool},
+#endif
+	{(void *) & rule, (char *) "rule", (char *) "Rule", (char *) DEF_RULE, t_String},
+	{(void *) & lifefile, (char *) "lifefile", (char *) "LifeFile", (char *) "", t_String},
+	{(void *) & serial, (char *) "serial", (char *) "Serial", (char *) DEF_SERIAL, t_Bool}
+
 };
 static OptionStruct desc[] =
 {
+#ifdef LIFE_NAMES
+	{(char *) "-/+label", (char *) "turn on/off name labeling"},
+#endif
 	{(char *) "-rule string", (char *) "S<survial_neighborhood>/B<birth_neighborhood> parameters"},
 	{(char *) "-lifefile file", (char *) "life file"},
+	{(char *) "-/+serial", (char *) "turn on/off picking of sequential patterns"}
 };
 
 ModeSpecOpt life3d_opts =
@@ -128,7 +159,7 @@ ModStruct   life3d_description =
 #define Reset3D(x,y,z) SetMem(lp,(unsigned int)x,(unsigned int)y,(unsigned int)z,OFF)
 
 #define SetList3D(x,y,z) if (!SetMem(lp,(unsigned int)x,(unsigned int)y,(unsigned int)z,ON)) return False; \
-if (!AddToList(lp,(unsigned int)x,(unsigned int)y,(unsigned int)z)) return False;
+if (!AddToList(lp,(unsigned int)x,(unsigned int)y,(unsigned int)z)) return False
 
 #define CellState3D(c) ((c)&ON)
 #define CellNbrs3D(c) ((c)&0x1f)	/* 26 <= 31 */
@@ -139,16 +170,15 @@ if (!AddToList(lp,(unsigned int)x,(unsigned int)y,(unsigned int)z)) return False
 #define NBUCKETS ((MAXCOLUMNS+MAXROWS+MAXSTACKS)*BUCKETSIZE)
 #define Distance(x1,y1,z1,x2,y2,z2) sqrt((x1-x2)*(x1-x2)+(y1-y2)*(y1-y2)+(z1-z2)*(z1-z2))
 
-#define IP 0.0174533
+#define IP (M_PI / 180.0)
 
 #define COLORBASE 3
 #define COLORS (COLORBASE + 2)
-#define COLORSTEP (MI_NPIXELS(mi)/COLORBASE)	/* 21 different colors per side */
 
 #define BLACK 0
-#define RED 1
+#define RED   1
 #define GREEN 2
-#define BLUE 3
+#define BLUE  3
 #define WHITE 4
 
 typedef struct _CellList {
@@ -167,20 +197,22 @@ typedef struct {
 	int         ox, oy, oz;	/* origin */
 	double      vx, vy, vz;	/* viewpoint */
 	int         generation;
-	int         nstacks, nrows, ncolumns;
+	int         ncolumns, nrows, nstacks;
 	int         memstart;
 	char        visible;
 	int         noChangeCount;
 	unsigned char *base[BASESIZE];
 	double      A, B, C, F;
 	int         width, height;
-	unsigned long color[COLORS];
-	int         alt, azm;
-	double      dist;
+	unsigned long colors[COLORS];
+	double      azm;
+	double      metaAlt, metaAzm, metaDist;
 	CellList   *ptrhead, *ptrend, eraserhead, eraserend;
-	CellList   *buckethead[NBUCKETS], *bucketend[NBUCKETS];		/* comfortable upper b */
+	CellList   *buckethead[NBUCKETS], *bucketend[NBUCKETS];
 	Bool        wireframe;
 	Pixmap      dbuf;
+	int         labelOffsetX, labelOffsetY;
+	char        ruleString[80], nameString[80];
 } life3dstruct;
 
 static life3dstruct *life3ds = (life3dstruct *) NULL;
@@ -209,22 +241,32 @@ copyFromPatternedRule(paramstruct * param, int patterned_rule)
 }
 
 static void
-printRule(paramstruct param)
+printRule(char * string, paramstruct param, Bool verbose)
 {
-	int         l;
+	int         i = 1, l;
 
-	(void) fprintf(stdout, "rule (Survival/Birth neighborhood): S");
-	for (l = 0; l <= MAXNEIGHBORS; l++) {
-		if (param.survival & (1 << l))
-			(void) fprintf(stdout, "%d", l);
+	string[0] = 'S';
+	if (verbose)
+		(void) fprintf(stdout, "rule (Survival/Birth neighborhood): ");
+	for (l = 0; l <= MAXNEIGHBORS && l < 10; l++) {
+
+		if (param.survival & (1 << l)) {
+			(void) sprintf(&(string[i]), "%d", l);
+			i++;
+		}
 	}
-	(void) fprintf(stdout, "/B");
-	for (l = 0; l <= MAXNEIGHBORS; l++) {
-		if (param.birth & (1 << l))
-			(void) fprintf(stdout, "%d", l);
+	(void) sprintf(&(string[i]), "/B");
+	i += 2;
+	for (l = 0; l <= MAXNEIGHBORS && l < 10; l++) {
+		if (param.birth & (1 << l)) {
+			(void) sprintf(&(string[i]), "%d", l);
+			i++;
+		}
 	}
-	(void) fprintf(stdout, "\nbinary rule: Survival 0x%X, Birth 0x%X\n",
-		       param.survival, param.birth);
+	string[i] = '\0';
+	if (verbose)
+	  (void) fprintf(stdout, "%s\nbinary rule: Survival 0x%X, Birth 0x%X\n",
+		       string, param.survival, param.birth);
 }
 
 /*-
@@ -232,7 +274,7 @@ printRule(paramstruct param)
  * these modes would be much good anyway....  death assumed.
  */
 static void
-parseRule(ModeInfo * mi)
+parseRule(ModeInfo * mi, char * string)
 {
 	int         n, l;
 	char        serving = 0;
@@ -240,34 +282,33 @@ parseRule(ModeInfo * mi)
 
 	if (found)
 		return;
-
 	input_param.survival = input_param.birth = 0;
 	if (rule) {
 		n = 0;
 		while (rule[n]) {
-			if (rule[n] == 'P') {
+			if (rule[n] == 'P' || rule[n] == 'p') {
 				allPatterns = True;
 				found = True;
 				if (MI_IS_VERBOSE(mi))
 					(void) fprintf(stdout, "rule: All rules with known patterns\n");
 				return;
-			} else if (rule[n] == 'G') {
+			} else if (rule[n] == 'G' || rule[n] == 'g') {
 				allGliders = True;
 				found = True;
 				if (MI_IS_VERBOSE(mi))
 					(void) fprintf(stdout, "rule: All rules with known gliders\n");
 				return;
-			} else if (rule[n] == 'S' || rule[n] == 'E' || rule[n] == 'L') {
+			} else if (rule[n] == 'S' || rule[n] == 'E' || rule[n] == 'L' || rule[n] == 's' || rule[n] == 'e' || rule[n] == 'l') {
 				serving = 'S';
-			} else if (rule[n] == 'B') {
+			} else if (rule[n] == 'B' || rule[n] == 'b') {
 				serving = 'B';
 			} else {
 				l = rule[n] - '0';
 				if (l >= 0 && l <= 9 /*&& l <= MAXNEIGHBORS */ ) {	/* no 10..27 */
-					if (serving == 'S') {
+					if (serving == 'S' || rule[n] == 's') {
 						found = True;
 						input_param.survival |= (1 << l);
-					} else if (serving == 'B') {
+					} else if (serving == 'B' || rule[n] == 'b') {
 						found = True;
 						input_param.birth |= (1 << l);
 					}
@@ -276,16 +317,16 @@ parseRule(ModeInfo * mi)
 			n++;
 		}
 	}
-	if (!found) {		/* Default to Bays' rules if very stupid */
+	if (!found || !(input_param.survival || input_param.birth)) {
+		/* Default to Bays' rules if rule does not make sense */
 		allGliders = True;
 		found = True;
 		if (MI_IS_VERBOSE(mi))
 			(void) fprintf(stdout,
-				       "rule: Defaulting to all rules with known gliders\n");
+				"rule: Defaulting to all rules with known gliders\n");
 		return;
 	}
-	if (MI_IS_VERBOSE(mi))
-		printRule(input_param);
+	printRule(string, input_param, MI_IS_VERBOSE(mi));
 }
 
 static void
@@ -336,7 +377,7 @@ parseFile(ModeInfo *mi)
 		(void) fclose(file);
 	}
 
-	while (c != EOF && x < 127 && y < 127 && i < 3 * size) {
+	while (c != EOF && x < 127 && y < 127 && z < 127 && i < 3 * size) {
 		if (c == '0' || c == 'O' || c == '*') {
 			filePattern[i++] = x++;
 			filePattern[i++] = y;
@@ -407,17 +448,17 @@ AddToEraseList(life3dstruct * lp, CellList * cell)
 static void
 DelFromList(life3dstruct * lp, CellList * cell)
 {
-	if (cell != lp->ptrhead)
+	if (cell != lp->ptrhead) {
 		cell->prev->next = cell->next;
-	else {
+	} else {
 		lp->ptrhead = cell->next;
 		if (lp->ptrhead != NULL)
 			lp->ptrhead->prev = (struct _CellList *) NULL;
 	}
 
-	if (cell != lp->ptrend)
+	if (cell != lp->ptrend) {
 		cell->next->prev = cell->prev;
-	else {
+	} else {
 		lp->ptrend = cell->prev;
 		if (lp->ptrend != NULL)
 			lp->ptrend->next = (struct _CellList *) NULL;
@@ -466,8 +507,9 @@ GetMem(life3dstruct * lp, unsigned int x, unsigned int y, unsigned int z,
 {
 	int         b, o;
 
-	if (lp->memstart)
+	if (lp->memstart) {
 		MemInit(lp);
+	}
 	BASE_OFFSET(x, y, z, b, o);
 	*m = lp->base[b][o];
 	return True;
@@ -479,8 +521,9 @@ SetMem(life3dstruct * lp,
 {
 	int         b, o;
 
-	if (lp->memstart)
+	if (lp->memstart) {
 		MemInit(lp);
+	}
 	BASE_OFFSET(x, y, z, b, o);
 	lp->base[b][o] = val;
 	return True;
@@ -488,12 +531,14 @@ SetMem(life3dstruct * lp,
 
 static Bool
 ChangeMem(life3dstruct * lp,
-	  unsigned int x, unsigned int y, unsigned int z, unsigned int val)
+		unsigned int x, unsigned int y, unsigned int z,
+		unsigned int val)
 {
 	int         b, o;
 
-	if (lp->memstart)
+	if (lp->memstart) {
 		MemInit(lp);
+	}
 	BASE_OFFSET(x, y, z, b, o);
 	lp->base[b][o] += val;
 	return True;
@@ -546,7 +591,7 @@ End3D(life3dstruct * lp)
 	CellList   *ptr;
 
 	while (lp->ptrhead != NULL) {
-		/* SetMem(lp, lp->ptrhead->x, lp->ptrhead->y, lp->ptrhead->z, OFF); */
+		/* Reset3D(lp->ptrhead->x, lp->ptrhead->y, lp->ptrhead->z); */
 		DelFromList(lp, lp->ptrhead);
 	}
 	ptr = lp->eraserhead.next;
@@ -601,6 +646,7 @@ RunLife3D(life3dstruct * lp)
 								} else {
 									if (!Reset3D(x, y, z))
 										return False;
+
 								}
 							}
 						}
@@ -611,7 +657,7 @@ RunLife3D(life3dstruct * lp)
 			if (!Set3D(xc, yc, zc))
 				return False;
 		} else {
-			if (!SetMem(lp, ptr->x, ptr->y, ptr->z, OFF))
+			if (!Reset3D(ptr->x, ptr->y, ptr->z))
 				return False;
 			DelFromList(lp, ptr);
 		}
@@ -648,7 +694,8 @@ DisplayList(life3dstruct * lp)
 
 	ptr = lp->ptrhead;
 	while (ptr != NULL) {
-		(void) printf("(%x)=[%d,%d,%d] ", (int) ptr, ptr->x, ptr->y, ptr->z);
+		(void) printf("(%x)=[%d,%d,%d] ", (int) ptr,
+			ptr->x, ptr->y, ptr->z);
 		ptr = ptr->next;
 		++count;
 	}
@@ -672,8 +719,9 @@ RandomSoup(ModeInfo * mi, int n, int v)
 				if (NRAND(100) < n) {
 					SetList3D(x, y, z);
 				}
+	(void) strcpy(lp->nameString, "random pattern");
 	if (MI_IS_VERBOSE(mi)) {
-		(void) fprintf(stdout, "random pattern\n");
+		(void) fprintf(stdout, "%s\n", lp->nameString);
 	}
 	return True;
 }
@@ -684,33 +732,63 @@ GetPattern(ModeInfo * mi, int pattern_rule, int pattern)
 	life3dstruct *lp = &life3ds[MI_SCREEN(mi)];
 	int         x, y, z, orient, temp;
 	char       *patptr = (char *) NULL;
+#ifdef LIFE_NAMES
+	int pat = 2 * pattern + 1;
+	char * patstrg = (char *) "";
+#else
+	int pat = pattern;
+#endif
 
 	if (filePattern) {
 		patptr = &filePattern[0];
 	} else {
 		switch (pattern_rule) {
 			case LIFE_S45B5:
-				patptr = &patterns_S45B5[pattern][0];
+				patptr = &patterns_S45B5[pat][0];
+#ifdef LIFE_NAMES
+				patstrg = &patterns_S45B5[2 * pattern][0];
+#endif
 				break;
 			case LIFE_S567B6:
-				patptr = &patterns_S567B6[pattern][0];
+				patptr = &patterns_S567B6[pat][0];
+#ifdef LIFE_NAMES
+				patstrg = &patterns_S567B6[2 * pattern][0];
+#endif
 				break;
 			case LIFE_S56B5:
-				patptr = &patterns_S56B5[pattern][0];
+				patptr = &patterns_S56B5[pat][0];
+#ifdef LIFE_NAMES
+				patstrg = &patterns_S56B5[2 * pattern][0];
+#endif
 				break;
 			case LIFE_S678B5:
-				patptr = &patterns_S678B5[pattern][0];
+				patptr = &patterns_S678B5[pat][0];
+#ifdef LIFE_NAMES
+				patstrg = &patterns_S678B5[2 * pattern][0];
+#endif
 				break;
 			case LIFE_S67B67:
-				patptr = &patterns_S67B67[pattern][0];
+				patptr = &patterns_S67B67[pat][0];
+#ifdef LIFE_NAMES
+				patstrg = &patterns_S67B67[2 * pattern][0];
+#endif
 				break;
 		}
+#ifdef LIFE_NAMES
+		(void) strcpy(lp->nameString, patstrg);
+#endif
 	}
 #ifdef DEBUG
 	orient = 0;
 #else
 	orient = NRAND(24);
 #endif
+	if (MI_IS_VERBOSE(mi) && !filePattern) {
+#ifdef LIFE_NAMES
+		(void) fprintf(stdout, "%s, ", patstrg);
+#endif
+		(void) fprintf(stdout, "table number %d\n", pattern);
+	}
 	while ((x = *patptr++) != 127) {
 		y = *patptr++;
 		z = *patptr++;
@@ -743,9 +821,6 @@ GetPattern(ModeInfo * mi, int pattern_rule, int pattern)
 			SetList3D(x, y, z);
 		}
 	}
-	if (MI_IS_VERBOSE(mi) && !filePattern) {
-		(void) fprintf(stdout, "table number %d\n", pattern);
-	}
 	return True;
 }
 
@@ -765,6 +840,45 @@ NewViewpoint(life3dstruct * lp, double x, double y, double z)
 	lp->F = k * k;
 }
 
+static void
+lissajous(life3dstruct * lp)
+{
+	double alt, azm, dist;
+
+	alt = 30.0 * sin(lp->metaAlt * IP) + 45.0;
+	lp->metaAlt += 1.123;
+	if (lp->metaAlt >= 360.0)
+		lp->metaAlt -= 360.0;
+	if (lp->metaAlt < 0.0)
+		lp->metaAlt += 360.0;
+	azm = 30.0 * sin(lp->metaAzm * IP) + 45.0;
+	lp->metaAzm += 0.987;
+	if (lp->metaAzm >= 360.0)
+		lp->metaAzm -= 360.0;
+	if (lp->metaAzm < 0.0)
+		lp->metaAzm += 360.0;
+	dist = 10.0 * sin(lp->metaDist * IP) + 50.0;
+	lp->metaDist += 1.0;
+	if (lp->metaDist >= 360.0)
+		lp->metaDist -= 360.0;
+	if (lp->metaDist < 0.0)
+		lp->metaDist += 360.0;
+#if 0
+	if (alt >= 90.0)
+		alt = 90.0;
+	else if (alt < -90.0)
+		alt = -90.0;
+#endif
+	lp->azm = azm;
+#ifdef DEBUG
+	(void) printf("dist %g, alt %g, azm %g\n", dist, alt, azm);
+#endif
+	lp->vx = (sin(azm * IP) * cos(alt * IP) * dist);
+	lp->vy = (cos(azm * IP) * cos(alt * IP) * dist);
+	lp->vz = (sin(alt * IP) * dist);
+	NewViewpoint(lp, lp->vx, lp->vy, lp->vz);
+}
+
 static void
 NewPoint(life3dstruct * lp, double x, double y, double z,
 	 register XPoint * cubepts)
@@ -773,13 +887,15 @@ NewPoint(life3dstruct * lp, double x, double y, double z,
 
 	p1 = x * lp->vx + y * lp->vy;
 	E = lp->B - p1 - z * lp->vz;
-	cubepts->x = (int) (lp->width / 2 - lp->A * (lp->vx * y - lp->vy * x) / E);
-	cubepts->y = (int) (lp->height / 2 - lp->C * (z * lp->F - lp->vz * p1) / E);
+	cubepts->x = (int) (lp->width / 2 -
+		lp->A * (lp->vx * y - lp->vy * x) / E);
+	cubepts->y = (int) (lp->height / 2 -
+		lp->C * (z * lp->F - lp->vz * p1) / E);
 }
 
 
-/* Chain together all cells that are at the same distance. These * cannot
-   mutually overlap. */
+/* Chain together all cells that are at the same distance.
+ * These cannot mutually overlap. */
 static void
 SortList(life3dstruct * lp)
 {
@@ -825,7 +941,7 @@ SortList(life3dstruct * lp)
 
 	/* Check for invisibility */
 	rsize = 0.47 * lp->width / ((double) HalfScreenD * 2);
-	i = lp->azm;
+	i = (int) lp->azm;
 	if (i < 0)
 		i = -i;
 	i = i % RT_ANGLE;
@@ -843,7 +959,6 @@ SortList(life3dstruct * lp)
 					y = (double) ptr->y - lp->oy;
 					z = (double) ptr->z - lp->oz;
 					NewPoint(lp, x, y, z, &point);
-
 					r = (int) (rsize * (double) EyeToScreen / (double) ptr->dist);
 					if (point.x + r >= 0 && point.y + r >= 0 &&
 					    point.x - r < lp->width && point.y - r < lp->height)
@@ -856,7 +971,7 @@ SortList(life3dstruct * lp)
 
 static void
 DrawFace(ModeInfo * mi, int color, XPoint * cubepts,
-	 int p1, int p2, int p3, int p4)
+		int p1, int p2, int p3, int p4)
 {
 	Display    *display = MI_DISPLAY(mi);
 	GC          gc = MI_GC(mi);
@@ -869,19 +984,16 @@ DrawFace(ModeInfo * mi, int color, XPoint * cubepts,
 	facepts[3] = cubepts[p4];
 	facepts[4] = cubepts[p1];
 
-	XSetForeground(display, gc, lp->color[color]);
-	if (lp->wireframe) {
-		/* no double buffering needed */
-		XDrawLines(display, MI_WINDOW(mi), gc,
-			facepts, 5, CoordModeOrigin);
-		return;
+	XSetForeground(display, gc, lp->colors[color]);
+	if (!lp->wireframe) {
+		XFillPolygon(display, lp->dbuf, gc, facepts, 4,
+			Convex, CoordModeOrigin);
+		if (color == BLACK || MI_NPIXELS(mi) <= 2) {
+			XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
+		} else {
+			XSetForeground(display, gc, MI_WHITE_PIXEL(mi));
+		}
 	}
-	XFillPolygon(display, lp->dbuf, gc, facepts, 4,
-		     Convex, CoordModeOrigin);
-	if (color == BLACK || MI_NPIXELS(mi) <= 2) {
-		XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
-	} else
-		XSetForeground(display, gc, MI_WHITE_PIXEL(mi));
 	XDrawLines(display, lp->dbuf, gc, facepts, 5, CoordModeOrigin);
 }
 
@@ -906,8 +1018,10 @@ DrawCube(ModeInfo * mi, CellList * cell)
 		for (dy = y - LEN; dy <= y + LEN2; dy += LEN2)
 			for (dx = x - LEN; dx <= x + LEN2; dx += LEN2) {
 				NewPoint(lp, dx, dy, dz, &cubepts[i]);
-				if (cubepts[i].x < 0 || cubepts[i].x >= lp->width ||
-				    cubepts[i].y < 0 || cubepts[i].y >= lp->height)
+				if (cubepts[i].x < 0 ||
+				    cubepts[i].x >= lp->width ||
+				    cubepts[i].y < 0 ||
+				    cubepts[i].y >= lp->height)
 					++out;
 				++i;
 			}
@@ -956,19 +1070,17 @@ static void
 DrawScreen(ModeInfo * mi)
 {
 	life3dstruct *lp = &life3ds[MI_SCREEN(mi)];
+	Display    *display = MI_DISPLAY(mi);
+	GC          gc = MI_GC(mi);
 	CellList   *ptr;
 	CellList   *eraserptr;
 	int         i;
-	Display    *display = MI_DISPLAY(mi);
-	GC          gc = MI_GC(mi);
 
 	SortList(lp);
 
-	if (!lp->wireframe) {
-		XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
-		XFillRectangle(display, lp->dbuf, gc, 0,0,
-			lp->width, lp->height);
-	}
+	XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
+	XFillRectangle(display, lp->dbuf, gc, 0, 0,
+		lp->width, lp->height);
 
 	/* Erase dead cubes */
 	eraserptr = lp->eraserhead.next;
@@ -989,11 +1101,26 @@ DrawScreen(ModeInfo * mi)
 			/* ++count; */
 		}
 	}
+	if (label) {
+		int size = MAX(MIN(MI_WIDTH(mi), MI_HEIGHT(mi)) - 1, 1);
+		if (size >= 10 * FONT_WIDTH) {
+			/* hard code these to corners */
+			XSetForeground(display, gc, MI_WHITE_PIXEL(mi));
+			XDrawString(display, lp->dbuf, gc,
+				16 + lp->labelOffsetX,
+				16 + lp->labelOffsetY + FONT_HEIGHT,
+				lp->ruleString, strlen(lp->ruleString));
+			XDrawString(display, lp->dbuf, gc,
+				16 + lp->labelOffsetX,
+				MI_HEIGHT(mi) - 16 -
+			       	lp->labelOffsetY - FONT_HEIGHT / 2,
+				lp->nameString, strlen(lp->nameString));
+		}
+         }
 	XFlush(display);
-	if (!lp->wireframe) {
-		XCopyArea(display, lp->dbuf, MI_WINDOW(mi), gc,
-			0, 0, lp->width, lp->height, 0, 0);
-	}
+	XCopyArea(display, lp->dbuf, MI_WINDOW(mi), gc,
+		0, 0, lp->width, lp->height, 0, 0);
+
 #if 0
 	{
 		int         count = 0, v = 0;
@@ -1021,7 +1148,6 @@ shooter(life3dstruct * lp)
 	r2 = lp->nrows / 2;
 	s2 = lp->nstacks / 2;
 	r = NRAND(3);
-r = 1;
 	if (!r) {
 		hsp = NRAND(V2) + c2 - V2 / 2;
 		vsp = (LRAND() & 1) ? r2 - V : r2 + V;
@@ -1069,6 +1195,19 @@ r = 1;
 			SetList3D(hsp + 1 * hoff, vsp + 1 * voff, asp + 4 * aoff);
 			SetList3D(hsp + 1 * hoff, vsp + 0 * voff, asp + 4 * aoff);
 			SetList3D(hsp + 0 * hoff, vsp + 1 * voff, asp + 4 * aoff);
+		} else if (lp->patterned_rule == LIFE_S678B5) {
+			SetList3D(hsp + 1 * hoff, vsp + 1 * voff, asp + 2 * aoff);
+			SetList3D(hsp + 2 * hoff, vsp + 1 * voff, asp + 2 * aoff);
+			SetList3D(hsp + 0 * hoff, vsp + 0 * voff, asp + 2 * aoff);
+			SetList3D(hsp + 1 * hoff, vsp + 0 * voff, asp + 2 * aoff);
+			SetList3D(hsp + 2 * hoff, vsp + 0 * voff, asp + 2 * aoff);
+			SetList3D(hsp + 3 * hoff, vsp + 0 * voff, asp + 2 * aoff);
+			SetList3D(hsp + 1 * hoff, vsp + 1 * voff, asp + 1 * aoff);
+			SetList3D(hsp + 2 * hoff, vsp + 1 * voff, asp + 1 * aoff);
+			SetList3D(hsp + 1 * hoff, vsp + 0 * voff, asp + 1 * aoff);
+			SetList3D(hsp + 2 * hoff, vsp + 0 * voff, asp + 1 * aoff);
+			SetList3D(hsp + 1 * hoff, vsp + 0 * voff, asp + 0 * aoff);
+			SetList3D(hsp + 2 * hoff, vsp + 0 * voff, asp + 0 * aoff);
 		}
 	} else if (r == 1) {
 		hsp = (LRAND() & 1) ? c2 - V : c2 + V;
@@ -1117,6 +1256,19 @@ r = 1;
 			SetList3D(hsp + 1 * hoff, vsp + 4 * voff, asp + 1 * aoff);
 			SetList3D(hsp + 0 * hoff, vsp + 4 * voff, asp + 1 * aoff);
 			SetList3D(hsp + 1 * hoff, vsp + 4 * voff, asp + 0 * aoff);
+		} else if (lp->patterned_rule == LIFE_S678B5) {
+			SetList3D(hsp + 1 * hoff, vsp + 2 * voff, asp + 1 * aoff);
+			SetList3D(hsp + 1 * hoff, vsp + 2 * voff, asp + 2 * aoff);
+			SetList3D(hsp + 0 * hoff, vsp + 2 * voff, asp + 0 * aoff);
+			SetList3D(hsp + 0 * hoff, vsp + 2 * voff, asp + 1 * aoff);
+			SetList3D(hsp + 0 * hoff, vsp + 2 * voff, asp + 2 * aoff);
+			SetList3D(hsp + 0 * hoff, vsp + 2 * voff, asp + 3 * aoff);
+			SetList3D(hsp + 1 * hoff, vsp + 1 * voff, asp + 1 * aoff);
+			SetList3D(hsp + 1 * hoff, vsp + 1 * voff, asp + 2 * aoff);
+			SetList3D(hsp + 0 * hoff, vsp + 1 * voff, asp + 1 * aoff);
+			SetList3D(hsp + 0 * hoff, vsp + 1 * voff, asp + 2 * aoff);
+			SetList3D(hsp + 0 * hoff, vsp + 0 * voff, asp + 1 * aoff);
+			SetList3D(hsp + 0 * hoff, vsp + 0 * voff, asp + 2 * aoff);
 		}
 	} else {
 		hsp = (LRAND() & 1) ? c2 - V : c2 + V;
@@ -1165,6 +1317,19 @@ r = 1;
 			SetList3D(hsp + 4 * hoff, vsp + 1 * voff, asp + 1 * aoff);
 			SetList3D(hsp + 4 * hoff, vsp + 1 * voff, asp + 0 * aoff);
 			SetList3D(hsp + 4 * hoff, vsp + 0 * voff, asp + 1 * aoff);
+		} else if (lp->patterned_rule == LIFE_S678B5) {
+			SetList3D(hsp + 2 * hoff, vsp + 1 * voff, asp + 1 * aoff);
+			SetList3D(hsp + 2 * hoff, vsp + 2 * voff, asp + 1 * aoff);
+			SetList3D(hsp + 2 * hoff, vsp + 0 * voff, asp + 0 * aoff);
+			SetList3D(hsp + 2 * hoff, vsp + 1 * voff, asp + 0 * aoff);
+			SetList3D(hsp + 2 * hoff, vsp + 2 * voff, asp + 0 * aoff);
+			SetList3D(hsp + 2 * hoff, vsp + 3 * voff, asp + 0 * aoff);
+			SetList3D(hsp + 1 * hoff, vsp + 1 * voff, asp + 1 * aoff);
+			SetList3D(hsp + 1 * hoff, vsp + 2 * voff, asp + 1 * aoff);
+			SetList3D(hsp + 1 * hoff, vsp + 1 * voff, asp + 0 * aoff);
+			SetList3D(hsp + 1 * hoff, vsp + 2 * voff, asp + 0 * aoff);
+			SetList3D(hsp + 0 * hoff, vsp + 1 * voff, asp + 0 * aoff);
+			SetList3D(hsp + 0 * hoff, vsp + 2 * voff, asp + 0 * aoff);
 		}
 	}
 	return True;
@@ -1184,39 +1349,39 @@ free_life3d(Display *display, life3dstruct *lp)
 void
 init_life3d(ModeInfo * mi)
 {
-	int         i, npats;
-	life3dstruct *lp;
 	Display *display = MI_DISPLAY(mi);
+	life3dstruct *lp;
+	int i, npats;
 
 	if (life3ds == NULL) {
 		if ((life3ds = (life3dstruct *) calloc(MI_NUM_SCREENS(mi),
-					     sizeof (life3dstruct))) == NULL)
+				sizeof (life3dstruct))) == NULL)
 			return;
 	}
 	lp = &life3ds[MI_SCREEN(mi)];
 
 	lp->generation = 0;
 
-	parseRule(mi);
+	lp->labelOffsetX = NRAND(8);
+	lp->labelOffsetY = NRAND(8);
+	parseRule(mi, lp->ruleString);
 	parseFile(mi);
 	if (allPatterns) {
 		lp->patterned_rule = NRAND(LIFE_RULES);
 		copyFromPatternedRule(&lp->param, lp->patterned_rule);
-		if (MI_IS_VERBOSE(mi))
-			printRule(lp->param);
+		printRule(lp->ruleString, lp->param, MI_IS_VERBOSE(mi));
 	} else if (allGliders) {
 		lp->patterned_rule = NRAND(LIFE_GLIDERS);
 		copyFromPatternedRule(&lp->param, lp->patterned_rule);
-		if (MI_IS_VERBOSE(mi))
-			printRule(lp->param);
+		printRule(lp->ruleString, lp->param, MI_IS_VERBOSE(mi));
 	} else {
 		lp->param.survival = input_param.survival;
 		lp->param.birth = input_param.birth;
 	}
-	if (lp->eraserhead.next == NULL) {
-		lp->dist = 50.0 /*30.0 */ ;
-		lp->alt = 20 /*30 */ ;
-		lp->azm = 10 /*30 */ ;
+	if (!lp->eraserhead.next) {
+		lp->metaDist = (double) NRAND(360);
+                lp->metaAlt = (double) NRAND(360);
+                lp->metaAzm = (double) NRAND(360);
 		lp->ncolumns = MAXCOLUMNS;
 		lp->nrows = MAXROWS;
 		lp->nstacks = MAXSTACKS;
@@ -1228,20 +1393,23 @@ init_life3d(ModeInfo * mi)
 	} else {
 		End3D(lp);
 	}
-	lp->color[0] = MI_BLACK_PIXEL(mi);
+	lp->colors[0] = MI_BLACK_PIXEL(mi);
 	if (MI_NPIXELS(mi) > 2) {
 		i = NRAND(3);
 
-		lp->color[i + 1] = MI_PIXEL(mi, NRAND(MI_NPIXELS(mi) / COLORBASE));
-		lp->color[(i + 1) % 3 + 1] = MI_PIXEL(mi,
-					  NRAND(MI_NPIXELS(mi) / COLORBASE) +
-						 MI_NPIXELS(mi) / COLORBASE);
-		lp->color[(i + 2) % 3 + 1] = MI_PIXEL(mi,
-					  NRAND(MI_NPIXELS(mi) / COLORBASE) +
-					     2 * MI_NPIXELS(mi) / COLORBASE);
-	} else
-		lp->color[1] = lp->color[2] = lp->color[3] = MI_WHITE_PIXEL(mi);
-	lp->color[4] = MI_WHITE_PIXEL(mi);
+		lp->colors[i + 1] = MI_PIXEL(mi,
+			NRAND(MI_NPIXELS(mi) / COLORBASE));
+		lp->colors[(i + 1) % 3 + 1] = MI_PIXEL(mi,
+			NRAND(MI_NPIXELS(mi) / COLORBASE) +
+			MI_NPIXELS(mi) / COLORBASE);
+		lp->colors[(i + 2) % 3 + 1] = MI_PIXEL(mi,
+			NRAND(MI_NPIXELS(mi) / COLORBASE) +
+			2 * MI_NPIXELS(mi) / COLORBASE);
+	} else {
+		lp->colors[1] = lp->colors[2] = lp->colors[3] =
+			MI_WHITE_PIXEL(mi);
+	}
+	lp->colors[4] = MI_WHITE_PIXEL(mi);
 	lp->width = MI_WIDTH(mi);
 	lp->height = MI_HEIGHT(mi);
 	lp->memstart = 1;
@@ -1257,15 +1425,7 @@ init_life3d(ModeInfo * mi)
 	MI_CLEARWINDOW(mi);
 	lp->painted = False;
 
-	if (lp->alt > 89)
-		lp->alt = 89;
-	else if (lp->alt < -89)
-		lp->alt = -89;
-	/* Calculate viewpoint */
-	lp->vx = (sin(lp->azm * IP) * cos(lp->alt * IP) * lp->dist);
-	lp->vy = (cos(lp->azm * IP) * cos(lp->alt * IP) * lp->dist);
-	lp->vz = (sin(lp->alt * IP) * lp->dist);
-	NewViewpoint(lp, lp->vx, lp->vy, lp->vz);
+	lissajous(lp);
 
 	lp->patterned_rule = codeToPatternedRule(lp->param);
 	if ((unsigned) lp->patterned_rule < LIFE_RULES)
@@ -1291,12 +1451,10 @@ init_life3d(ModeInfo * mi)
 		XFreePixmap(display, lp->dbuf);
 		lp->dbuf = None;
 	}
-	if (!lp->wireframe) {
-		if ((lp->dbuf = XCreatePixmap(display, MI_WINDOW(mi),
-			lp->width, lp->height, MI_DEPTH(mi))) == None) {
-			free_life3d(display, lp);
-			return;
-		}
+	if ((lp->dbuf = XCreatePixmap(display, MI_WINDOW(mi),
+		lp->width, lp->height, MI_DEPTH(mi))) == None) {
+		free_life3d(display, lp);
+		return;
 	}
 
 	DrawScreen(mi);
@@ -1318,6 +1476,7 @@ draw_life3d(ModeInfo * mi)
 			End3D(lp);
 		return;
 	}
+	lissajous(lp);
 	if (lp->visible) /* kill static life also */
 		DrawScreen(mi);
 
@@ -1334,12 +1493,14 @@ draw_life3d(ModeInfo * mi)
 	 * screen after batchcount.
 	 */
 
-	if (lp->generation && lp->generation %
-	    ((MI_COUNT(mi) < 0) ? 1 : MI_COUNT(mi)) == 0)
-		if (!shooter(lp)) {
-			if (lp->eraserhead.next != NULL)
-				End3D(lp);
-		}
+	if (MI_COUNT(mi)) {
+		if (lp->generation && lp->generation %
+				((MI_COUNT(mi) < 0) ? 1 : MI_COUNT(mi)) == 0)
+			if (!shooter(lp)) {
+				if (lp->eraserhead.next != NULL)
+					End3D(lp);
+			}
+	}
 }
 
 void
@@ -1400,17 +1561,17 @@ change_life3d(ModeInfo * mi)
 			if ((unsigned) lp->patterned_rule >= LIFE_RULES)
 				lp->patterned_rule = 0;
 			copyFromPatternedRule(&lp->param, lp->patterned_rule);
-			if (MI_IS_VERBOSE(mi))
-				printRule(lp->param);
+			printRule(lp->ruleString, lp->param, MI_IS_VERBOSE(mi));
 		} else if (allGliders) {
 			lp->patterned_rule++;
 			if (lp->patterned_rule >= LIFE_GLIDERS)
 				lp->patterned_rule = 0;
 			copyFromPatternedRule(&lp->param, lp->patterned_rule);
-			if (MI_IS_VERBOSE(mi))
-				printRule(lp->param);
+			printRule(lp->ruleString, lp->param, MI_IS_VERBOSE(mi));
 		}
 	}
+	if (!serial)
+		lp->pattern = NRAND(npats + 2);
 	if (lp->pattern >= npats) {
 		if (!RandomSoup(mi, 30, 10)) {
 			if (lp->eraserhead.next != NULL)
