@@ -2,7 +2,7 @@
 /* mandelbrot --- animated mandelbrot sets */
 
 #if !defined( lint ) && !defined( SABER )
-static const char sccsid[] = "@(#)mandelbrot.c	5.00 2000/11/01 xlockmore";
+static const char sccsid[] = "@(#)mandelbrot.c	5.09 2003/06/30 xlockmore";
 
 #endif
 
@@ -27,16 +27,19 @@ static const char sccsid[] = "@(#)mandelbrot.c	5.00 2000/11/01 xlockmore";
  * Magazine" Aug 1985 for more info.  Also A.K. Dewdney's "Computer
  * Recreations", Scientific American Magazine" Jul 1989, has some neat
  * extensions besides z^n + c (n small but >= 2) some of these are:
- *   z^z + z^n + c
+ *   z^z + z^n + c  <-- pow
+ *   sin(z) + z^n + c  <-- sin
  *   sin(z) + e^z + c
- *   sin(z) + z^n + c
  * These were first explored by a colleague of Mandelbrot, Clifford A.
  * Pickover.  These would make nice additions to add.
  *
  * Revision History:
+ * 03-Jul-2003: Added pow and sin options
+ * 30-Jun-2003: Changed writeable mode to be more consistent with
+ *              xscreensaver's starfish
  * 01-Nov-2000: Allocation checks
  * 24-Mar-1999: DEM and Binary decomp options added by Tim Auckland
- *              <Tim.Auckland@Procket.com>.  Ideas from Peitgen & Saupe's
+ *              <tda10.geo@yahoo.com>.  Ideas from Peitgen & Saupe's
  *              "The Science of Fractal Images"
  * 17-Nov-1998: Many Changes by Stromberg, including selection of
  *              interesting subregions, more extreme color ranges,
@@ -63,10 +66,8 @@ static const char sccsid[] = "@(#)mandelbrot.c	5.00 2000/11/01 xlockmore";
 #define SMOOTH_COLORS
 #define WRITABLE_COLORS
 #include "xlockmore.h"		/* from the xscreensaver distribution */
-#include <X11/Xutil.h>
 #else /* !STANDALONE */
 #include "xlock.h"		/* from the xlockmore distribution */
-#include "vis.h"
 #include "color.h"
 #endif /* !STANDALONE */
 
@@ -76,6 +77,10 @@ static const char sccsid[] = "@(#)mandelbrot.c	5.00 2000/11/01 xlockmore";
 #define DEF_INCREMENT  "1.00"
 #define DEF_BINARY     "False"
 #define DEF_DEM        "False"
+#define DEF_POW        "False"
+#define DEF_SIN        "False"
+#define DEF_CYCLE "True"
+
 /* 4.0 is best for seeing if a point is inside the set, 13 is better if
 ** you want to get a pretty corona
 */
@@ -89,27 +94,42 @@ static const char sccsid[] = "@(#)mandelbrot.c	5.00 2000/11/01 xlockmore";
 static float increment;
 static Bool  binary;
 static Bool  dem;
+static Bool  pow_p;
+static Bool  sin_p;
+static Bool  cycle_p;
 
 static XrmOptionDescRec opts[] =
 {
-     {(char *) "-increment", (char *) ".mandelbrot.increment", XrmoptionSepArg, (caddr_t) NULL},
-     {(char *) "-binary", (char *) ".mandelbrot.binary", XrmoptionNoArg, (caddr_t) "on"},
-     {(char *) "+binary", (char *) ".mandelbrot.binary", XrmoptionNoArg, (caddr_t) "off"},
-     {(char *) "-dem", (char *) ".mandelbrot.dem", XrmoptionNoArg, (caddr_t) "on"},
-     {(char *) "+dem", (char *) ".mandelbrot.dem", XrmoptionNoArg, (caddr_t) "off"}
+  {(char *) "-increment", (char *) ".mandelbrot.increment", XrmoptionSepArg, (caddr_t) NULL},
+  {(char *) "-binary", (char *) ".mandelbrot.binary", XrmoptionNoArg, (caddr_t) "on"},
+  {(char *) "+binary", (char *) ".mandelbrot.binary", XrmoptionNoArg, (caddr_t) "off"},
+  {(char *) "-dem", (char *) ".mandelbrot.dem", XrmoptionNoArg, (caddr_t) "on"},
+  {(char *) "+dem", (char *) ".mandelbrot.dem", XrmoptionNoArg, (caddr_t) "off"},
+  {(char *) "-pow", (char *) ".mandelbrot.pow", XrmoptionNoArg, (caddr_t) "on"},
+  {(char *) "+pow", (char *) ".mandelbrot.pow", XrmoptionNoArg, (caddr_t) "off"},
+  {(char *) "-sin", (char *) ".mandelbrot.sin", XrmoptionNoArg, (caddr_t) "on"},
+  {(char *) "+sin", (char *) ".mandelbrot.sin", XrmoptionNoArg, (caddr_t) "off"},
+  {(char *) "-cycle", (char *) ".mandelbrot.cycle", XrmoptionNoArg, (caddr_t) "on"},
+  {(char *) "+cycle", (char *) ".mandelbrot.cycle", XrmoptionNoArg, (caddr_t) "off"}
 };
 
 static argtype vars[] =
 {
- {(caddr_t *) & increment, (char *) "increment", (char *) "Increment", (char *) DEF_INCREMENT, t_Float},
- {(caddr_t *) & binary, (char *) "binary", (char *) "Binary", (char *) DEF_BINARY, t_Bool},
- {(caddr_t *) & dem, (char *) "dem", (char *) "Dem", (char *) DEF_DEM, t_Bool},
+  {(void *) & increment, (char *) "increment", (char *) "Increment", (char *) DEF_INCREMENT, t_Float},
+  {(void *) & binary, (char *) "binary", (char *) "Binary", (char *) DEF_BINARY, t_Bool},
+  {(void *) & dem, (char *) "dem", (char *) "Dem", (char *) DEF_DEM, t_Bool},
+  {(void *) & pow_p, (char *) "pow", (char *) "Pow", (char *) DEF_POW, t_Bool},
+  {(void *) & sin_p, (char *) "sin", (char *) "Sin", (char *) DEF_SIN, t_Bool},
+  {(void *) & cycle_p, (char *) "cycle", (char *) "Cycle", (char *) DEF_CYCLE, t_Bool}
 };
 static OptionStruct desc[] =
 {
-	{(char *) "-increment value", (char *) "increasing orders"},
-	{(char *) "-/+binary", (char *) "turn on/off Binary Decomposition colour modulation"},
-	{(char *) "-/+dem", (char *) "turn on/off Distance Estimator Method (instead of escape time)"}
+  {(char *) "-increment value", (char *) "increasing orders"},
+  {(char *) "-/+binary", (char *) "turn on/off Binary Decomposition colour modulation"},
+  {(char *) "-/+dem", (char *) "turn on/off Distance Estimator Method (instead of escape time)"},
+  {(char *) "-/+pow", (char *) "turn on/off adding z^z"},
+  {(char *) "-/+sin", (char *) "turn on/off adding sin(z)"},
+  {(char *) "-/+cycle", (char *) "turn on/off colour cycling"}
 };
 
 ModeSpecOpt mandelbrot_opts =
@@ -149,13 +169,70 @@ mult(complex * a, complex b)
 	a->imag = ti;
 }
 
-/* Plans for future additions?  a, z complex; x, y real
-   sin(z) = (e^(i * z) - e^(-i * z)) / (2 * i)
-   cos(z) = (e^(i * z) - e^(-i * z)) / 2
-   a^z = e^(z * ln(a))
-   e^z = e^x * (cos(y) + i * sin(y))
-   ln(z) = ln ((x^2 + y^2)^(1/2)) + i * invtan(y/x)
- */
+static void
+cln(complex * a)
+{
+	/* ln(z) = ln ((x^2 + y^2)^(1/2)) + i * invtan(y/x) */
+	double      tr, ti;
+
+	tr = sqrt(a->real * a->real + a->imag * a->imag);
+	ti = (a->real == 0.0 && a->imag == 0.0) ? 0.0 :
+		atan2(a->imag, a->real);
+	a->real = tr;
+	a->imag = ti;
+}
+
+static void
+complex_exp(complex * a)
+{
+	/* e^z = e^x * (cos(y) + i * sin(y)) */
+	double      tr;
+
+	tr = exp(a->real);
+	a->real = tr * cos(a->imag);
+	a->imag = tr * sin(a->imag);
+}
+
+static complex
+complex_pow(complex a, complex b)
+{
+	/* a^z = e^(z * ln(a)) */
+
+	complex c, d;
+
+	c = a;
+	d = b;
+	cln(&c);
+	mult(&d, c);
+	complex_exp(&d);
+	return d;
+}
+
+static complex
+complex_sin(complex a)
+{
+	/* sin(z) = -i * (e^(i * z) - e^(-i * z)) / 2 */
+	/* cos(z) = (e^(i * z) - e^(-i * z)) / 2 */
+	complex c, d, i;
+
+	c = a;
+	d = a;
+	i.real = 0; i.imag = 1;
+
+	/* inefficient but I just want to see the picture */
+	mult(&c, i);
+	i.imag = -i.imag;
+	mult(&d, i);
+	complex_exp(&c);
+	complex_exp(&d);
+	d.real = -d.real;
+	d.imag = -d.imag;
+	add(&c, d);
+	c.real = c.real / 2;
+	c.imag = c.imag / 2;
+	mult(&c, i);
+	return c;
+}
 
 /* this is a true power function. */
 static void
@@ -189,16 +266,14 @@ typedef struct {
 	int         counter;
 	double      power;
 	int         column;
-	Bool        backwards, reverse;
-	XColor      fgcol, bgcol;	/* foreground and background colour specs */
-	Bool        fixed_colormap;
+	Bool        backwards;
 	int         ncolors;
-	XColor      top;
-	XColor      bottom;
-	XColor     *colors;
-	Colormap    cmap;
-	int         usable_colors;
 	unsigned int cur_color;
+	GC          gc;
+	Colormap    cmap;
+	unsigned long blackpixel, whitepixel, fg, bg;
+	int direction;
+	XColor     *colors;
 	complex     extreme_ul;
 	complex	    extreme_lr;
 	complex	    ul;
@@ -206,8 +281,9 @@ typedef struct {
 	int         screen_width;
 	int         screen_height;
 	int         reptop;
-	Bool        dem;
+	Bool        dem, pow, sin, cycle_p, mono_p, no_colors;
 	Bool        binary;
+	ModeInfo   *mi;
 } mandelstruct;
 
 static mandelstruct *mandels = (mandelstruct *) NULL;
@@ -218,7 +294,7 @@ static mandelstruct *mandels = (mandelstruct *) NULL;
  * Loosely based on  Peitgen & Saupe's "The Science of Fractal Images"
  */
 static int
-reps(complex c, double p, int r, Bool binary, double demrange)
+reps(complex c, double p, int r, Bool binary, double demrange, Bool zpow, Bool zsin)
 {
 	int         rep;
 	int         escaped = 0;
@@ -234,6 +310,10 @@ reps(complex c, double p, int r, Bool binary, double demrange)
 	    t1 = t;
 		ipow(&t, (int) p);
 		add(&t, c);
+		if (zpow)
+			add(&t, complex_pow(t1, t1));
+		if (zsin)
+			add(&t, complex_sin(t1));
 		if (t.real * t.real + t.imag * t.imag >= escape) {
 			escaped = 1;
 			break;
@@ -275,6 +355,7 @@ static void
 Select(/* input variables first */
   complex *extreme_ul, complex *extreme_lr,
   int width, int height, int power, int top,
+  Bool zpow, Bool zsin,
   /* output variables follow */
   complex *selected_ul,complex *selected_lr)
 {
@@ -319,7 +400,7 @@ Select(/* input variables first */
 					temp.real = selected_ul->real +
 						(selected_ul->real - selected_lr->real) *
 						(((double)column)/sample_step);
-					r = reps(temp,(double) power,top,0,0.0);
+					r = reps(temp,(double) power,top,0,0.0, zpow, zsin);
 					/* Here, we just want to see if the point is in the set,
 					** not if we can make something pretty
 					*/
@@ -350,24 +431,43 @@ Select(/* input variables first */
 static void
 free_mandelbrot(Display *display, mandelstruct *mp)
 {
-	if (mp->cmap != None) {
-		XFreeColormap(display, mp->cmap);
-		mp->cmap = None;
+	ModeInfo *mi = mp->mi;
+
+	if (MI_IS_INSTALL(mi) && MI_NPIXELS(mi) > 2) {
+		MI_WHITE_PIXEL(mi) = mp->whitepixel;
+		MI_BLACK_PIXEL(mi) = mp->blackpixel;
+#ifndef STANDALONE
+		MI_FG_PIXEL(mi) = mp->fg;
+		MI_BG_PIXEL(mi) = mp->bg;
+#endif
+		if (mp->colors != NULL) {
+			if (mp->ncolors && !mp->no_colors)
+				free_colors(display, mp->cmap, mp->colors,
+					mp->ncolors);
+				free(mp->colors);
+				mp->colors = (XColor *) NULL;
+		}
+		if (mp->cmap != None) {
+			XFreeColormap(display, mp->cmap);
+			mp->cmap = None;
+		}
 	}
-	if (mp->colors != NULL) {
-		XFree((caddr_t) mp->colors);
-		mp->colors = (XColor *) NULL;
+	if (mp->gc != None) {
+		XFreeGC(display, mp->gc);
+		mp->gc = None;
 	}
 }
 
+#ifndef STANDALONE
+extern char *background;
+extern char *foreground;
+#endif
+
 void
 init_mandelbrot(ModeInfo * mi)
 {
-	int         preserve;
-	Bool        truecolor;
-	unsigned long redmask, greenmask, bluemask;
-	Window      window = MI_WINDOW(mi);
 	Display    *display = MI_DISPLAY(mi);
+	Window      window = MI_WINDOW(mi);
 	mandelstruct *mp;
 
 	if (mandels == NULL) {
@@ -376,10 +476,10 @@ init_mandelbrot(ModeInfo * mi)
 			return;
 	}
 	mp = &mandels[MI_SCREEN(mi)];
+	mp->mi = mi;
 
 	mp->screen_width = MI_WIDTH(mi);
 	mp->screen_height = MI_HEIGHT(mi);
-	mp->reverse = (Bool) (LRAND() & 1);
 	mp->backwards = (Bool) (LRAND() & 1);
 	if (mp->backwards)
 		mp->column = mp->screen_width - 1;
@@ -396,9 +496,16 @@ init_mandelbrot(ModeInfo * mi)
 	  case 1: mp->binary = 0; mp->dem = 1; break;
 	  default:mp->binary = 0; mp->dem = 0; break;
 	  }
+#if 0
+	/* too slow */
+	  mp->pow = (NRAND(5) == 0);
+	  mp->sin = (NRAND(5) == 0);
+#endif
 	} else {
 	  mp->binary = binary;
 	  mp->dem = dem;
+	  mp->pow = pow_p;
+	  mp->sin = sin_p;
 	}
 
 	mp->reptop = 300;
@@ -412,173 +519,182 @@ init_mandelbrot(ModeInfo * mi)
 	mp->extreme_lr.real = 3.0;
 	mp->extreme_lr.imag = 3.0;
 
+	if (!mp->gc) {
+		if (MI_IS_INSTALL(mi) && MI_NPIXELS(mi) > 2) {
+			XColor      color;
+
 #ifndef STANDALONE
-	mp->fixed_colormap = !setupColormap(mi,
-		&(mp->ncolors), &truecolor, &redmask, &greenmask, &bluemask);
-	if (!mp->fixed_colormap) {
-		preserve = preserveColors(MI_BLACK_PIXEL(mi), MI_WHITE_PIXEL(mi),
-					  MI_BG_PIXEL(mi), MI_FG_PIXEL(mi));
-		mp->bgcol.pixel = MI_BG_PIXEL(mi);
-		mp->fgcol.pixel = MI_FG_PIXEL(mi);
-		XQueryColor(display, MI_COLORMAP(mi), &(mp->bgcol));
-		XQueryColor(display, MI_COLORMAP(mi), &(mp->fgcol));
-
-#define RANGE 65536
-#define DENOM 4
-		/* color in the bottom part */
-		mp->bottom.red = NRAND(RANGE / DENOM);
-		mp->bottom.blue = NRAND(RANGE / DENOM);
-		mp->bottom.green = NRAND(RANGE / DENOM);
-		/* color in the top part */
-		mp->top.red = RANGE - NRAND(((DENOM-1)*RANGE) / DENOM);
-		mp->top.blue = RANGE - NRAND(((DENOM-1)*RANGE) / DENOM);
-		mp->top.green = RANGE - NRAND(((DENOM-1)*RANGE) / DENOM);
-
-		/* allocate colormap, if needed */
-		if (mp->colors == NULL)
-			if ((mp->colors = (XColor *) malloc(sizeof (XColor) *
-					mp->ncolors)) == NULL) {
-				free_mandelbrot(display, mp);
-				return;
-			}
-		if (mp->cmap == None)
+			mp->fg = MI_FG_PIXEL(mi);
+			mp->bg = MI_BG_PIXEL(mi);
+#endif
+			mp->blackpixel = MI_BLACK_PIXEL(mi);
+			mp->whitepixel = MI_WHITE_PIXEL(mi);
 			if ((mp->cmap = XCreateColormap(display, window,
-					   MI_VISUAL(mi), AllocAll)) == None) {
+					MI_VISUAL(mi), AllocNone)) == None) {
 				free_mandelbrot(display, mp);
 				return;
 			}
-		mp->usable_colors = mp->ncolors - preserve;
+			XSetWindowColormap(display, window, mp->cmap);
+			(void) XParseColor(display, mp->cmap, "black", &color);
+			(void) XAllocColor(display, mp->cmap, &color);
+			MI_BLACK_PIXEL(mi) = color.pixel;
+			(void) XParseColor(display, mp->cmap, "white", &color);
+			(void) XAllocColor(display, mp->cmap, &color);
+			MI_WHITE_PIXEL(mi) = color.pixel;
+#ifndef STANDALONE
+			(void) XParseColor(display, mp->cmap, background, &color);
+			(void) XAllocColor(display, mp->cmap, &color);
+			MI_BG_PIXEL(mi) = color.pixel;
+			(void) XParseColor(display, mp->cmap, foreground, &color);
+			(void) XAllocColor(display, mp->cmap, &color);
+			MI_FG_PIXEL(mi) = color.pixel;
+#endif
+			mp->colors = (XColor *) NULL;
+			mp->ncolors = 0;
+		}
+		if ((mp->gc = XCreateGC(display, MI_WINDOW(mi),
+			     (unsigned long) 0, (XGCValues *) NULL)) == None) {
+			free_mandelbrot(display, mp);
+			return;
+		}
 	}
+	MI_CLEARWINDOW(mi);
+
+  /* Set up colour map */
+  mp->direction = (LRAND() & 1) ? 1 : -1;
+  if (MI_IS_INSTALL(mi) && MI_NPIXELS(mi) > 2) {
+    if (mp->colors != NULL) {
+      if (mp->ncolors && !mp->no_colors)
+        free_colors(display, mp->cmap, mp->colors, mp->ncolors);
+      free(mp->colors);
+      mp->colors = (XColor *) NULL;
+    }
+    mp->ncolors = MI_NCOLORS(mi);
+    if (mp->ncolors < 2)
+      mp->ncolors = 2;
+    if (mp->ncolors <= 2)
+      mp->mono_p = True;
+    else
+      mp->mono_p = False;
+
+    if (mp->mono_p)
+      mp->colors = (XColor *) NULL;
+    else
+      if ((mp->colors = (XColor *) malloc(sizeof (*mp->colors) *
+          (mp->ncolors + 1))) == NULL) {
+        free_mandelbrot(display, mp);
+        return;
+      }
+    mp->cycle_p = has_writable_cells(mi);
+    if (mp->cycle_p) {
+      if (MI_IS_FULLRANDOM(mi)) {
+        if (!NRAND(8))
+          mp->cycle_p = False;
+        else
+          mp->cycle_p = True;
+      } else {
+        mp->cycle_p = cycle_p;
+      }
+    }
+    if (!mp->mono_p) {
+      if (!(LRAND() % 10))
+        make_random_colormap(
+#if STANDALONE
+            display, MI_WINDOW(mi),
+#else
+            mi,
+#endif
+              mp->cmap, mp->colors, &mp->ncolors,
+              True, True, &mp->cycle_p);
+      else if (!(LRAND() % 2))
+        make_uniform_colormap(
+#if STANDALONE
+            display, MI_WINDOW(mi),
+#else
+            mi,
+#endif
+                  mp->cmap, mp->colors, &mp->ncolors,
+                  True, &mp->cycle_p);
+      else
+        make_smooth_colormap(
+#if STANDALONE
+            display, MI_WINDOW(mi),
+#else
+            mi,
+#endif
+                 mp->cmap, mp->colors, &mp->ncolors,
+                 True, &mp->cycle_p);
+    }
+    XInstallColormap(display, mp->cmap);
+    if (mp->ncolors < 2) {
+      mp->ncolors = 2;
+      mp->no_colors = True;
+    } else
+      mp->no_colors = False;
+    if (mp->ncolors <= 2)
+      mp->mono_p = True;
+
+    if (mp->mono_p)
+      mp->cycle_p = False;
+
+  }
+  if (MI_IS_INSTALL(mi) && MI_NPIXELS(mi) > 2) {
+                if (mp->mono_p) {
+			mp->cur_color = MI_BLACK_PIXEL(mi);
+		}
+  }
 	Select(&mp->extreme_ul,&mp->extreme_lr,
 		mp->screen_width,mp->screen_height,
-		(int) mp->power,mp->reptop,
+		(int) mp->power,mp->reptop, mp->pow, mp->sin,
 		&mp->ul,&mp->lr);
-
-#endif /* !STANDALONE */
 }
 
-#if !defined(OLD_COLOR)
-static unsigned short
-pick_rgb(unsigned short bottom,unsigned short top,
-	int color_ind,int ncolors)
-{
-	/* por == part of range */
-	double por;
-	if (color_ind<ncolors/2) {
-		/* going up */
-		por = ((float)color_ind*2) / ncolors;
-	} else {
-		/* going down */
-		por = ((float)(color_ind-ncolors/2)*2) / ncolors;
-	}
-	return ((unsigned short) (bottom + (top - bottom)*por));
-}
-#endif
-
 void
 draw_mandelbrot(ModeInfo * mi)
 {
 	Display    *display = MI_DISPLAY(mi);
 	Window      window = MI_WINDOW(mi);
-	GC          gc = MI_GC(mi);
 	int         h;
 	complex     c;
 #if defined(USE_LOG)
 	double      log_top;
 #endif
 	double      demrange;
-	unsigned int i;
-	int         j;
 	mandelstruct *mp;
 
 	if (mandels == NULL)
 		return;
 	mp = &mandels[MI_SCREEN(mi)];
-	if (!mp->fixed_colormap && mp->colors == NULL)
-		return;
 
 	MI_IS_DRAWN(mi) = True;
 #if defined(USE_LOG)
 	log_top = log((float) mp->reptop);
 #endif
-#ifndef STANDALONE
-	if (mp->counter % 15 == 0) {
-		/* advance "drawing" color */
-		mp->cur_color = (mp->cur_color + 1) % mp->ncolors;
-		if (!mp->fixed_colormap && mp->usable_colors > 2) {
-			while (mp->cur_color == MI_WHITE_PIXEL(mi) ||
-			       mp->cur_color == MI_BLACK_PIXEL(mi) ||
-			       mp->cur_color == MI_BG_PIXEL(mi) ||
-			       mp->cur_color == MI_FG_PIXEL(mi)) {
-				mp->cur_color = (mp->cur_color + 1) % mp->ncolors;
-			}
-		}
-		/* advance colormap */
-		if (!mp->fixed_colormap && mp->usable_colors > 2) {
-			for (i = 0, j = mp->cur_color;
-			     i < (unsigned int) mp->ncolors; i++) {
-				if (i == MI_WHITE_PIXEL(mi)) {
-					mp->colors[i].pixel = i;
-					mp->colors[i].red = 65535;
-					mp->colors[i].blue = 65535;
-					mp->colors[i].green = 65535;
-					mp->colors[i].flags = DoRed | DoGreen | DoBlue;
-				} else if (i == MI_BLACK_PIXEL(mi)) {
-					mp->colors[i].pixel = i;
-					mp->colors[i].red = 0;
-					mp->colors[i].blue = 0;
-					mp->colors[i].green = 0;
-					mp->colors[i].flags = DoRed | DoGreen | DoBlue;
-				} else if (i == MI_BG_PIXEL(mi)) {
-					mp->colors[i] = mp->bgcol;
-				} else if (i == MI_FG_PIXEL(mi)) {
-					mp->colors[i] = mp->fgcol;
-				} else {
-#if defined(OLD_COLOR)
-					/* this is known to work well enough. I just wanted
-					** to explore some other possibilities
-					*/
-					double      range;
-					mp->colors[i].pixel = i;
-					range = ((double) (mp->top.red - mp->bottom.red)) /
-						mp->ncolors;
-					mp->colors[i].red = (short unsigned int) (range * j +
-							     mp->bottom.red);
-					range = ((double) (mp->top.green - mp->bottom.green)) /
-						mp->ncolors;
-					mp->colors[i].green = (short unsigned int) (range * j +
-							   mp->bottom.green);
-					range = ((double) (mp->top.blue - mp->bottom.blue)) /
-						mp->ncolors;
-					mp->colors[i].blue = (short unsigned int) (range * j +
-							    mp->bottom.blue);
-					mp->colors[i].flags = DoRed | DoGreen | DoBlue;
-					if (mp->reverse)
-						j = (j + 1) % mp->ncolors;
-					else
-						j = (j - 1 + mp->ncolors) % mp->ncolors;
-#else
-					mp->colors[i].pixel = i;
-					mp->colors[i].red = pick_rgb(mp->bottom.red,mp->top.red,
-						j,mp->ncolors);
-					mp->colors[i].green = pick_rgb(mp->bottom.green,mp->top.green,
-						j,mp->ncolors);
-					mp->colors[i].blue = pick_rgb(mp->bottom.blue,mp->top.blue,
-						j,mp->ncolors);
-					mp->colors[i].flags = DoRed | DoGreen | DoBlue;
-					if (mp->reverse)
-						j = (j + 1) % mp->ncolors;
-					else
-						j = (j - 1 + mp->ncolors) % mp->ncolors;
-#endif
-				}
-			}
-			/* make the entire mandelbrot move forward */
-			XStoreColors(display, mp->cmap, mp->colors, mp->ncolors);
-			setColormap(display, window, mp->cmap, MI_IS_INWINDOW(mi));
-		}
-	}
-#endif /* !STANDALONE */
+        if (MI_IS_INSTALL(mi) && MI_NPIXELS(mi) > 2) {
+                if (mp->mono_p) {
+                        XSetForeground(display, mp->gc, mp->cur_color);
+                } else {
+                        mp->cur_color = (mp->cur_color + 1) % mp->ncolors;
+                        XSetForeground(display, mp->gc, mp->colors[mp->cur_color].pixel);
+                }
+        } else {
+                if (MI_NPIXELS(mi) > 2)
+                        XSetForeground(display, mp->gc, MI_PIXEL(mi, mp->cur_color));
+                else if (mp->cur_color)
+                        XSetForeground(display, mp->gc, MI_BLACK_PIXEL(mi));
+                else
+                        XSetForeground(display, mp->gc, MI_WHITE_PIXEL(mi));
+                if (++mp->cur_color >= (unsigned int) MI_NPIXELS(mi))
+                        mp->cur_color = 0;
+        }
+
+  /* Rotate colours */
+  if (mp->cycle_p) {
+    rotate_colors(display, mp->cmap, mp->colors, mp->ncolors,
+      mp->direction);
+    if (!(LRAND() % 1000))
+      mp->direction = -mp->direction;
+  }
 	/* so we iterate columns beyond the width of the physical screen, so that
 	** we just wait around and show what we've done
 	*/
@@ -594,7 +710,7 @@ draw_mandelbrot(ModeInfo * mi)
 		/* select a new region! */
 		Select(&mp->extreme_ul,&mp->extreme_lr,
 			mp->screen_width,mp->screen_height,
-			(int) mp->power,mp->reptop,
+			(int) mp->power,mp->reptop, mp->pow, mp->sin,
 			&mp->ul,&mp->lr);
 	} else if (mp->column >= mp->screen_width || mp->column < 0) {
 		/* delay a while */
@@ -617,32 +733,21 @@ draw_mandelbrot(ModeInfo * mi)
 			(mp->ul.real-mp->lr.real)*(((double)(mp->column))/mp->screen_width);
 		c.imag = mp->ul.imag +
 			(mp->ul.imag - mp->lr.imag)*(((double) h) / mp->screen_height);
-		result = reps(c, mp->power, mp->reptop, mp->binary, demrange);
+		result = reps(c, mp->power, mp->reptop, mp->binary, demrange, mp->pow, mp->sin);
 		if (result == 0 || result == mp->reptop)
-			XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
+			XSetForeground(display, mp->gc, MI_BLACK_PIXEL(mi));
 		else {
 #if defined(USE_LOG)
 			color=(unsigned int) (MI_NPIXELS(mi) * log((float) result) / log_top);
 #else
 			color=(unsigned int) ((MI_NPIXELS(mi) * (float)result) / mp->reptop);
 #endif
-#ifndef STANDALONE
-			if (!mp->fixed_colormap && mp->usable_colors > 2) {
-				while (color == MI_WHITE_PIXEL(mi) ||
-				       color == MI_BLACK_PIXEL(mi) ||
-				       color == MI_BG_PIXEL(mi) ||
-				       color == MI_FG_PIXEL(mi)) {
-					color = (color + 1) % mp->ncolors;
-				}
-				XSetForeground(display, gc, color);
-			} else
-				XSetForeground(display, gc, MI_PIXEL(mi, color));
-#endif /* !STANDALONE */
+			XSetForeground(display, mp->gc, MI_PIXEL(mi, color));
 		}
 		/* we no longer have vertical symmetry - so we compute all points
 		** and don't draw with redundancy
 		*/
-		XDrawPoint(display, window, gc, mp->column, h);
+		XDrawPoint(display, window, mp->gc, mp->column, h);
 	}
 	if (mp->backwards)
 		mp->column--;
