@@ -16,7 +16,7 @@ static const char sccsid[] = "@(#)petri.c	5.04 2002/07/19 xlockmore";
  * the above copyright notice appear in all copies and that both that
  * copyright notice and this permission notice appear in supporting
  * documentation.  No representations are made about the suitability of this
- * software for any purpose.  It is provided "as is" without express or 
+ * software for any purpose.  It is provided "as is" without express or
  * implied warranty.
  *
  *
@@ -26,7 +26,7 @@ static const char sccsid[] = "@(#)petri.c	5.04 2002/07/19 xlockmore";
  * size: the size of a cell in pixels
  * count: the number of different kinds of mold (minimum: 2)
  * diaglim: the age limit for diagonal growth as a multiplier of orthogonal
- *   growth (minimum: 1, maximum 2). 1 means square growth, 1.414 
+ *   growth (minimum: 1, maximum 2). 1 means square growth, 1.414
  *   (i.e., sqrt(2)) means approximately circular growth, 2 means diamond
  *   growth.
  * anychan: the chance (fraction, between 0 and 1) that at each iteration,
@@ -47,7 +47,7 @@ static const char sccsid[] = "@(#)petri.c	5.04 2002/07/19 xlockmore";
  *   maximum possible speed (fraction, between 0 and 1)
  * maxdeathspeed: the maximum speed for black death cells as a fraction of the
  *   maximum possible speed (fraction, between 0 and 1)
- * originalcolors: if true, count must be 8 or less and the colors are a 
+ * originalcolors: if true, count must be 8 or less and the colors are a
  *   fixed set of primary and secondary colors (the artist's original choices)
  *
  * Interesting settings:
@@ -60,13 +60,13 @@ static const char sccsid[] = "@(#)petri.c	5.04 2002/07/19 xlockmore";
  *      petri -count 4 -anychan 0.01 -minorchan 1 \
  *              -minlifespan 2000 -maxlifespan 5000
  *
- *      petri -count 3 -anychan 1 -minlifespan 100000 \ 
+ *      petri -count 3 -anychan 1 -minlifespan 100000 \
  *              -instantdeathchan 0
  *
  *      petri -minlifespeed 0.02 -maxlifespeed 0.03 -minlifespan 1 \
  *              -maxlifespan 1 -instantdeathchan 0 -minorchan 0 \
  *              -anychan 0.3 -delay 4000
- * 
+ *
  * Revision History:
  * 22 Jul-2002: xlockmore version by Jouk Jansen <joukj@hrem.stm.tudelft.nl>
  */
@@ -91,9 +91,7 @@ static const char sccsid[] = "@(#)petri.c	5.04 2002/07/19 xlockmore";
 
 #ifdef MODE_petri
 
-
 #include <math.h>
-#include "spline.h"
 
 #define FLOAT float
 #define RAND_FLOAT (((FLOAT) (random() & 0xffff)) / ((FLOAT) 0x10000))
@@ -142,27 +140,27 @@ static XrmOptionDescRec opts[] =
 
 static argtype vars[] =
 {
-   {(caddr_t *) &st_anychan, (char *) "anychan",
+   {(void *) &st_anychan, (char *) "anychan",
    (char *) "Anychan", (char *) DEF_ANYCHAN , t_Float},
-   {(caddr_t *) &st_diaglim, (char *) "diaglim",
+   {(void *) &st_diaglim, (char *) "diaglim",
    (char *) "Diaglim", (char *) DEF_DIAGLIM , t_Float},
-   {(caddr_t *) &st_instantdeathchan, (char *) "instantdeathchan",
+   {(void *) &st_instantdeathchan, (char *) "instantdeathchan",
    (char *) "Instantdeathchan", (char *) DEF_DIAGLIM , t_Float},
-   {(caddr_t *) &memThrottle, (char *) "memthrottle",
+   {(void *) &memThrottle, (char *) "memthrottle",
    (char *) "Memthrottle", (char *) DEF_MEMTHROTTLE , t_String},
-   {(caddr_t *) &st_maxlifespan, (char *) "maxlifespan",
+   {(void *) &st_maxlifespan, (char *) "maxlifespan",
    (char *) "Maxlifespan", (char *) DEF_MAXLIFESPAN , t_Int},
-   {(caddr_t *) &st_minlifespan, (char *) "minlifespan",
+   {(void *) &st_minlifespan, (char *) "minlifespan",
    (char *) "Minlifespan", (char *) DEF_MINLIFESPAN , t_Int},
-   {(caddr_t *) &st_maxlifespeed, (char *) "maxlifespeed",
+   {(void *) &st_maxlifespeed, (char *) "maxlifespeed",
    (char *) "Maxlifespeed", (char *) DEF_MAXLIFESPEED , t_Float},
-   {(caddr_t *) &st_minlifespeed, (char *) "minlifespeed",
+   {(void *) &st_minlifespeed, (char *) "minlifespeed",
    (char *) "Minlifespeed", (char *) DEF_MINLIFESPEED , t_Float},
-   {(caddr_t *) &st_maxdeathspeed, (char *) "maxdeathspeed",
+   {(void *) &st_maxdeathspeed, (char *) "maxdeathspeed",
    (char *) "Maxdeathspeed", (char *) DEF_MAXDEATHSPEED , t_Float},
-   {(caddr_t *) &st_mindeathspeed, (char *) "mindeathspeed",
+   {(void *) &st_mindeathspeed, (char *) "mindeathspeed",
    (char *) "Mindeathspeed", (char *) DEF_MINDEATHSPEED , t_Float},
-   {(caddr_t *) &st_minorchan, (char *) "minorchan",
+   {(void *) &st_minorchan, (char *) "minorchan",
    (char *) "Minorchan", (char *) DEF_MINORCHAN , t_Float}
 };
 
@@ -193,7 +191,7 @@ ModStruct   petri_description =
 
 #endif
 
-typedef struct cell_s 
+typedef struct cell_s
 {
     unsigned char col;              /*  0      */
     unsigned char isnext;           /*  1      */
@@ -264,7 +262,7 @@ free_petri(Display *display, petristruct *sp)
     int n, shade;
 
     if (sp->coloredGCs != NULL) {
-	for (n = 0; n < sp->count*2; n++) 
+	for (n = 0; n < sp->count*2; n++)
 		if (sp->coloredGCs[n] != None)
 			XFreeGC(display, sp->coloredGCs[n]);
 	free(sp->coloredGCs);
@@ -295,18 +293,17 @@ free_petri(Display *display, petristruct *sp)
 static int setup_random_colormap (ModeInfo * mi)
 {
    petristruct *sp = &petries[MI_SCREEN(mi)];
-    XGCValues gcv;
-    int lose = 0;
-    int ncolors = sp->count - 1;
-    int n;
-    XColor *colors = (XColor *) NULL;
+   int lose = 0;
+   int ncolors = sp->count - 1;
+   int n;
+   XColor *colors = (XColor *) NULL;
    Display    *display = MI_DISPLAY(mi);
    Window      window = MI_WINDOW(mi);
-    
+
     colors = (XColor *) calloc (sizeof(*colors), sp->count*2);
     if (colors == NULL) {
 	free_petri(display, sp);
-        return False; 
+        return False;
     }
     colors[0].pixel = MI_BLACK_PIXEL(mi);
 
@@ -326,7 +323,7 @@ static int setup_random_colormap (ModeInfo * mi)
     }
     ncolors++;
     sp->count = ncolors;
-    
+
     if (sp->mono) {
 	if (colors != NULL) {
 		XFree((caddr_t) colors);
@@ -355,14 +352,14 @@ static int setup_random_colormap (ModeInfo * mi)
     }
     (void) memcpy (colors + sp->count, colors, sp->count * sizeof(*colors));
     colors[sp->count].pixel = MI_WHITE_PIXEL(mi);
-    
+
     for (n = 1; n < sp->count; n++)
     {
 	int m = n + sp->count;
 	colors[n].red = colors[m].red / 2;
 	colors[n].green = colors[m].green / 2;
 	colors[n].blue = colors[m].blue / 2;
-	
+
 	if (!XAllocColor (display, sp->cmap, &colors[n]))
 	{
 	    lose++;
@@ -371,12 +368,14 @@ static int setup_random_colormap (ModeInfo * mi)
     }
     if (lose)
     {
-	(void) fprintf (stderr, 
+	(void) fprintf (stderr,
 		 "petri: unable to allocate %d half-intensity colors.\n",
 		 lose);
     }
-    for (n = 0; n < sp->count*2; n++) 
+    for (n = 0; n < sp->count*2; n++)
     {
+        XGCValues gcv;
+
 	gcv.foreground = colors[n].pixel;
 	sp->coloredGCs[n] = XCreateGC (display, window, GCForeground, &gcv);
     }
@@ -390,10 +389,9 @@ static int setup_random_colormap (ModeInfo * mi)
 static int setup_original_colormap (ModeInfo * mi)
 {
    petristruct *sp = &petries[MI_SCREEN(mi)];
-    XGCValues gcv;
-    int lose = 0;
-    int n;
-    XColor *colors = (XColor *) NULL;
+   int lose = 0;
+   int n;
+   XColor *colors = (XColor *) NULL;
    Display    *display = MI_DISPLAY(mi);
    Window      window = MI_WINDOW(mi);
 
@@ -424,7 +422,7 @@ static int setup_original_colormap (ModeInfo * mi)
     colors = (XColor *) calloc (sizeof(*colors), sp->count*2);
     if (colors == NULL) {
 	free_petri(display, sp);
-        return False; 
+        return False;
     }
     colors[0].pixel = MI_BLACK_PIXEL(mi);
     colors[sp->count].pixel = MI_WHITE_PIXEL(mi);
@@ -455,13 +453,15 @@ static int setup_original_colormap (ModeInfo * mi)
 
     if (lose)
     {
-	(void) fprintf (stderr, 
+	(void) fprintf (stderr,
 		 "petri: unable to allocate %d colors.\n",
 		 lose);
     }
-    
-    for (n = 0; n < sp->count*2; n++) 
+
+    for (n = 0; n < sp->count*2; n++)
     {
+        XGCValues gcv;
+
 	gcv.foreground = colors[n].pixel;
 	sp->coloredGCs[n] = XCreateGC (display, window, GCForeground, &gcv);
     }
@@ -493,7 +493,7 @@ static int setup_display (ModeInfo * mi)
       {
         int n;
         char c;
-	 
+
 	(void) strcpy( s , memThrottle );
         if (1 == sscanf (s, " %d M %c", &n, &c) ||
             1 == sscanf (s, " %d m %c", &n, &c))
@@ -510,7 +510,7 @@ static int setup_display (ModeInfo * mi)
             free_petri(display, sp);
 	    return False;
           }
-        
+
         free(s);
       }
 
@@ -538,7 +538,7 @@ static int setup_display (ModeInfo * mi)
     sp->coloredGCs = (GC *) calloc (sizeof(GC), sp->count * 2);
     if (sp->coloredGCs == NULL) {
 	free_petri(display, sp);
-        return False; 
+        return False;
     }
 
    if (MI_IS_FULLRANDOM(mi))
@@ -567,7 +567,7 @@ static int setup_display (ModeInfo * mi)
     {
 	sp->anychan = 1.0;
     }
-    
+
    if (MI_IS_FULLRANDOM(mi))
      sp->minorchan = (float) LRAND() / (float) MAXRAND;
    else
@@ -580,7 +580,7 @@ static int setup_display (ModeInfo * mi)
     {
 	sp->minorchan = 1.0;
     }
-    
+
    if (MI_IS_FULLRANDOM(mi))
      sp->instantdeathchan = (float) pow( (double) LRAND() / (double) MAXRAND ,
 					 8.0 );
@@ -675,10 +675,10 @@ static int setup_display (ModeInfo * mi)
     sp->maxdeathspeed *= sp->diaglim;
 
     sp->cmap = xgwa.colormap;
-    
+
     sp->windowWidth = xgwa.width;
     sp->windowHeight = xgwa.height;
-    
+
     sp->arr_width = sp->windowWidth / cell_size;
     sp->arr_height = sp->windowHeight / cell_size;
 
@@ -723,7 +723,7 @@ static int setup_display (ModeInfo * mi)
     {
 	sp->ySize = sp->xSize;
     }
-    
+
     sp->xOffset = (sp->windowWidth - (sp->arr_width * sp->xSize)) / 2;
     sp->yOffset = (sp->windowHeight - (sp->arr_height * sp->ySize)) / 2;
 
@@ -788,13 +788,13 @@ static int setup_arr (ModeInfo * mi)
 
     if (sp->mono) {
       XSetForeground(display, MI_GC(mi), MI_BLACK_PIXEL(mi));
-      XFillRectangle (display, window, MI_GC(mi), 0, 0, 
+      XFillRectangle (display, window, MI_GC(mi), 0, 0,
 		    sp->windowWidth, sp->windowHeight);
-    } else  
-      XFillRectangle (display, window, sp->coloredGCs[0], 0, 0, 
+    } else
+      XFillRectangle (display, window, sp->coloredGCs[0], 0, 0,
 		    sp->windowWidth, sp->windowHeight);
 
-    sp->arr = (cell *) calloc (sizeof(cell), sp->arr_width * sp->arr_height);  
+    sp->arr = (cell *) calloc (sizeof(cell), sp->arr_width * sp->arr_height);
     if (!sp->arr)
       {
         (void) fprintf (stderr, "petri: out of memory allocating %dx%d grid\n",
@@ -806,7 +806,7 @@ static int setup_arr (ModeInfo * mi)
     for (y = 0; y < sp->arr_height; y++)
     {
       int row = y * sp->arr_width;
-	for (x = 0; x < sp->arr_width; x++) 
+	for (x = 0; x < sp->arr_width; x++)
 	{
 	    sp->arr[row+x].speed = 0.0;
 	    sp->arr[row+x].growth = 0.0;
@@ -828,7 +828,7 @@ static int setup_arr (ModeInfo * mi)
         return False;
     }
     }
-    
+
     if (sp->tail == NULL)
     {
 	sp->tail = (cell *) malloc (sizeof (cell));
@@ -854,13 +854,13 @@ static void newcell (ModeInfo * mi , cell *c, unsigned char col, FLOAT spf)
 {
    petristruct *sp = &petries[MI_SCREEN(mi)];
     if (! c) return;
-    
+
     if (c->col == col) return;
-    
+
     c->nextcol = col;
     c->nextspeed = spf;
     c->isnext = 1;
-    
+
     if (c->prev == 0) {
 	c->next = sp->head->next;
 	c->prev = sp->head;
@@ -885,14 +885,14 @@ static int randblip (ModeInfo * mi , int doit)
    petristruct *sp = &petries[MI_SCREEN(mi)];
     int n;
     int b = 0;
-    if (!doit 
-	&& (sp->blastcount-- >= 0) 
+    if (!doit
+	&& (sp->blastcount-- >= 0)
 	&& (RAND_FLOAT > sp->anychan))
     {
 	return True;
     }
-    
-    if (sp->blastcount < 0) 
+
+    if (sp->blastcount < 0)
     {
 	b = 1;
 	n = 2;
@@ -907,16 +907,16 @@ static int randblip (ModeInfo * mi , int doit)
 	    b = 0;
 	}
     }
-    else if (RAND_FLOAT <= sp->minorchan) 
+    else if (RAND_FLOAT <= sp->minorchan)
     {
 	n = 2;
     }
-    else 
+    else
     {
 	n = random () % 3 + 3;
     }
-    
-    while (n--) 
+
+    while (n--)
     {
 	int x = random () % sp->arr_width;
 	int y = random () % sp->arr_height;
@@ -950,8 +950,8 @@ void draw_petri (ModeInfo * mi)
    if (sp->arr == NULL)
       return;
    MI_IS_DRAWN(mi) = True;
-   
-    for (a = sp->head->next; a != sp->tail; a = a->next) 
+
+    for (a = sp->head->next; a != sp->tail; a = a->next)
     {
 	static XPoint all_coords[] = {{-1, -1}, {-1, 1}, {1, -1}, {1, 1},
 				      {-1,  0}, { 1, 0}, {0, -1}, {0, 1},
@@ -962,7 +962,7 @@ void draw_petri (ModeInfo * mi)
         if (a->speed == 0) continue;
         a->growth += a->speed;
 
-	if (a->growth >= sp->diaglim) 
+	if (a->growth >= sp->diaglim)
 	{
 	    coords = all_coords;
 	}
@@ -980,25 +980,25 @@ void draw_petri (ModeInfo * mi)
 	    int x = cell_x(a) + coords->x;
 	    int y = cell_y(a) + coords->y;
 	    coords++;
-	    
+
 	    if (x < 0) x = sp->arr_width - 1;
 	    else if (x >= sp->arr_width) x = 0;
-	    
+
 	    if (y < 0) y = sp->arr_height - 1;
 	    else if (y >= sp->arr_height) y = 0;
-	    
+
 	    newcell (mi , &sp->arr[y * sp->arr_width + x], a->col, a->speed);
 	}
 
-	if (a->growth >= sp->diaglim) 
+	if (a->growth >= sp->diaglim)
 	    killcell (mi ,a);
     }
-    
+
     if (!randblip (mi , (sp->head->next) == sp->tail))
-	 return; 
+	 return;
     for (a = sp->head->next; a != sp->tail; a = a->next)
     {
-	if (a->isnext) 
+	if (a->isnext)
 	{
 	    a->isnext = 0;
 	    a->speed = a->nextspeed;
@@ -1041,7 +1041,7 @@ init_petri(ModeInfo * mi)
         (void) printf( "mindeathspeed : %f\n" , st_mindeathspeed );
         (void) printf( "maxdeathspeed : %f\n" , st_maxdeathspeed );
      }
-   
+
 /* initialize */
 	if (petries == NULL) {
 		if ((petries = (petristruct *) calloc(MI_NUM_SCREENS(mi),
@@ -1055,7 +1055,7 @@ init_petri(ModeInfo * mi)
 	   return;
 	if (!setup_arr(mi))
 	    return;
-    
+
     (void) randblip (mi , 1);
 }
 
@@ -1064,7 +1064,7 @@ release_petri(ModeInfo * mi)
 {
    if (petries != NULL) {
       int screen;
-      
+
       for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 	free_petri(MI_DISPLAY(mi), &petries[screen]);
       free(petries);
