@@ -23,7 +23,7 @@ static const char sccsid[] = "@(#)polyominoes.c 5.01 2000/12/18 xlockmore";
  *
  * Revision History:
  * 07-Jan-2001: Made improvement to the search algorithm for the puzzles
- *              involving identical polyominoes (via the variable 
+ *              involving identical polyominoes (via the variable
  *              reason_to_not_attach).  By Stephen Montgomery-Smith.
  * 20-Dec-2000: Added more puzzles at David Bagley's request.
  * 27-Nov-2000: Adapted from euler2d.c Copyright (c) 2000 by Stephen
@@ -65,8 +65,8 @@ static XrmOptionDescRec opts[] =
 };
 static argtype vars[] =
 {
-  {(caddr_t *) &identical, (char *) "identical", (char *) "Identical", (char *) DEF_IDENTICAL, t_Bool},
-  {(caddr_t *) & plain, (char *) "plain", (char *) "Plain", (char *) DEF_PLAIN, t_Bool}
+  {(void *) &identical, (char *) "identical", (char *) "Identical", (char *) DEF_IDENTICAL, t_Bool},
+  {(void *) & plain, (char *) "plain", (char *) "Plain", (char *) DEF_PLAIN, t_Bool}
 };
 static OptionStruct desc[] =
 {
@@ -221,7 +221,7 @@ typedef struct _polyominoesstruct{
 #define G ((sp->box/45)+1)         /* 1/2 of gap between polyominoes. */
 #define T ((sp->box<=12)?1:(G*2))  /* Thickness of walls of polyominoes. */
 #define R ((sp->box<=12)?1:(G*6))  /* Amount of rounding. */
-#define RT ((sp->box<=12)?1:(G*3)) /* Thickness of wall of rounded parts. 
+#define RT ((sp->box<=12)?1:(G*3)) /* Thickness of wall of rounded parts.
                                       Here 3 is an approximation to 2 sqrt(2). */
 #define RR 0   /* Roof ridge thickness */
 
@@ -345,7 +345,7 @@ These are the routines for manipulating the polyominoes and
 attaching and detaching them from the rectangle.
 ************************************************************/
 
-static void transform(point_type in, point_type offset, int transform_no, 
+static void transform(point_type in, point_type offset, int transform_no,
                       point_type attach_point, point_type *out) {
   switch (transform_no) {
     case 0: out->x=in.x-offset.x+attach_point.x;
@@ -395,7 +395,7 @@ static void next_poly_no(polyominoesstruct *sp, int *poly_no) {
   }
 }
 
-/* check_all_regions_multiple_of looks for connected regions of 
+/* check_all_regions_multiple_of looks for connected regions of
    blank spaces, and returns 0 if it finds a connected region containing
    a number of blanks that is not a multiple of n.
 */
@@ -499,8 +499,8 @@ score_point(polyominoesstruct *sp, int x, int y, int min_score_so_far) {
   int score = 0;
 
   if (x>=1 && x<sp->width-1 && y>=1 && y<sp->height-1 &&
-      ARRAY(x-1,y-1)<0 && ARRAY(x-1,y)<0 && ARRAY(x-1,y+1)<0 && 
-      ARRAY(x+1,y-1)<0 && ARRAY(x+1,y)<0 && ARRAY(x+1,y+1)<0 && 
+      ARRAY(x-1,y-1)<0 && ARRAY(x-1,y)<0 && ARRAY(x-1,y+1)<0 &&
+      ARRAY(x+1,y-1)<0 && ARRAY(x+1,y)<0 && ARRAY(x+1,y+1)<0 &&
       ARRAY(x,y-1)<0 && ARRAY(x,y+1)<0)
     return 10000;
 
@@ -514,9 +514,9 @@ score_point(polyominoesstruct *sp, int x, int y, int min_score_so_far) {
       for (i=0;i<sp->polyomino[poly_no].len;i++) {
         transform(sp->polyomino[poly_no].point[i],
                   sp->polyomino[poly_no].point[point_no],
-                  sp->polyomino[poly_no].transform_list[transform_index], 
+                  sp->polyomino[poly_no].transform_list[transform_index],
                   attach_point, &target_point);
-        if ( ! ((target_point.x>=0) && (target_point.x<sp->width) 
+        if ( ! ((target_point.x>=0) && (target_point.x<sp->width)
                   && (target_point.y>=0) && (target_point.y<sp->height)
                   && (ARRAY_P(target_point)<0))) {
           attachable = 0;
@@ -557,7 +557,7 @@ static void find_blank(polyominoesstruct *sp, point_type *point) {
     }
   }
 
-  for (x=0;x<sp->width;x++) for (y=0;y<sp->height;y++) 
+  for (x=0;x<sp->width;x++) for (y=0;y<sp->height;y++)
     if (ARRAY(x,y)<0) ARRAY(x,y) = -1;
 }
 
@@ -577,7 +577,7 @@ void detach(polyominoesstruct *sp, int *poly_no, int *point_no, int *transform_i
   for (i=0;i<sp->polyomino[*poly_no].len;i++) {
     transform(sp->polyomino[*poly_no].point[i],
               sp->polyomino[*poly_no].point[*point_no],
-              sp->polyomino[*poly_no].transform_list[*transform_index]^(rot180<<1), 
+              sp->polyomino[*poly_no].transform_list[*transform_index]^(rot180<<1),
               *attach_point, &target_point);
     ARRAY_P(target_point) = -1;
     CHANGED_ARRAY_P(target_point) = 1;
@@ -586,7 +586,7 @@ void detach(polyominoesstruct *sp, int *poly_no, int *point_no, int *transform_i
   sp->polyomino[*poly_no].attached = 0;
 }
 
-/* Attempts to attach a polyomino at point (x,y) at the 
+/* Attempts to attach a polyomino at point (x,y) at the
    point_no-th point of that polyomino, using the transform
    transform_no.  Returns 1 if successful.
 */
@@ -609,15 +609,15 @@ int attach(polyominoesstruct *sp, int poly_no, int point_no, int transform_index
   for (i=0;i<sp->polyomino[poly_no].len;i++) {
     transform(sp->polyomino[poly_no].point[i],
               sp->polyomino[poly_no].point[point_no],
-              sp->polyomino[poly_no].transform_list[transform_index]^(rot180<<1), 
+              sp->polyomino[poly_no].transform_list[transform_index]^(rot180<<1),
               attach_point, &target_point);
-    if ( ! ((target_point.x>=0) && (target_point.x<sp->width) 
+    if ( ! ((target_point.x>=0) && (target_point.x<sp->width)
               && (target_point.y>=0) && (target_point.y<sp->height)
               && (ARRAY_P(target_point) == -1))) {
       if (sp->identical) {
         attachable = 0;
-        if ((target_point.x>=0) && (target_point.x<sp->width) 
-           && (target_point.y>=0) && (target_point.y<sp->height) 
+        if ((target_point.x>=0) && (target_point.x<sp->width)
+           && (target_point.y>=0) && (target_point.y<sp->height)
            && (ARRAY_P(target_point) >= 0)
            && (ARRAY_P(target_point)<worst_reason_not_to_attach))
           worst_reason_not_to_attach = ARRAY_P(target_point);
@@ -818,10 +818,10 @@ static void create_bitmaps(ModeInfo * mi, polyominoesstruct *sp) {
           THIRDBIT(n,x,y)
       }
 
-      if (IS_LEFT(n)) 
+      if (IS_LEFT(n))
         for (y=0;y<sp->box;y++) for (x=G;x<G+T;x++)
           SETBIT(n,x,y)
-      if (IS_RIGHT(n)) 
+      if (IS_RIGHT(n))
         for (y=0;y<sp->box;y++) for (x=G;x<G+T;x++)
           SETBIT(n,sp->box-1-x,y)
       if (IS_UP(n))
@@ -830,10 +830,10 @@ static void create_bitmaps(ModeInfo * mi, polyominoesstruct *sp) {
       if (IS_DOWN(n))
         for (x=0;x<sp->box;x++) for (y=G;y<G+T;y++)
           SETBIT(n,x,sp->box-1-y)
-      if (IS_LEFT(n)) 
+      if (IS_LEFT(n))
         for (y=0;y<sp->box;y++) for (x=0;x<G;x++)
           RESBIT(n,x,y)
-      if (IS_RIGHT(n)) 
+      if (IS_RIGHT(n))
         for (y=0;y<sp->box;y++) for (x=0;x<G;x++)
           RESBIT(n,sp->box-1-x,y)
       if (IS_UP(n))
@@ -1009,7 +1009,7 @@ Routines to initialise and close down polyominoes.
 
 static void free_bitmaps(polyominoesstruct *sp) {
   int n;
-  
+
   for (n=0;n<256;n++)
 /* Don't bother to free duplicates */
     if (IS_LEFT_UP(n) && (IS_LEFT(n) || IS_UP(n)))
@@ -1115,31 +1115,31 @@ static struct {int len; point_type point[4];
                int transform_len, transform_list[8], max_white;} tetromino[5] =
 {
 /*
-xxxx 
+xxxx
 */
   {4, {{0,0}, {1,0}, {2,0}, {3,0}},
    2, {0, 1, -1, -1, -1, -1, -1, -1}, 2},
 /*
-xxx  
-  x  
+xxx
+  x
 */
   {4, {{0,0}, {1,0}, {2,0}, {2,1}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 2},
 /*
-xxx  
- x   
+xxx
+ x
 */
   {4, {{0,0}, {1,0}, {1,1}, {2,0}},
    4, {0, 1, 2, 3, -1, -1, -1, -1}, 3},
 /*
-xx   
- xx  
+xx
+ xx
 */
   {4, {{0,0}, {1,0}, {1,1}, {2,1}},
    4, {0, 1, 4, 5, -1, -1, -1, -1}, 2},
 /*
-xx   
-xx   
+xx
+xx
 */
   {4, {{0,0}, {0,1}, {1,0}, {1,1}},
    1, {0, -1, -1, -1, -1, -1, -1, -1}, 2}};
@@ -1150,79 +1150,79 @@ static struct pentomino_struct {int len; point_type point[5];
   pentomino[12] =
 {
 /*
-xxxxx 
+xxxxx
 */
   {5, {{0,0}, {1,0}, {2,0}, {3,0}, {4,0}},
    2, {0, 1, -1, -1, -1, -1, -1, -1}, 3},
 /*
-xxxx  
-   x  
+xxxx
+   x
 */
   {5, {{0,0}, {1,0}, {2,0}, {3,0}, {3,1}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 3},
 /*
-xxxx  
-  x   
+xxxx
+  x
 */
   {5, {{0,0}, {1,0}, {2,0}, {2,1}, {3,0}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 3},
 /*
-  x   
-xxx   
-  x   
+  x
+xxx
+  x
 */
   {5, {{0,0}, {1,0}, {2,-1}, {2,0}, {2,1}},
    4, {0, 1, 2, 3, -1, -1, -1, -1}, 3},
 /*
-xxx   
-  xx  
+xxx
+  xx
 */
   {5, {{0,0}, {1,0}, {2,0}, {2,1}, {3,1}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 3},
 /*
-xxx   
- xx   
+xxx
+ xx
 */
   {5, {{0,0}, {1,0}, {1,1}, {2,0}, {2,1}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 3},
 /*
-xxx   
-  x   
-  x   
+xxx
+  x
+  x
 */
   {5, {{0,0}, {1,0}, {2,0}, {2,1}, {2,2}},
    4, {0, 1, 2, 3, -1, -1, -1, -1}, 3},
 /*
- x    
-xxx   
-  x   
+ x
+xxx
+  x
 */
   {5, {{0,0}, {1,-1}, {1,0}, {2,0}, {2,1}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 3},
 /*
-xxx   
-x x   
+xxx
+x x
 */
   {5, {{0,0}, {0,1}, {1,0}, {2,0}, {2,1}},
    4, {0, 1, 2, 3, -1, -1, -1, -1}, 3},
 /*
-  x   
-xxx   
-x     
+  x
+xxx
+x
 */
   {5, {{0,0}, {0,1}, {1,0}, {2,-1}, {2,0}},
    4, {0, 1, 4, 5, -1, -1, -1, -1}, 3},
 /*
- x    
-xxx   
- x    
+ x
+xxx
+ x
 */
   {5, {{0,0}, {1,-1}, {1,0}, {1,1}, {2,0}},
    1, {0, -1, -1, -1, -1, -1, -1, -1}, 4},
 /*
-xx    
- xx   
-  x   
+xx
+ xx
+  x
 */
   {5, {{0,0}, {1,0}, {1,1}, {2,1}, {2,2}},
    4, {0, 1, 2, 3, -1, -1, -1, -1}, 3}};
@@ -1233,233 +1233,233 @@ static struct hexomino_struct {int len; point_type point[6];
   hexomino[35] =
 {
 /*
-xxxxxx 
+xxxxxx
 */
   {6, {{0,0}, {1,0}, {2,0}, {3,0}, {4,0}, {5,0}},
    2, {0, 1, -1, -1, -1, -1, -1, -1}, 3},
 /*
-xxxxx  
-    x  
+xxxxx
+    x
 */
   {6, {{0,0}, {1,0}, {2,0}, {3,0}, {4,0}, {4,1}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 3},
 /*
-xxxxx  
-   x   
+xxxxx
+   x
 */
   {6, {{0,0}, {1,0}, {2,0}, {3,0}, {3,1}, {4,0}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 4},
 /*
-xxxxx  
-  x    
+xxxxx
+  x
 */
   {6, {{0,0}, {1,0}, {2,0}, {2,1}, {3,0}, {4,0}},
    4, {0, 1, 2, 3, -1, -1, -1, -1}, 3},
 /*
-   x   
-xxxx   
-   x   
+   x
+xxxx
+   x
 */
   {6, {{0,0}, {1,0}, {2,0}, {3,-1}, {3,0}, {3,1}},
    4, {0, 1, 2, 3, -1, -1, -1, -1}, 4},
 /*
-xxxx   
-   xx  
+xxxx
+   xx
 */
   {6, {{0,0}, {1,0}, {2,0}, {3,0}, {3,1}, {4,1}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 3},
 /*
-xxxx   
-  xx   
+xxxx
+  xx
 */
   {6, {{0,0}, {1,0}, {2,0}, {2,1}, {3,0}, {3,1}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 3},
 /*
-xxxx   
-   x   
-   x   
+xxxx
+   x
+   x
 */
   {6, {{0,0}, {1,0}, {2,0}, {3,0}, {3,1}, {3,2}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 3},
 /*
-  x    
-xxxx   
-   x   
+  x
+xxxx
+   x
 */
   {6, {{0,0}, {1,0}, {2,-1}, {2,0}, {3,0}, {3,1}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 3},
 /*
-xxxx   
- x x   
+xxxx
+ x x
 */
   {6, {{0,0}, {1,0}, {1,1}, {2,0}, {3,0}, {3,1}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 4},
 /*
- x     
-xxxx   
-   x   
+ x
+xxxx
+   x
 */
   {6, {{0,0}, {1,-1}, {1,0}, {2,0}, {3,0}, {3,1}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 4},
 /*
-xxxx   
-x  x   
+xxxx
+x  x
 */
   {6, {{0,0}, {0,1}, {1,0}, {2,0}, {3,0}, {3,1}},
    4, {0, 1, 2, 3, -1, -1, -1, -1}, 3},
 /*
-   x   
-xxxx   
-x      
+   x
+xxxx
+x
 */
   {6, {{0,0}, {0,1}, {1,0}, {2,0}, {3,-1}, {3,0}},
    4, {0, 1, 4, 5, -1, -1, -1, -1}, 3},
 /*
-  x    
-xxxx   
-  x    
+  x
+xxxx
+  x
 */
   {6, {{0,0}, {1,0}, {2,-1}, {2,0}, {2,1}, {3,0}},
    4, {0, 1, 2, 3, -1, -1, -1, -1}, 4},
 /*
-xxxx   
- xx    
+xxxx
+ xx
 */
   {6, {{0,0}, {1,0}, {1,1}, {2,0}, {2,1}, {3,0}},
    4, {0, 1, 2, 3, -1, -1, -1, -1}, 3},
 /*
-xxxx   
-  x    
-  x    
+xxxx
+  x
+  x
 */
   {6, {{0,0}, {1,0}, {2,0}, {2,1}, {2,2}, {3,0}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 3},
 /*
- x     
-xxxx   
-  x    
+ x
+xxxx
+  x
 */
   {6, {{0,0}, {1,-1}, {1,0}, {2,0}, {2,1}, {3,0}},
    4, {0, 1, 4, 5, -1, -1, -1, -1}, 3},
 /*
-  xx   
-xxx    
-  x    
+  xx
+xxx
+  x
 */
   {6, {{0,0}, {1,0}, {2,-1}, {2,0}, {2,1}, {3,-1}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 3},
 /*
- xx    
-xxx    
-  x    
+ xx
+xxx
+  x
 */
   {6, {{0,0}, {1,-1}, {1,0}, {2,-1}, {2,0}, {2,1}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 3},
 /*
-  x    
-xxx    
-x x    
+  x
+xxx
+x x
 */
   {6, {{0,0}, {0,1}, {1,0}, {2,-1}, {2,0}, {2,1}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 4},
 /*
-xxx    
-  xxx  
+xxx
+  xxx
 */
   {6, {{0,0}, {1,0}, {2,0}, {2,1}, {3,1}, {4,1}},
    4, {0, 1, 4, 5, -1, -1, -1, -1}, 3},
 /*
-xxx    
-  xx   
-   x   
+xxx
+  xx
+   x
 */
   {6, {{0,0}, {1,0}, {2,0}, {2,1}, {3,1}, {3,2}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 3},
 /*
-xxx    
- xxx   
+xxx
+ xxx
 */
   {6, {{0,0}, {1,0}, {1,1}, {2,0}, {2,1}, {3,1}},
    4, {0, 1, 4, 5, -1, -1, -1, -1}, 4},
 /*
-xxx    
-  xx   
-  x    
+xxx
+  xx
+  x
 */
   {6, {{0,0}, {1,0}, {2,0}, {2,1}, {2,2}, {3,1}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 4},
 /*
- x     
-xxx    
-  xx   
+ x
+xxx
+  xx
 */
   {6, {{0,0}, {1,-1}, {1,0}, {2,0}, {2,1}, {3,1}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 4},
 /*
-xxx    
-x xx   
+xxx
+x xx
 */
   {6, {{0,0}, {0,1}, {1,0}, {2,0}, {2,1}, {3,1}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 3},
 /*
-xxx    
- xx    
-  x    
+xxx
+ xx
+  x
 */
   {6, {{0,0}, {1,0}, {1,1}, {2,0}, {2,1}, {2,2}},
    4, {0, 1, 2, 3, -1, -1, -1, -1}, 4},
 /*
- x     
-xxx    
- xx    
+ x
+xxx
+ xx
 */
   {6, {{0,0}, {1,-1}, {1,0}, {1,1}, {2,0}, {2,1}},
    4, {0, 1, 2, 3, -1, -1, -1, -1}, 4},
 /*
-xxx    
-xxx    
+xxx
+xxx
 */
   {6, {{0,0}, {0,1}, {1,0}, {1,1}, {2,0}, {2,1}},
    2, {0, 1, -1, -1, -1, -1, -1, -1}, 3},
 /*
-xxx    
-  x    
-  xx   
+xxx
+  x
+  xx
 */
   {6, {{0,0}, {1,0}, {2,0}, {2,1}, {2,2}, {3,2}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 3},
 /*
-xxx    
-  x    
- xx    
+xxx
+  x
+ xx
 */
   {6, {{0,0}, {1,0}, {1,2}, {2,0}, {2,1}, {2,2}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 3},
 /*
- x     
-xxx    
-x x    
+ x
+xxx
+x x
 */
   {6, {{0,0}, {0,1}, {1,-1}, {1,0}, {2,0}, {2,1}},
    4, {0, 1, 2, 3, -1, -1, -1, -1}, 3},
 /*
-  xx   
-xxx    
-x      
+  xx
+xxx
+x
 */
   {6, {{0,0}, {0,1}, {1,0}, {2,-1}, {2,0}, {3,-1}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 3},
 /*
- xx    
-xxx    
-x      
+ xx
+xxx
+x
 */
   {6, {{0,0}, {0,1}, {1,-1}, {1,0}, {2,-1}, {2,0}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 3},
 /*
-xx     
- xx    
-  xx   
+xx
+ xx
+  xx
 */
   {6, {{0,0}, {1,0}, {1,1}, {2,1}, {2,2}, {3,2}},
    4, {0, 1, 4, 5, -1, -1, -1, -1}, 3}};
@@ -1752,7 +1752,7 @@ Science News November 14, 1987 Vol 132, Pg 310
 
 */
 
-static struct {int len; point_type point[5]; 
+static struct {int len; point_type point[5];
                int transform_len, transform_list[8], max_white;} pentomino1 =
   {5, {{0,0}, {1,0}, {2,0}, {3,0}, {1,1}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 3};
@@ -1782,7 +1782,7 @@ int set_pentomino_puzzle1(polyominoesstruct *sp) {
 
 */
 
-static struct {int len; point_type point[6]; 
+static struct {int len; point_type point[6];
                int transform_len, transform_list[8], max_white;} hexomino1 =
   {6, {{0,0}, {1,0}, {2,0}, {3,0}, {4,0}, {1,1}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 4};
@@ -1814,7 +1814,7 @@ int set_hexomino_puzzle1(polyominoesstruct *sp) {
 
 */
 
-static struct {int len; point_type point[7]; 
+static struct {int len; point_type point[7];
                int transform_len, transform_list[8], max_white;} heptomino1 =
   {7, {{0,0}, {1,0}, {2,0}, {3,0}, {4,0}, {1,1}, {2,1}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 4};
@@ -1840,7 +1840,7 @@ int set_heptomino_puzzle1(polyominoesstruct *sp) {
   return 1;
 }
 
-/* The following puzzles from 
+/* The following puzzles from
 Polyominoes Puzzles, Patterns, Problems, and Packings Revised (2nd) Edition
 by Solomon W. Golomb   Princeton University Press 1994
 */
@@ -1877,9 +1877,9 @@ int set_heptomino_puzzle2(polyominoesstruct *sp) {
 
 */
 
-static struct {int len; point_type point[11]; 
+static struct {int len; point_type point[11];
                int transform_len, transform_list[8], max_white;} elevenomino1 =
-  {11, {{0,0}, {1,0}, {2,0}, 
+  {11, {{0,0}, {1,0}, {2,0},
         {0,1}, {1,1}, {2,1}, {3,1},
         {0,2}, {1,2}, {2,2}, {3,2}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 6};
@@ -1914,10 +1914,10 @@ int set_elevenomino_puzzle1(polyominoesstruct *sp) {
 
 */
 
-static struct {int len; point_type point[10]; 
+static struct {int len; point_type point[10];
                int transform_len, transform_list[8], max_white;} dekomino1 =
   {10, {       {1,-1},
-               {1,0}, 
+               {1,0},
         {0,1}, {1,1}, {2,1}, {3,1},
         {0,2}, {1,2}, {2,2}, {3,2}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 5};
@@ -1948,9 +1948,9 @@ int set_dekomino_puzzle1(polyominoesstruct *sp) {
 
 */
 
-static struct {int len; point_type point[10]; 
+static struct {int len; point_type point[10];
                int transform_len, transform_list[8], max_white;} octomino1 =
-  {8, {        {1,0}, 
+  {8, {        {1,0},
         {0,1}, {1,1}, {2,1},
         {0,2}, {1,2}, {2,2}, {3,2}},
    8, {0, 1, 2, 3, 4, 5, 6, 7}, 5};
@@ -2039,7 +2039,7 @@ init_polyominoes(ModeInfo * mi) {
 
   if (polyominoeses == NULL) {
     if ((polyominoeses
-         = (polyominoesstruct *) calloc(MI_NUM_SCREENS(mi),sizeof (polyominoesstruct))) 
+         = (polyominoesstruct *) calloc(MI_NUM_SCREENS(mi),sizeof (polyominoesstruct)))
         == NULL)
       return;
   }
@@ -2054,7 +2054,7 @@ init_polyominoes(ModeInfo * mi) {
     sp->identical = (Bool) (LRAND() & 1);
     sp->use3D = (Bool) (NRAND(4));
   } else {
-    sp->identical = identical; 
+    sp->identical = identical;
     sp->use3D = !plain;
   }
   if (sp->identical) {
@@ -2189,7 +2189,7 @@ init_polyominoes(ModeInfo * mi) {
 
   /* Clear the background. */
   MI_CLEARWINDOW(mi);
-  
+
 }
 
 void
@@ -2219,7 +2219,7 @@ draw_polyominoes(ModeInfo * mi) {
   sp->wait--;
   if (sp->wait>0) return;
 
-  memset(sp->changed_array,0,sp->width*sp->height*sizeof(int));
+  (void) memset(sp->changed_array,0,sp->width*sp->height*sizeof(int));
 
   poly_no = first_poly_no(sp);
   point_no = 0;
@@ -2228,7 +2228,7 @@ draw_polyominoes(ModeInfo * mi) {
   another_attachment_try = 1;
   find_blank(sp,&attach_point);
   if (sp->identical && sp->nr_attached < sp->nr_polyominoes)
-    memset(&REASON_TO_NOT_ATTACH(sp->nr_attached,0),0,sp->nr_polyominoes*sizeof(int));
+    (void) memset(&REASON_TO_NOT_ATTACH(sp->nr_attached,0),0,sp->nr_polyominoes*sizeof(int));
   while(!done) {
     if (sp->nr_attached < sp->nr_polyominoes) {
       while (!done && another_attachment_try) {
@@ -2293,7 +2293,7 @@ draw_polyominoes(ModeInfo * mi) {
 void
 release_polyominoes(ModeInfo * mi) {
   int screen;
-  
+
   if (polyominoeses != NULL) {
     for (screen=0;screen<MI_NUM_SCREENS(mi); screen++)
       free_polyominoes(&polyominoeses[screen]);
