@@ -62,19 +62,17 @@ static XrmOptionDescRec opts[] =
 	{(char *) "-duration", (char *) ".random.duration", XrmoptionSepArg, (caddr_t) NULL},
 	{(char *) "-modelist", (char *) ".random.modelist", XrmoptionSepArg, (caddr_t) NULL},
 	{(char *) "-sequential", (char *) ".random.sequential", XrmoptionNoArg, (caddr_t) "on"},
-      {(char *) "+sequential", (char *) ".random.sequential", XrmoptionNoArg, (caddr_t) "off"},
-	{(char *) "-sequential", (char *) ".random.sequential", XrmoptionNoArg, (caddr_t) "on"},
-      {(char *) "+sequential", (char *) ".random.sequential", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "+sequential", (char *) ".random.sequential", XrmoptionNoArg, (caddr_t) "off"},
 	{(char *) "-fullrandom", (char *) ".random.fullrandom", XrmoptionNoArg, (caddr_t) "on"},
 	{(char *) "+fullrandom", (char *) ".random.fullrandom", XrmoptionNoArg, (caddr_t) "off"}
 };
 
 static argtype vars[] =
 {
-	{(caddr_t *) & duration, (char *) "duration", (char *) "Duration", (char *) DEF_DURATION, t_Int},
-    {(caddr_t *) & modelist, (char *) "modelist", (char *) "Modelist", (char *) DEF_MODELIST, t_String},
-	{(caddr_t *) & sequential, (char *) "sequential", (char *) "Sequential", (char *) DEF_SEQUENTIAL, t_Bool},
-{(caddr_t *) & fullrandom, (char *) "fullrandom", (char *) "FullRandom", (char *) DEF_FULLRANDOM, t_Bool}
+	{(void *) & duration, (char *) "duration", (char *) "Duration", (char *) DEF_DURATION, t_Int},
+	{(void *) & modelist, (char *) "modelist", (char *) "Modelist", (char *) DEF_MODELIST, t_String},
+	{(void *) & sequential, (char *) "sequential", (char *) "Sequential", (char *) DEF_SEQUENTIAL, t_Bool},
+	{(void *) & fullrandom, (char *) "fullrandom", (char *) "FullRandom", (char *) DEF_FULLRANDOM, t_Bool}
 };
 
 static OptionStruct desc[] =
@@ -144,6 +142,9 @@ static char gl_modes[][MAXMODECHARS] =
 #ifdef MODE_atunnels
 	"atunnels",
 #endif
+#ifdef MODE_biof
+	"biof",
+#endif
 #ifdef MODE_bubble3d
 	"bubble3d",
 #endif
@@ -204,6 +205,9 @@ static char gl_modes[][MAXMODECHARS] =
 #ifdef MODE_text3d
 	"text3d",
 #endif
+#ifdef MODE_text3d2
+	"text3d2",
+#endif
 };
 
 #define NUMGL (int) (sizeof (gl_modes) / sizeof (gl_modes[0]))
@@ -264,6 +268,9 @@ static char write_modes[][MAXMODECHARS] =
 #ifdef MODE_tik_tak
 	"tik_tak",
 #endif
+#ifdef MODE_toneclock
+	"toneclock",
+#endif
 #ifdef MODE_tube
 	"tube"
 #endif
@@ -274,6 +281,9 @@ static char write_modes[][MAXMODECHARS] =
 
 static char nice_modes[][MAXMODECHARS] =
 {
+#ifdef MODE_apollonian
+	"apollonian",
+#endif
 #ifdef MODE_blot
 	"blot",
 #endif
@@ -286,21 +296,24 @@ static char nice_modes[][MAXMODECHARS] =
 #ifdef MODE_clock
 	"clock",
 #endif
-#ifdef MODE_crystal
-	"crystal",
-#endif
 #ifdef MODE_daisy
 	"daisy",
 #endif
 #ifdef MODE_dclock
 	"dclock",
 #endif
-#ifdef MODE_demon
-	"demon",
+#ifdef MODE_decay
+	"decay",
 #endif
 #ifdef MODE_deco
 	"deco",
 #endif
+#ifdef MODE_demon
+	"demon",
+#endif
+#ifdef MODE_dilemma
+	"dilemma",
+#endif
 #ifdef MODE_dragon
 	"dragon",
 #endif
@@ -310,17 +323,17 @@ static char nice_modes[][MAXMODECHARS] =
 #ifdef MODE_fadeplot
 	"fadeplot",
 #endif
-#ifdef MODE_flag
-	"flag",
-#endif
 #ifdef MODE_flame
 	"flame",
 #endif
+#ifdef MODE_forest
+	"forest",
+#endif
 #ifdef MODE_grav
 	"grav",
 #endif
-#ifdef MODE_helix
-	"helix",
+#ifdef MODE_hop
+	"hop",
 #endif
 #ifdef MODE_hyper
 	"hyper",
@@ -334,9 +347,6 @@ static char nice_modes[][MAXMODECHARS] =
 #ifdef MODE_kaleid
 	"kaleid",
 #endif
-#ifdef MODE_laser
-  "laser",
-#endif
 #ifdef MODE_life
   "life",
 #endif
@@ -361,18 +371,21 @@ static char nice_modes[][MAXMODECHARS] =
 #ifdef MODE_marquee
 	"marquee",
 #endif
+#ifdef MODE_munch
+	"munch",
+#endif
 #ifdef MODE_nose
 	"nose",
 #endif
+#ifdef MODE_pacman
+	"pacman",
+#endif
 #ifdef MODE_penrose
 	"penrose",
 #endif
 #ifdef MODE_petal
 	"petal",
 #endif
-#ifdef MODE_petri
-	"petri",
-#endif
 #ifdef MODE_puzzle
 	"puzzle",
 #endif
@@ -385,18 +398,18 @@ static char nice_modes[][MAXMODECHARS] =
 #ifdef MODE_roll
 	"roll",
 #endif
-#ifdef MODE_rotor
-	"rotor",
-#endif
-#ifdef MODE_shape
-	"shape",
-#endif
-#ifdef MODE_sierpinski
-	"sierpinski",
-#endif
 #ifdef MODE_solitare
 	"solitare",
 #endif
+#ifdef MODE_space
+	"space",
+#endif
+#ifdef MODE_sphere
+	"sphere",
+#endif
+#ifdef MODE_spiral
+	"spiral",
+#endif
 #ifdef MODE_spline
 	"spline",
 #endif
@@ -406,6 +419,9 @@ static char nice_modes[][MAXMODECHARS] =
 #ifdef MODE_swarm
 	"swarm",
 #endif
+#ifdef MODE_tetris
+	"tetris",
+#endif
 #ifdef MODE_triangle
 	"triangle",
 #endif
@@ -418,8 +434,8 @@ static char nice_modes[][MAXMODECHARS] =
 #ifdef MODE_vines
 	"vines",
 #endif
-#ifdef MODE_voters
-	"voters",
+#ifdef MODE_wator
+	"wator",
 #endif
 #ifdef MODE_wire
 	"wire",
@@ -430,6 +446,9 @@ static char nice_modes[][MAXMODECHARS] =
 #ifdef MODE_worm
 	"worm",
 #endif
+#ifdef MODE_xcl
+	"xcl",
+#endif
 #ifdef MODE_xjack
 	"xjack"
 #endif
@@ -499,6 +518,9 @@ static char automata_modes[][MAXMODECHARS] =
 #ifdef MODE_ant
 	"ant",
 #endif
+#ifdef MODE_ant3d
+	"ant3d",
+#endif
 #ifdef MODE_bug
 	"bug",
 #endif
@@ -660,7 +682,10 @@ static char geometry_modes[][MAXMODECHARS] =
 	"spline",
 #endif
 #ifdef MODE_tik_tak
-	"tik_tak"
+	"tik_tak",
+#endif
+#ifdef MODE_toneclock
+	"toneclock"
 #endif
 };
 
