@@ -22,6 +22,7 @@ static const char sccsid[] = "@(#)strange.c	5.00 2000/11/01 xlockmore";
  * other special, indirect and consequential damages.
  *
  * Revision History:
+ * 22-Dec-2004: TDA: Replace Gauss_Rand with a real Gaussian.
  * 01-Nov-2000: Allocation checks
  * 10-May-1997: jwz@jwz.org: turned into a standalone program.
  *              Made it render into an offscreen bitmap and then copy
@@ -96,7 +97,7 @@ typedef struct _ATTRACTOR {
 	GC          dbuf_gc;
 } ATTRACTOR;
 
-static ATTRACTOR *Root = (ATTRACTOR *) NULL; 
+static ATTRACTOR *Root = (ATTRACTOR *) NULL;
 
 static DBL  Amp_Prm[MAX_PRM] =
 {
@@ -110,7 +111,7 @@ static DBL  Mid_Prm[MAX_PRM] =
 	0.0, 1.5, 0.0, .5, 1.5,
 	0.0, 1.5, -1.0, -.5, 2.5,
 };
-
+#if 0
 static      DBL
 Gauss_Rand(DBL c, DBL A, DBL S)
 {
@@ -123,6 +124,39 @@ Gauss_Rand(DBL c, DBL A, DBL S)
 	else
 		return (c - y);
 }
+#else
+/* I don't know that it makes a difference, but this one actually *is*
+   a Gaussian.  [TDA] */
+
+/* Generate Gaussian random number: mean c, "amplitude" A (actually
+   A is 3*standard deviation).  'S' is unused.  */
+
+/* Note this generates a pair of gaussian variables, so it saves one
+   to give out next time it's called */
+
+static double
+Gauss_Rand(DBL c, DBL A, DBL S)
+{
+	static double d;
+	static Bool ready = 0;
+	if(ready) {
+		ready = 0;
+		return c + A/3 * d;
+	} else {
+		double x, y, w;
+		do {
+			x = 2.0 * (double)LRAND() / MAXRAND - 1.0;
+			y = 2.0 * (double)LRAND() / MAXRAND - 1.0;
+			w = x*x + y*y;
+		} while(w >= 1.0);
+
+		w = sqrt((-2 * log(w))/w);
+		ready = 1;
+		d =          x * w;
+		return c + A/3 * y * w;
+	}
+}
+#endif
 
 static void
 Random_Prm(DBL * Prm)
@@ -430,7 +464,7 @@ release_strange(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); ++screen)
 			free_strange(MI_DISPLAY(mi), &Root[screen]);
 		free(Root);
-		Root = (ATTRACTOR *) NULL; 
+		Root = (ATTRACTOR *) NULL;
 	}
 }
 
