@@ -3,14 +3,14 @@
  *  Control-Line in a box
  *  Copyright (c) 2000 by Martin Berentsen <berentsen@sent5.uni-duisburg.de>
  *
- * change-log 
+ * change-log
  * 0.4pl2 -> 0.5pl0 25/07/2000
- * -singl command line option becomes to -count num 
+ * -singl command line option becomes to -count num
  * 0.5pl0 -> 0.5pl1 02.02.2001
  * bugs in -oldcolor and -randomstart option removed
  *
  * TODO as next:
- * - a user defined speed for every used plane 
+ * - a user defined speed for every used plane
  *
  */
 
@@ -88,15 +88,15 @@ static XrmOptionDescRec opts[] =
 };
 static argtype vars[] =
 {
-  {(caddr_t *) & speed_in, (char *) "speed", (char *) "Speed", (char *) DEF_SPEED_IN, t_Float},
-  {(caddr_t *) & frametime, (char *) "frametime", (char *) "frametime", (char *) DEF_FRAMETIME, t_Int},
-  {(caddr_t *) & line_length, (char *) "line_length", (char *) "Line_length", (char *) DEF_LINE_LENGTH, t_Int},
-  {(caddr_t *) & spectator, (char *) "spectator", (char *) "Spectator", (char *) DEF_SPECTATOR, t_Float},
-  {(caddr_t *) & viewmodel, (char *) "viewmodel", (char *) "Viewmodel", (char *) DEF_VIEWMODEL, t_Bool},
-  {(caddr_t *) & oldcolor, (char *) "oldcolor", (char *) "Oldcolor", (char *) DEF_OLDCOLOR, t_Bool},
-  {(caddr_t *) & debug, (char *) "xcldebug", (char *) "Xcldebug", (char *) DEF_XCLDEBUG, t_Bool},
-  {(caddr_t *) & automatic, (char *) "automatic", (char *) "Automatic", (char *) DEF_AUTOMATIC, t_Bool},
-  {(caddr_t *) & randomstart, (char *) "randomstart", (char *) "Randomstart", (char *) DEF_RANDOMSTART, t_Bool}
+  {(void *) & speed_in, (char *) "speed", (char *) "Speed", (char *) DEF_SPEED_IN, t_Float},
+  {(void *) & frametime, (char *) "frametime", (char *) "frametime", (char *) DEF_FRAMETIME, t_Int},
+  {(void *) & line_length, (char *) "line_length", (char *) "Line_length", (char *) DEF_LINE_LENGTH, t_Int},
+  {(void *) & spectator, (char *) "spectator", (char *) "Spectator", (char *) DEF_SPECTATOR, t_Float},
+  {(void *) & viewmodel, (char *) "viewmodel", (char *) "Viewmodel", (char *) DEF_VIEWMODEL, t_Bool},
+  {(void *) & oldcolor, (char *) "oldcolor", (char *) "Oldcolor", (char *) DEF_OLDCOLOR, t_Bool},
+  {(void *) & debug, (char *) "xcldebug", (char *) "Xcldebug", (char *) DEF_XCLDEBUG, t_Bool},
+  {(void *) & automatic, (char *) "automatic", (char *) "Automatic", (char *) DEF_AUTOMATIC, t_Bool},
+  {(void *) & randomstart, (char *) "randomstart", (char *) "Randomstart", (char *) DEF_RANDOMSTART, t_Bool}
 };
 static OptionStruct desc[] =
 {
@@ -182,7 +182,7 @@ static int countlines(void)
 static void um2(int X, int Y, int Z, xclstruct *dp)
 {
   float X2,X3,X4,Y1,Y3,Y4,Z1,Z2,Z4;
-  
+
   Y1 = dp->Ca * Y - dp->Sa * Z;
   Z1 = dp->Sa * Y + dp->Ca * Z;
   X2 = dp->Cb * X - dp->Sb * Z1;
@@ -212,7 +212,7 @@ static void view_3d(XSegment *xseg, xclstruct *dp)
   dp->Sc = sin(dp->Gamma);
 
   for(I = 0; I < ENDPOINTS; I++) {
-    um2( model_data1 [ I * 3 + 0], model_data1 [ I * 3 + 1], 
+    um2( model_data1 [ I * 3 + 0], model_data1 [ I * 3 + 1],
          model_data1 [ I * 3 + 2],dp);
     BX [I] = dp->Bx;
     BY [I] = dp->By;
@@ -233,15 +233,15 @@ static long get_color(Display *dpy, char *color, XColor *final_color)
   XColor cdef;
   Colormap cmap;
   cmap = DefaultColormap(dpy,DefaultScreen(dpy));
-  
+
   if (!XParseColor(dpy, cmap, color, &cdef) ||
       !XAllocColor(dpy, cmap, &cdef))
     {
       (void) fprintf(stderr, "Color \"%s\" wasn't found\n", color);
     }
-  
+
   if (final_color != NULL) *final_color = cdef;  /* copy the final color. */
-  
+
   return(cdef.pixel);
 }
 
@@ -267,7 +267,7 @@ static void
 free_xcl(Display *display, xclstruct  *dp)
 {
     int plane;
-      
+
     for (plane = 0; plane < dp->planes; plane++) {
       if (dp->xseg[plane] != NULL) {
         free(dp->xseg[plane]);
@@ -304,20 +304,20 @@ void init_xcl(ModeInfo * mi)
   Display *display = MI_DISPLAY(mi);
   int i;            /* scratch */
   xclstruct *dp;
-  
+
   if (xcls == NULL) {
     if ((xcls = (xclstruct *) calloc(MI_NUM_SCREENS(mi),
                                      sizeof (xclstruct))) == NULL)
       return;
   }
   dp = &xcls[MI_SCREEN(mi)];
-  
+
   /* Update every time */
   dp->width = MI_WIDTH(mi);
   dp->height = MI_HEIGHT(mi);
   dp->mid_x = (dp->width / 2);
   dp->mid_y = (dp->height / 2);
-  
+
   if(dp->no_preset != 1) {
     dp->no_preset = 1;
     /* some presettings */
@@ -345,14 +345,14 @@ void init_xcl(ModeInfo * mi)
       dp->alpha[i] = 0.75;      /* direction */
       dp->turn[i] = 0;
       dp->turn_direction[i] = 1;
-      
+
       speed[i] = speed_in;  /* see TODO */
     }
-    
+
     random_pid = getpid(); /* goes here first for randomstart */
-    
+
     if(randomstart) {
-      for(i=0;i< dp->planes; i++) { 
+      for(i=0;i< dp->planes; i++) {
         switch(i) {
         case 0:
           dp->az[0] += (random_pid % 31) / 5.0;
@@ -362,21 +362,21 @@ void init_xcl(ModeInfo * mi)
         }
       }
     }
-    
+
     dp->bg = MI_BLACK_PIXEL(mi);
-    
+
     if(MI_IS_MONO(mi))
-      for(i=0;i< dp->planes; i++) { 
+      for(i=0;i< dp->planes; i++) {
         dp->planecolor[i] = MI_WHITE_PIXEL(mi);
       }
     else {
       if(!oldcolor) {
-        for(i=0;i< dp->planes; i++) { 
+        for(i=0;i< dp->planes; i++) {
           dp->planecolor[i] = MI_PIXEL(mi, NRAND(MI_NPIXELS(mi)));
         }
       }
       else { /* with count >2 no so good */
-        for(i=0;i< dp->planes; i++) { 
+        for(i=0;i< dp->planes; i++) {
           switch(i) {
           case 0:
             dp->planecolor[0] = get_color(display, (char *) "yellow",
@@ -392,16 +392,16 @@ void init_xcl(ModeInfo * mi)
         }
       }
     }
-    
+
     if(dp->erase_gc == NULL)
       if (!get_GC(display, MI_WINDOW(mi), &(dp->erase_gc),dp->bg)) {
         free_xcl(display, dp);
         return;
       }
-    
+
     dp->lines = countlines();
-    
-    for(i=0;i< dp->planes; i++) { 
+
+    for(i=0;i< dp->planes; i++) {
       if(dp->gc[i] == NULL)
         if (!get_GC(display, MI_WINDOW(mi), &(dp->gc[i]),
                     dp->planecolor[i])) {
@@ -409,7 +409,7 @@ void init_xcl(ModeInfo * mi)
           return;
         }
       dp->omega_const[i] = speed[i]/3.6 /line_length*1000.0;
-      
+
       if(dp->xseg[i] == NULL)
         if ((dp-> xseg[i] = (XSegment *) malloc(sizeof(XSegment) *
                                                 dp->lines)) == NULL) {
@@ -423,7 +423,7 @@ void init_xcl(ModeInfo * mi)
           return;
         }
     }
-    
+
     if(MI_IS_VERBOSE(mi)) {
       (void) printf("X control line combat in a box\n");
 #if !defined( lint ) && !defined( SABER )
@@ -438,15 +438,15 @@ void init_xcl(ModeInfo * mi)
       (void) printf("Calibration at %d frames\n",REGULATE);
     }
   }
-  
+
   /* clear the screen */
-  
+
   MI_CLEARWINDOW(mi);
-    
+
   (void) gettimeofday(&(dp->tv1),0);
-  dp->time1 = (double)dp->tv1.tv_sec + 
+  dp->time1 = (double)dp->tv1.tv_sec +
     (double)dp->tv1.tv_usec/(double)1000000;
-  
+
   dp->xcldelay = frametime;
 }
 
@@ -455,7 +455,7 @@ void draw_xcl(ModeInfo * mi)
   static int count = 0;
   int i;
   xclstruct *dp;
-  
+
   if (xcls == NULL)
     return;
   dp = &xcls[MI_SCREEN(mi)];
@@ -463,7 +463,7 @@ void draw_xcl(ModeInfo * mi)
     return;
 
   MI_IS_DRAWN(mi) = True;
- 
+
   if(viewmodel == True)
     {
       dp->Vx = 1;                     /* movement in X (width,negativ)*/
@@ -476,7 +476,7 @@ void draw_xcl(ModeInfo * mi)
       dp->Alpha += 0.03;
       dp->Beta += 0.006;
       dp->Gamma += 0.009;
-      
+
       if (count != 0) {
         XDrawSegments(MI_DISPLAY(mi),MI_WINDOW(mi),dp->erase_gc,
                       dp->xseg_old[0],dp->lines);
@@ -491,38 +491,38 @@ void draw_xcl(ModeInfo * mi)
   else {
     if(automatic)
       dp->G = dp->width / 2.1 ;
-    
+
     for(i=0;i<dp->planes;i++) {
       (void) memcpy(dp->xseg_old[i],dp->xseg[i],sizeof(XSegment)*dp->lines);
-      
+
       dp->Alpha = - dp->alpha[i];
       dp->Beta = - dp->el[i];
       dp->Gamma = dp->az[i];
-      
+
       dp->Vx = -(int)(cos(dp->az[i]) * cos(dp->el[i]) * line_length);
-      dp->Vy = spectator - 
+      dp->Vy = spectator -
         (int)(sin(dp->az[i]) * cos(dp->el[i]) * line_length);
       dp->Vz = (int)(sin(dp->el[i]) * line_length);
-      
+
       view_3d(dp->xseg[i],dp);
       XDrawSegments(MI_DISPLAY(mi),MI_WINDOW(mi),dp->erase_gc,
                     dp->xseg_old[i],dp->lines);
       XDrawSegments(MI_DISPLAY(mi),MI_WINDOW(mi),dp->gc[i],
                     dp->xseg[i],dp->lines);
     }
-    
+
     XFlush(MI_DISPLAY(mi));
-    
+
     /* now move all planes */
     for(i=0;i<dp->planes;i++) {
       dp->delta_az[i] = cos(dp->alpha[i]) * dp->omega_const[i] *
         frametime/1000000;
       dp->delta_el[i] = sin(dp->alpha[i]) * dp->omega_const[i] *
         frametime/1000000;
-      
+
       dp->az[i] -= dp->delta_az[i];
       dp->el[i] -= dp->delta_el[i];
-      
+
       if (dp->el[i] >= 0.0)
         switch (dp->turn[i]) {
         case 0:
@@ -554,9 +554,9 @@ void draw_xcl(ModeInfo * mi)
         if(dp->turn[i] == 0)
           dp->alpha[i] += (double)(RAND(600))  / 6283.0 * 2.0 * M_PI;
     } /* for (i) */
-    
+
     count++;
-    
+
     (void) usleep(dp->xcldelay);
     if((count % REGULATE) == 0) {
       (void) gettimeofday(&(dp->tv1),0);
@@ -564,7 +564,7 @@ void draw_xcl(ModeInfo * mi)
         (double)1000000;
       dp->time3 = dp->time2 - dp->time1;
       dp->time1 = dp->time2;
-      dp->drawtime = (int) (dp->time3 * (1000000/REGULATE))  
+      dp->drawtime = (int) (dp->time3 * (1000000/REGULATE))
         - dp->xcldelay;
       if((dp->xcldelay = frametime - dp->drawtime) <= 0) {
         dp->xcldelay = 10;  /* 1 is possible xor xscreensaver mode */
