@@ -81,6 +81,12 @@ LockStruct  LockProcs[] =
 	 200000, 6, 30, 1, 64, 0.3, (char *) "",
 	 (char *) "Shows billiards", 0, NULL},
 #endif
+#ifdef MODE_biof
+	{(char *) "biof", init_biof, draw_biof, release_biof,
+	 draw_biof, init_biof, (ModeHook *) NULL, &biof_opts,
+	 10000, 800, 1, 0, 64, 1.0, (char *) "",
+	 (char *) "Shows 3D bioform", 0, NULL},
+#endif
 #ifdef MODE_blot
 	{(char *) "blot", init_blot, draw_blot, release_blot,
 	 refresh_blot, init_blot, (ModeHook *) NULL, &blot_opts,
@@ -225,6 +231,12 @@ LockStruct  LockProcs[] =
 	 30000, 10, 1500, 1, 64, 0.6, (char *) "",
 	 (char *) "Shows a fading plot of sine squared", 0, NULL},
 #endif
+#ifdef MODE_fiberlamp
+	{(char *) "fiberlamp", init_fiberlamp, draw_fiberlamp, release_fiberlamp,
+	 draw_fiberlamp, change_fiberlamp, (ModeHook *) NULL, &fiberlamp_opts,
+	 10000, 500, 10000, 0, 64, 1.0, (char *) "",
+	 (char *) "Shows a Fiber Optic Lamp", 0, NULL},
+#endif
 #ifdef MODE_fire
 	{(char *) "fire", init_fire, draw_fire, release_fire,
 	 draw_fire, change_fire, (ModeHook *) NULL, &fire_opts,
@@ -329,8 +341,8 @@ LockStruct  LockProcs[] =
 #endif
 #ifdef MODE_juggle
 	{(char *) "juggle", init_juggle, draw_juggle, release_juggle,
-	 draw_juggle, init_juggle, (ModeHook *) NULL, &juggle_opts,
-	 10000, 150, 30, 1, 64, 1.0, (char *) "",
+	 draw_juggle, change_juggle, (ModeHook *) NULL, &juggle_opts,
+	 10000, 200, 1000, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows a Juggler, juggling", 0, NULL},
 #endif
 #ifdef MODE_julia
@@ -716,6 +728,12 @@ LockStruct  LockProcs[] =
 	 60000, -20, 200, -1000, 64, 1.0, (char *) "",
 	 (char *) "Shows rotating polygons", 0, NULL},
 #endif
+#ifdef MODE_toneclock
+	{(char *) "toneclock", init_toneclock, draw_toneclock, release_toneclock,
+	 refresh_toneclock, init_toneclock, (ModeHook *) NULL, &toneclock_opts,
+	 60000, -20, 200, -1000, 64, 1.0, (char *) "",
+	 (char *) "Shows Peter Schat's toneclock", 0, NULL},
+#endif
 #ifdef MODE_triangle
 	{(char *) "triangle", init_triangle, draw_triangle, release_triangle,
 	 refresh_triangle, init_triangle, (ModeHook *) NULL, &triangle_opts,
