@@ -88,7 +88,9 @@ static login_cap_t *rlc = NULL;
 #endif
 
 #include <errno.h>
+#ifndef errno
 extern int  errno;
+#endif
 
 #if ( HAVE_FCNTL_H && (defined( USE_MULTIPLE_ROOT ) || defined( USE_MULTIPLE_USER )))
 #include <fcntl.h>
@@ -1175,6 +1177,7 @@ checkPasswd(char *buffer)
  */
 	pam_handle_t *pamh;
 	int         pam_error;
+	char *display;
 #ifdef BAD_PAM
 	uid_t       ruid;
 #define BAD_PAM_SETUID	seteuid(ruid);
@@ -1183,7 +1186,7 @@ checkPasswd(char *buffer)
 #endif
 
 #define PAM_BAIL if (pam_error != PAM_SUCCESS) { \
-    pam_end(pamh, 0); BAD_PAM_SETUID return False; \
+    pam_end(pamh, pam_error); BAD_PAM_SETUID return False; \
 }
 #ifdef BAD_PAM
 	ruid = getuid();  /* the real user we are running as */
@@ -1192,6 +1195,13 @@ checkPasswd(char *buffer)
 	PAM_password = buffer;
 	pam_error = pam_start("xlock", user, &PAM_conversation, &pamh);
 	PAM_BAIL;
+
+	display = getenv("DISPLAY");
+	if (display != NULL) {
+		pam_error = pam_set_item(pamh, PAM_TTY, display);
+		PAM_BAIL;
+	}
+
 	pam_error = pam_authenticate(pamh, 0);
 	if (pam_error != PAM_SUCCESS) {
                 if (!allowroot) {
@@ -1208,10 +1218,15 @@ checkPasswd(char *buffer)
 #ifdef BAD_PAM
 	(void) seteuid(ruid); /* back to user's privileges */
 #endif
-	/* Do not do account management or credentials; credentials
-	 * are not needed and account management would just lock up
-	 * a computer and require root to come and unlock it.  Blech.
-	 */
+
+	pam_error = pam_acct_mgmt(pamh, 0);
+	if (pam_error == PAM_NEW_AUTHTOK_REQD)
+		pam_error = pam_chauthtok(pamh, PAM_CHANGE_EXPIRED_AUTHTOK);
+	PAM_BAIL;
+
+	pam_error = pam_setcred(pamh, PAM_REINITIALIZE_CRED);
+	PAM_BAIL;
+
 	pam_end(pamh, PAM_SUCCESS);
 	/* If this point is reached, the user has been authenticated. */
 	done = True;
