@@ -2174,8 +2174,30 @@ checkResources(void)
 		}
 	}
 	if (i == numprocs) {
-		(void) fprintf(stderr, "Unknown mode: ");
-		Syntax(mode);
+		(void) fprintf(stderr,
+			"unrecognized mode \"%s\", using backup mode \"%s\"\n",
+			mode, (char *) DEF_MODE);
+		for (i = 0; i < numprocs; i++) {
+			if (!strcmp(LockProcs[i].cmdline_arg, (char *) DEF_MODE)) {
+				set_default_mode(&LockProcs[i]);
+				break;
+			}
+		}
+		if (i != numprocs) {
+			delay = LockProcs[i].def_delay;
+			count = LockProcs[i].def_count;
+			cycles = LockProcs[i].def_cycles;
+			size = LockProcs[i].def_size;
+			ncolors = LockProcs[i].def_ncolors;
+			saturation = LockProcs[i].def_saturation;
+			bitmap = LockProcs[i].def_bitmap;
+		}
+	}
+	if (i == numprocs) {
+			/* Should not get here, but you never know. */
+		  (void) fprintf(stderr, "unrecognized mode and backup mode \"%s\"\n",
+				(char *) DEF_MODE);
+			Syntax(mode);
 	} else {
 
 		/* count and size we allow negative to mean randomize up to that number */
