@@ -98,7 +98,7 @@ play_sound_so(char *filename, Bool verbose)
 
 	status = AmdInitialize("SO:", volume);	/* Initialize access to AMD */
         if ( status !=0 ) return status;
-   
+
 	AmdSelect(speaker);	/* Select which speaker */
 	fp = open(filename, O_RDONLY, 0777);	/* Open the file */
 	if (!(fp == -1)) {
@@ -131,7 +131,7 @@ play_sound(char* filename, Bool verbose)
 	privs[1] = 0;
 	privs[0] = PRV$M_SYSNAM;
 	pr_status = SYS$SETPRV ( 1, privs, 0, 0 );
-	
+
 	if ( pr_status == SS$_NORMAL ) PLAY_SOUND_MMOV(filename, verbose);
 #endif
      }
@@ -285,7 +285,7 @@ sound_esd_load_sample(char *file)
    {
        while ( s && s->next )
          s = s->next;
-       s->next = malloc(sizeof(EsdSample_t));
+       s->next = (EsdSample_t *) malloc(sizeof(EsdSample_t));
        if ( !s->next )
        {
            (void) fprintf( stderr, "Error ! cannot allocate sample data !\n" );
@@ -297,7 +297,7 @@ sound_esd_load_sample(char *file)
    }
    else
    {
-       s = malloc(sizeof(EsdSample_t));
+       s = (EsdSample_t *) malloc(sizeof(EsdSample_t));
        if ( !s )
        {
            (void) fprintf( stderr, "Error ! cannot allocate sample data !\n" );
@@ -333,7 +333,7 @@ sound_esd_load_sample(char *file)
    s->rate = (int)in_rate;
 
    s->samples = frame_count * bytes_per_frame;
-   s->data = malloc(frame_count * bytes_per_frame);
+   s->data = (unsigned char *) malloc(frame_count * bytes_per_frame);
    if ( !s->data )
    {
        (void) fprintf( stderr, "Error ! cannot allocate memory for sample !\n" );
@@ -429,7 +429,7 @@ sound_esd_shutdown(void)
     if (sound_fd >= 0)
     {
         EsdSample_ptr	s = EsdSamplesList;
- 
+
         while ( s )
         {
             EsdSamplesList = s->next;
