@@ -9,12 +9,19 @@ typedef struct LockStruct_s
 static LockStruct LockProcs[] =
 {
 {(char *) "ant", (char *) "Shows Langton's and Turk's generalized ants"},
+{(char *) "ant3d", (char *) "Shows 3D ants"},
 {(char *) "apollonian", (char *) "Shows Apollonian Circles"},
 #ifdef USE_GL
 {(char *) "atlantis", (char *) "Shows moving sharks/whales/dolphin"},
 #endif
+#ifdef USE_GL
+{(char *) "atunnels", (char *) "Shows an OpenGL advanced tunnel screensaver"},
+#endif
 {(char *) "ball", (char *) "Shows bouncing balls"},
 {(char *) "bat", (char *) "Shows bouncing flying bats"},
+#ifdef USE_GL
+{(char *) "biof", (char *) "Shows 3D bioform"},
+#endif
 {(char *) "blot", (char *) "Shows Rorschach's ink blot test"},
 {(char *) "bouboule", (char *) "Shows Mimi's bouboule of moving stars"},
 {(char *) "bounce", (char *) "Shows bouncing footballs"},
@@ -36,12 +43,13 @@ static LockStruct LockProcs[] =
 {(char *) "deco", (char *) "Shows art as ugly as sin"},
 {(char *) "demon", (char *) "Shows Griffeath's cellular automata"},
 {(char *) "dilemma", (char *) "Shows Lloyd's Prisoner's Dilemma simulation"},
-{(char *) "dragon", (char *) "Shows Deventer's Hexagonal Dragons Maze"},
 {(char *) "discrete", (char *) "Shows various discrete maps"},
+{(char *) "dragon", (char *) "Shows Deventer's Hexagonal Dragons Maze"},
 {(char *) "drift", (char *) "Shows cosmic drifting flame fractals"},
 {(char *) "euler2d", (char *) "Shows a simulation of 2D incompressible inviscid fluid"},
 {(char *) "eyes", (char *) "Shows eyes following a bouncing grelb"},
 {(char *) "fadeplot", (char *) "Shows a fading plot of sine squared"},
+{(char *) "fiberlamp", (char *) "Shows a Fiber Optic Lamp"},
 #ifdef USE_GL
 {(char *) "fire", (char *) "Shows a 3D fire-like image"},
 #endif
@@ -98,7 +106,9 @@ static LockStruct LockProcs[] =
 #endif
 {(char *) "mountain", (char *) "Shows Papo's mountain range"},
 {(char *) "munch", (char *) "Shows munching squares"},
-{(char *) "nose", (char *) "Shows SGI Diatoms"},
+#ifdef USE_GL
+{(char *) "noof", (char *) "Shows SGI Diatoms"},
+#endif
 {(char *) "nose", (char *) "Shows a man with a big nose runs around spewing out messages"},
 {(char *) "pacman", (char *) "Shows Pacman(tm)"},
 {(char *) "penrose", (char *) "Shows Penrose's quasiperiodic tilings"},
@@ -157,8 +167,12 @@ static LockStruct LockProcs[] =
 #if defined(USE_GL) && defined(HAVE_CXX) && defined( HAVE_TTF ) && defined( HAVE_GLTT )
 {(char *) "text3d", (char *) "Shows 3D text"},
 #endif
+#if defined(USE_GL) && defined(HAVE_CXX) && defined( HAVE_FREETYPE ) && defined( HAVE_FTGL )
+{(char *) "text3d2", (char *) "Shows 3D text"},
+#endif
 {(char *) "thornbird", (char *) "Shows an animated bird in a thorn bush fractal map"},
 {(char *) "tik_tak", (char *) "Shows rotating polygons"},
+{(char *) "toneclock", (char *) "Shows Peter Schat's toneclock"},
 {(char *) "triangle", (char *) "Shows a triangle mountain range"},
 {(char *) "tube", (char *) "Shows an animated tube"},
 {(char *) "turtle", (char *) "Shows turtle fractals"},
