@@ -13,7 +13,7 @@ static const char sccsid[] = "@(#)xmlock.c	4.08 98/02/18 xlockmore";
  *
  * Revision History:
  * Jun-03: Code added from Xlockup by Thad Phetteplace
- *     tdphette@dexter.glaci.com 
+ *     tdphette@dexter.glaci.com
  *   Sun -- works (both timeouts seem connected to the same device)
  *   Linux -- mouse timeout works, keyboard timeout does not work
  *   Cygwin -- mouse timout does not work, keyboard timeout does not work
@@ -81,14 +81,13 @@ static const char sccsid[] = "@(#)xmlock.c	4.08 98/02/18 xlockmore";
 
 #include "option.h"
 
-#ifdef SunCplusplus
-        extern int  kill(pid_t, int);
-        extern pid_t  wait(int *);
-
+#ifdef SOLARIS2
+extern int  kill(pid_t, int);
+extern pid_t  wait(int *);
 #else
 #if 0
-        extern int  kill(int, int);
-        extern pid_t  wait(int *);
+extern int  kill(int, int);
+extern pid_t  wait(int *);
 
 #endif
 #endif
@@ -259,7 +258,7 @@ static void checkTime()
       (timenow-statkeybd.st_atime >= timeout)*/) {
      callLocker(LAUNCH);
   }
-#if DEBUG
+#ifdef DEBUG
   printf("timeout %ld,  timenow - amouse %ld\n",
     timeout, timenow - statmouse.st_atime);
   printf("timeout %ld,  timenow - akeybd %ld\n",
